-- MySQL dump 10.11
--
-- Host: eldfell.gene.le.ac.uk    Database: HGVbaseG2P_marker
-- ------------------------------------------------------
-- Server version	5.0.51a-3-log

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `Allele`
--

DROP TABLE IF EXISTS `Allele`;
CREATE TABLE `Allele` (
  `AlleleID` int(10) unsigned NOT NULL auto_increment,
  `Identifier` varchar(15) default NULL,
  `Status` varchar(20) NOT NULL default 'active',
  `MarkerID` int(10) unsigned NOT NULL default '0',
  `Upstream30bp` varchar(30) NOT NULL default '' COMMENT 'type & strand as in dbSNP, to contextualize alleles',
  `AlleleSeq` text NOT NULL COMMENT 'type & strand as in dbSNP',
  `AlleleSeqDigest` varchar(32) default NULL COMMENT 'MD5 digest of allele seq, to check if seqs are the same or not',
  `Downstream30bp` varchar(30) NOT NULL default '' COMMENT 'type & strand as in dbSNP, to contextualize alleles',
  `SeqType` enum('G','C') NOT NULL default 'G' COMMENT '''G'' (Genomic) or ''C'' (cDNA), as used in dbSNP',
  PRIMARY KEY  (`AlleleID`),
  UNIQUE KEY `MarkerID` (`MarkerID`,`AlleleSeqDigest`),
  CONSTRAINT `Allele_ibfk_1` FOREIGN KEY (`MarkerID`) REFERENCES `Marker` (`MarkerID`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=40891740 DEFAULT CHARSET=latin1;

--
-- Table structure for table `AssayMarker`
--

DROP TABLE IF EXISTS `AssayMarker`;
CREATE TABLE `AssayMarker` (
  `AssayMarkerID` int(10) unsigned NOT NULL default '0',
  `AssayID` int(10) unsigned NOT NULL default '0',
  `MarkerID` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`AssayMarkerID`),
  KEY `MarkerID` (`MarkerID`),
  KEY `AssayID` (`AssayID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `AssayMarkerGenotype`
--

DROP TABLE IF EXISTS `AssayMarkerGenotype`;
CREATE TABLE `AssayMarkerGenotype` (
  `AssayMarkerGenotypeID` int(10) unsigned NOT NULL auto_increment,
  `AssayMarkerID` int(10) unsigned NOT NULL,
  `GenotypeID` int(10) unsigned NOT NULL,
  PRIMARY KEY  (`AssayMarkerGenotypeID`),
  UNIQUE KEY `AssayMarkerID` (`AssayMarkerID`,`GenotypeID`),
  KEY `GenotypeID` (`GenotypeID`),
  CONSTRAINT `AssayMarkerGenotype_ibfk_3` FOREIGN KEY (`AssayMarkerID`) REFERENCES `AssayMarker` (`AssayMarkerID`),
  CONSTRAINT `AssayMarkerGenotype_ibfk_4` FOREIGN KEY (`GenotypeID`) REFERENCES `Genotype` (`GenotypeID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `Assay_MethodList`
--

DROP TABLE IF EXISTS `Assay_MethodList`;
CREATE TABLE `Assay_MethodList` (
  `Method` varchar(250) NOT NULL default '' COMMENT 'initial values: (''ABI 5''-Nuclease'',''Affymetrix 10k array'',''Affymetrix 100k array'',',
  PRIMARY KEY  (`Method`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `Assay_TypeList`
--

DROP TABLE IF EXISTS `Assay_TypeList`;
CREATE TABLE `Assay_TypeList` (
  `Type` varchar(100) NOT NULL COMMENT 'initial values: (''SNP:singleplex'',',
  PRIMARY KEY  (`Type`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `AssayedGenotype`
--

DROP TABLE IF EXISTS `AssayedGenotype`;
CREATE TABLE `AssayedGenotype` (
  `AssayMarkerID` int(10) unsigned NOT NULL default '0',
  `GenotypeID` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`AssayMarkerID`,`GenotypeID`),
  KEY `GenotypeID` (`GenotypeID`),
  CONSTRAINT `AssayedGenotype_ibfk_1` FOREIGN KEY (`AssayMarkerID`) REFERENCES `AssayMarker` (`AssayMarkerID`),
  CONSTRAINT `AssayedGenotype_ibfk_2` FOREIGN KEY (`GenotypeID`) REFERENCES `Genotype` (`GenotypeID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `Build`
--

DROP TABLE IF EXISTS `Build`;
CREATE TABLE `Build` (
  `BuildID` int(10) unsigned NOT NULL auto_increment,
  `Database` varchar(50) NOT NULL,
  `FullName` varchar(250) default NULL,
  `URL` varchar(250) default NULL,
  `Build` varchar(10) NOT NULL default 'N/A' COMMENT 'Start at 21 for HGVbase-G2P. Latest download for dbSNP',
  `Date` date NOT NULL default '0000-00-00',
  PRIMARY KEY  (`BuildID`),
  UNIQUE KEY `Database` (`Database`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `Crossref`
--

DROP TABLE IF EXISTS `Crossref`;
CREATE TABLE `Crossref` (
  `CrossrefID` int(10) unsigned NOT NULL auto_increment,
  `HotlinkID` int(10) unsigned NOT NULL default '0',
  `UrlID` varchar(100) default '',
  PRIMARY KEY  (`CrossrefID`),
  UNIQUE KEY `HotlinkID` (`HotlinkID`,`UrlID`),
  CONSTRAINT `Crossref_ibfk_1` FOREIGN KEY (`HotlinkID`) REFERENCES `Hotlink` (`HotlinkID`)
) ENGINE=InnoDB AUTO_INCREMENT=4625 DEFAULT CHARSET=latin1;

--
-- Table structure for table `DataSource`
--

DROP TABLE IF EXISTS `DataSource`;
CREATE TABLE `DataSource` (
  `DataSourceID` int(4) unsigned NOT NULL auto_increment,
  `Name` varchar(100) NOT NULL,
  `URI` varchar(300) default NULL,
  PRIMARY KEY  (`DataSourceID`),
  UNIQUE KEY `Name` (`Name`),
  UNIQUE KEY `URI` (`URI`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=latin1;

--
-- Table structure for table `DiseaseCategory`
--

DROP TABLE IF EXISTS `DiseaseCategory`;
CREATE TABLE `DiseaseCategory` (
  `DiseaseCategoryID` int(6) unsigned NOT NULL auto_increment,
  `ParentCategoryID` int(6) unsigned default NULL COMMENT 'PK for parent category, if this is not a root term',
  `MeSHTreeID` varchar(30) default NULL COMMENT 'MeSH tree ID, for linking back to NLM website',
  `Name` varchar(100) default NULL,
  `Description` text,
  PRIMARY KEY  (`DiseaseCategoryID`),
  UNIQUE KEY `Name` (`Name`),
  KEY `ParentCategoryID` (`ParentCategoryID`),
  CONSTRAINT `DiseaseCategory_ibfk_1` FOREIGN KEY (`ParentCategoryID`) REFERENCES `DiseaseCategory` (`DiseaseCategoryID`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=9 DEFAULT CHARSET=latin1 COMMENT='Rough disease categories for phenotype properties, mostly ba';

--
-- Table structure for table `Genotype`
--

DROP TABLE IF EXISTS `Genotype`;
CREATE TABLE `Genotype` (
  `GenotypeID` int(10) unsigned NOT NULL auto_increment,
  `MarkerID` int(10) unsigned NOT NULL,
  `GenotypeLabel` varchar(100) NOT NULL,
  PRIMARY KEY  (`GenotypeID`),
  UNIQUE KEY `MarkerID_2` (`MarkerID`,`GenotypeLabel`),
  CONSTRAINT `Genotype_ibfk_1` FOREIGN KEY (`MarkerID`) REFERENCES `Marker` (`MarkerID`)
) ENGINE=InnoDB AUTO_INCREMENT=12608861 DEFAULT CHARSET=latin1;

--
-- Table structure for table `Genotypedef`
--

DROP TABLE IF EXISTS `Genotypedef`;
CREATE TABLE `Genotypedef` (
  `GenotypedefID` int(10) unsigned NOT NULL auto_increment,
  `GenotypeID` int(10) unsigned NOT NULL default '0',
  `AlleleID` int(10) unsigned default NULL COMMENT ' Enter values in at most one',
  `Type` enum('Observed','Ratio','Count','Signal') NOT NULL COMMENT 'Allowed values: "Observed", "Ratio", "Count", "Signal"',
  `Value` varchar(50) NOT NULL COMMENT 'Actual value observed',
  PRIMARY KEY  (`GenotypedefID`),
  KEY `GenotypeID` (`GenotypeID`),
  KEY `AlleleID` (`AlleleID`),
  CONSTRAINT `Genotypedef_ibfk_1` FOREIGN KEY (`AlleleID`) REFERENCES `Allele` (`AlleleID`),
  CONSTRAINT `Genotypedef_ibfk_2` FOREIGN KEY (`GenotypeID`) REFERENCES `Genotype` (`GenotypeID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `Haplotype`
--

DROP TABLE IF EXISTS `Haplotype`;
CREATE TABLE `Haplotype` (
  `HaplotypeID` int(10) unsigned NOT NULL default '0',
  `Identifier` varchar(14) NOT NULL default '' COMMENT '''HAP...''',
  `MarkersetID` int(10) unsigned default NULL,
  `LocalID` varchar(100) NOT NULL,
  PRIMARY KEY  (`HaplotypeID`),
  UNIQUE KEY `Identifier` (`Identifier`),
  KEY `MarkersetID` (`MarkersetID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `HaplotypeAllele`
--

DROP TABLE IF EXISTS `HaplotypeAllele`;
CREATE TABLE `HaplotypeAllele` (
  `HaplotypeAlleleID` int(10) unsigned NOT NULL auto_increment,
  `HaplotypeID` int(10) unsigned NOT NULL default '0',
  `AlleleID` int(10) unsigned NOT NULL default '0',
  `PQOrder` tinyint(3) unsigned NOT NULL default '0',
  PRIMARY KEY  (`HaplotypeAlleleID`),
  UNIQUE KEY `HaplotypeID` (`HaplotypeID`,`AlleleID`),
  KEY `AlleleID` (`AlleleID`),
  CONSTRAINT `HaplotypeAllele_ibfk_1` FOREIGN KEY (`HaplotypeID`) REFERENCES `Haplotype` (`HaplotypeID`),
  CONSTRAINT `HaplotypeAllele_ibfk_2` FOREIGN KEY (`AlleleID`) REFERENCES `Allele` (`AlleleID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `HaplotypeCrossref`
--

DROP TABLE IF EXISTS `HaplotypeCrossref`;
CREATE TABLE `HaplotypeCrossref` (
  `HaplotypeCrossrefID` int(10) NOT NULL auto_increment,
  `HaplotypeID` int(10) unsigned NOT NULL default '0',
  `CrossrefID` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`HaplotypeCrossrefID`),
  UNIQUE KEY `HaplotypeID` (`HaplotypeID`,`CrossrefID`),
  KEY `CrossrefID` (`CrossrefID`),
  CONSTRAINT `HaplotypeCrossref_ibfk_1` FOREIGN KEY (`HaplotypeID`) REFERENCES `Haplotype` (`HaplotypeID`),
  CONSTRAINT `HaplotypeCrossref_ibfk_2` FOREIGN KEY (`CrossrefID`) REFERENCES `Crossref` (`CrossrefID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `Hotlink`
--

DROP TABLE IF EXISTS `Hotlink`;
CREATE TABLE `Hotlink` (
  `HotlinkID` int(10) unsigned NOT NULL auto_increment,
  `HotlinkLabel` varchar(100) NOT NULL COMMENT 'Indicate where the URL is pointing, e.g. "dbSNP refSNP report"',
  `UrlPrefix` varchar(300) NOT NULL,
  `UrlSuffix` varchar(100) default NULL,
  PRIMARY KEY  (`HotlinkID`),
  UNIQUE KEY `HotlinkLabel` (`HotlinkLabel`)
) ENGINE=InnoDB AUTO_INCREMENT=146 DEFAULT CHARSET=latin1;

--
-- Table structure for table `Marker`
--

DROP TABLE IF EXISTS `Marker`;
CREATE TABLE `Marker` (
  `MarkerID` int(10) unsigned NOT NULL auto_increment,
  `Identifier` varchar(15) default NULL,
  `Accession` varchar(15) default NULL,
  `AccessionVersion` varchar(10) default NULL,
  `DataSourceID` int(4) unsigned default NULL,
  `Status` varchar(20) NOT NULL default 'active' COMMENT 'Indicates whether the marker is active, dead or withheld or other',
  `VariationType` varchar(30) NOT NULL COMMENT 'SO term for the type of the marker feature',
  `HotlinkID` int(10) unsigned default NULL,
  `Upstream30bp` varchar(30) NOT NULL,
  `AlleleSeqs` text COMMENT 'shorthand-string with active alleleseqs from the Allele table',
  `Downstream30bp` varchar(30) NOT NULL,
  `ValidationCode` text,
  `AddedFromSourceBuild` varchar(10) default NULL COMMENT 'Label of source database build (or nickname) from where we first got the marker. Example: ''b128'' for dbSNP.',
  `TimeLastTouched` timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (`MarkerID`),
  UNIQUE KEY `Identifier` (`Identifier`),
  UNIQUE KEY `Accession` (`Accession`,`DataSourceID`),
  KEY `VariationType` (`VariationType`),
  KEY `HotlinkID` (`HotlinkID`),
  KEY `TimeLastTouched` (`TimeLastTouched`),
  KEY `DataSourceID` (`DataSourceID`),
  CONSTRAINT `Marker_ibfk_1` FOREIGN KEY (`DataSourceID`) REFERENCES `DataSource` (`DataSourceID`),
  CONSTRAINT `Marker_ibfk_2` FOREIGN KEY (`HotlinkID`) REFERENCES `Hotlink` (`HotlinkID`)
) ENGINE=InnoDB AUTO_INCREMENT=22373703 DEFAULT CHARSET=latin1;

--
-- Table structure for table `MarkerAlias`
--

DROP TABLE IF EXISTS `MarkerAlias`;
CREATE TABLE `MarkerAlias` (
  `MarkerAliasID` int(10) unsigned NOT NULL auto_increment,
  `MarkerID` int(10) unsigned NOT NULL,
  `Alias` varchar(50) NOT NULL COMMENT 'One of possibly several external aliases for the marker, e.g. D3S2404 for a microsatellite',
  `IsPrimary` tinyint(1) unsigned default NULL,
  PRIMARY KEY  (`MarkerAliasID`),
  UNIQUE KEY `MarkerID` (`MarkerID`,`IsPrimary`),
  KEY `Alias` (`Alias`),
  CONSTRAINT `MarkerAlias_ibfk_1` FOREIGN KEY (`MarkerID`) REFERENCES `Marker` (`MarkerID`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COMMENT='For looking up by an external alias for a marker (e.g. D3S24';

--
-- Table structure for table `MarkerCoord`
--

DROP TABLE IF EXISTS `MarkerCoord`;
CREATE TABLE `MarkerCoord` (
  `MarkerCoordID` int(10) unsigned NOT NULL auto_increment,
  `MarkerID` int(10) unsigned NOT NULL default '0',
  `Chr` varchar(20) NOT NULL COMMENT 'Chromosome that marker maps to. ''MT'' for mitochondrial genome, ''Un'' if unplaced on chromosome',
  `Start` int(10) unsigned default NULL,
  `Stop` int(10) unsigned default NULL,
  `Span` varchar(10) default NULL,
  `Strand` smallint(1) NOT NULL default '0' COMMENT 'Strand orientation relative to the reference sequence: +1 for forward strand, -1 for reverse strand and 0 if not applicable or unknown',
  `MapWeight` varchar(20) default NULL,
  `GenomeBuild` varchar(5) NOT NULL default '',
  `AssemblyType` varchar(30) NOT NULL,
  `AssemblyName` varchar(30) NOT NULL,
  PRIMARY KEY  (`MarkerCoordID`),
  KEY `MarkerID` (`MarkerID`),
  KEY `Chr_2` (`Chr`,`Start`,`Stop`),
  CONSTRAINT `MarkerCoord_ibfk_1` FOREIGN KEY (`MarkerID`) REFERENCES `Marker` (`MarkerID`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=59204838 DEFAULT CHARSET=latin1 COMMENT='Markers only represented in this table if mapping data exist';

--
-- Table structure for table `MarkerCrossref`
--

DROP TABLE IF EXISTS `MarkerCrossref`;
CREATE TABLE `MarkerCrossref` (
  `MarkerCrossrefID` int(10) unsigned NOT NULL auto_increment,
  `MarkerID` int(10) unsigned NOT NULL default '0',
  `CrossrefID` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`MarkerCrossrefID`),
  UNIQUE KEY `MarkerID` (`MarkerID`,`CrossrefID`),
  KEY `CrossrefID` (`CrossrefID`),
  CONSTRAINT `MarkerCrossref_ibfk_3` FOREIGN KEY (`MarkerID`) REFERENCES `Marker` (`MarkerID`) ON DELETE CASCADE,
  CONSTRAINT `MarkerCrossref_ibfk_4` FOREIGN KEY (`CrossrefID`) REFERENCES `Crossref` (`CrossrefID`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `MarkerRevision`
--

DROP TABLE IF EXISTS `MarkerRevision`;
CREATE TABLE `MarkerRevision` (
  `MarkerRevisionID` int(10) unsigned NOT NULL auto_increment,
  `MarkerID` int(10) unsigned NOT NULL,
  `ReplacedByMarkerID` int(10) unsigned default NULL COMMENT 'Pointer to marker that replaced this one, if applicable.',
  `StrandFlipped` varchar(5) default NULL COMMENT 'Boolean flag to indicate whether the revision resulted in a strand-flip of flanks (and alleles). Mainly happens when one rs# is merged into another rs# in dbSNP',
  `ChangeType` varchar(100) NOT NULL COMMENT 'Change type category (e.g. Deletion, Merging and so on). Can be Unknown if it is something not seen before',
  `ChangeTrigger` varchar(100) NOT NULL COMMENT 'What triggered this particular change. Usually the processing of a particular db-build, but can be something else',
  `TimeCreated` timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  `Comment` varchar(250) default NULL,
  PRIMARY KEY  (`MarkerRevisionID`),
  UNIQUE KEY `MarkerID` (`MarkerID`,`ReplacedByMarkerID`),
  KEY `ReplacedByMarkerID` (`ReplacedByMarkerID`),
  CONSTRAINT `MarkerRevision_ibfk_3` FOREIGN KEY (`MarkerID`) REFERENCES `Marker` (`MarkerID`) ON DELETE CASCADE,
  CONSTRAINT `MarkerRevision_ibfk_4` FOREIGN KEY (`ReplacedByMarkerID`) REFERENCES `Marker` (`MarkerID`)
) ENGINE=InnoDB AUTO_INCREMENT=2798745 DEFAULT CHARSET=latin1 COMMENT='Tracks marker revision history';
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2009-06-18 13:34:23
