/*
 * Citation.java
 *
 * Created on den 8 mars 2005, 15:53
 */

package phenobase.data;

import java.io.*;
import phenobase.storage.*;

/**
 * Class for representing citation data for use with HGVbaseG2P database and applications.
 *
 * @author fresjo
 */
public class Citation implements DataElement {
    
    public static int COUNT;
    
    private String citationDetail;
    private int pubMedID;
    private DataArray authors;
    private DataArray meshTerms;
    private String title;
    private int id;
     
    /** 
     * Creates a new instance of <code>Citation</code>. 
     */
    public Citation() {
        pubMedID = 0;
        title = "";
        citationDetail = "";
        authors = new DataArray();
        meshTerms = new DataArray();
        id = COUNT;
        COUNT = COUNT + 1;
    }
    
    public int getType() {
        return DataElement.CITATION;
    }
    
    public void setCitationDetail(String s) {
        citationDetail = s;
    }
    
    public String getCitationDetail() {
        return citationDetail;
    }
    
    public void setPubMedID(int i) {
        pubMedID = i;
    }
    
    public int getPubMedID() {
        return pubMedID;
    }
    
    public void addAuthor(String s) {
        authors.add(s);
    }
    
    public void setAuthors(DataArray d) {
        authors = d;
    }
    
    public Object[] getAuthors() {
        return authors.getArray();
    }
    
    public void addMeshTerm(String s) {
        meshTerms.add(s);
    }
    
    public void setMeshTerms(DataArray d) {
        meshTerms = d;
    }
    
    public Object[] getMeshTerms() {
        return meshTerms.getArray();
    }
    
    public void setTitle(String s) {
        title = s;
    }
    
    public String getTitle() {
        return title;
    }
    
    public int getID() {
        return id;
    }
    
    public void setID(int i) {
        id = i;
        //makes sure that no new created Citation gets the same id as an old one.
        if(COUNT <= id) {
            COUNT = id + 1;
        }
    }
      
    /**
     * Writes this <code>Citation</code> as XML on the given stream.
     *
     * @param out       the stream where the XML should be written out
     * @param offset    specifies the number of blank spaces that precedes the 
     *                  first line of the XML, to make the text easier to read.
     */
    public void writeXML(PrintStream out, int offset) {
        String os = "";
        for(int i = 0; i < offset; i++) {
            os = os + " ";
        }
        out.println(os + "<citation>");
        out.println(os + "<citationID>" + id + "</citationID>");
        out.println(os + "  <pubMedID>" + pubMedID + "</pubMedID>");
        out.println(os + "  <citationDetail>" + citationDetail + "</citationDetail>");
        out.println(os + "  <title>" + title + "</title>");
        for(int i = 0; i < authors.nrOfElements(); i++) {
            out.println(os + "  <author>" + authors.get(i) + "</author>");
        }
        for(int i = 0; i < meshTerms.nrOfElements(); i++) {
            out.println(os + "  <meshTerm>" + meshTerms.get(i) + "</meshTerm>");
        }
        out.println(os + "</citation>");
    }
        
    /**
     * Returns a <code>String</code> representation of this <code>Citation</code>.
     *
     * @return      the names followed by institution for this <code>Citation</code>.
     */
    public String toString() {
        String res = "";
        if(title.length() > 130) {
            res = title.substring(0,129) + " ...";
        }
        else {
            res = title;
        }
        return res;
    }
}