/*
 * Marker.java
 *
 * Created on den 3 juli 2006, 13:04
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package phenobase.data;

import java.io.*;
import phenobase.storage.*;

/**
 *
 * @author Fredrik
 */
public class Marker implements DataElement {
    
    public static int COUNT;
    
    private String markerID;
    private String rsID;
    private String validation;
    private String sequenceType;
    private DataArray alleles;
    private int connections;
    private int id;
    
    /** Creates a new instance of Marker */
    public Marker() {
        alleles = new DataArray();
        id = COUNT;
        COUNT++;
    }
    
    public Marker(int i) {
        alleles = new DataArray();
        id = i;
    }
    
    public void setCount(int i) {
        COUNT = i;
    }
    
    public int getID() {
        return id;
    }
    
    public int getType() {
        return DataElement.MARKER;
    }
    
    public String getMarkerID() {
        return markerID;
    }
    
    public void setMarkerID(String s) {
        markerID = s;
    }
    
    public String getRsID() {
        return rsID;
    }
    
    
    public void setRsID(String s) {
        rsID = s;
    }
     
    public String getValidation() {
        return validation;
    }
    
    public void setValidation(String s) {
        validation = s;
    }
    
    public String getSequenceType() {
        return sequenceType;
    }
    
    public void setSequenceType(String s) {
        sequenceType = s;
    }
    
    public void addAllele(Allele a) {
        alleles.add(a);
    }
    
    public Object[] getAlleles() {
        return alleles.getArray();
    }
    
    public int getNrAlleles() {
        return alleles.nrOfElements();
    }
   
    //Fixa fr 3 alleles, funkar endast fr 3 nu!!!
    public Object[] getGenotypes() {
        DataArray genotypes = new DataArray();
        for(int i = 0; i < getNrAlleles(); i++) {
            for(int j = i; j < getNrAlleles(); j++) {
                if(i == j) {
                    genotypes.add(getUpstream5bp() + "[("+ alleles.get(i) + ")]" + getDownstream5bp());
                }
                else {
                    genotypes.add(getUpstream5bp() + "[("+ alleles.get(i) + ")+(" + alleles.get(j) + ")]" + getDownstream5bp());
                }
            }
        }
        return genotypes.getArray();
    }
    
    public Object[] getAlleleSequences() {
        DataArray seqs = new DataArray();
        for(int i = 0; i < getNrAlleles(); i++) {
            seqs.add(((Allele)alleles.get(i)).getAlleleSequence());
        }
        return seqs.getArray();
    }
    
    public boolean isConnected() {
        return (connections > 0);
    }
    
    public void addConnection() {
        connections++;
    }
    
    public void removeConnection() {
        connections--;
    }
    
    public void writeXML(PrintStream out, int offset) {
        String offsetString = "";
        for(int i = 0; i < offset; i++) {
            offsetString = offsetString + " ";
        }
        out.println(offsetString + "<marker>");
        out.println(offsetString + "  <rsID>" + rsID + "</rsID>");
        out.println(offsetString + "  <markerID>" + markerID + "</markerID>");
        out.println(offsetString + "  <validation>" + validation + "</validation>");
        out.println(offsetString + "  <sequenceType>" + sequenceType + "</sequenceType>");
        for(int i = 0; i < alleles.nrOfElements(); i++) {
                Allele a = (Allele)alleles.get(i);
                a.writeXML(out, offset + 2);
        }
        out.println(offsetString + "</marker>");
    }
    
    public String toString() {
        return rsID;
    }
    
    public String getUpstream5bp() {
        if(getNrAlleles() > 0) {
            Allele a = (Allele)alleles.get(0);
            String upstreamSeq = a.getUpstream30bp();
            return upstreamSeq.substring(25);
        }
        else {
            return null;
        }
    }
    
    public String getDownstream5bp() {
        if(getNrAlleles() > 0) {
            Allele a = (Allele)alleles.get(0);
            String downstreamSeq = a.getDownstream30bp();
            return downstreamSeq.substring(0,5);
        }
        else {
            return null;
        }
    }
 }
