/*
 * Assessment.java
 *
 * Created on den 4 mars 2005, 16:28
 */

package phenobase.data;

import java.io.*;
import java.util.List;
import java.util.ArrayList;
import phenobase.storage.*;

/**
 *
 * @author aligol
 */
public class PhenotypeMethod implements DataElement {
    
    public static int COUNT;
    
    private int id;
    private String resultType;
    private String sampleType;
    private String methodName;
    private String circumstance;
    private String details;
    private String timeInstant;
    private String timePeriod;
    private String phenotypeName;
    private DataArray keywords;
    private DataArray citations;
    
    
    /** Creates a new instance of Assessment */
    public PhenotypeMethod() {
        timeInstant = null;
        timePeriod = null;
        keywords = new DataArray();
        citations = new DataArray();
        id = COUNT;
        COUNT++;
    }
    
    public int getType() {
        return DataElement.PHENOTYPE_METHOD;
    }
    
    public int getID() {
        return id;
    }
    
    public void addCitation(Citation c) {
        citations.add(c);
    }
       
    public Object[] getCitationArray() {
        return citations.getArray();
    }
        
    public void addKeyword(String kw) {
        keywords.add(kw);
    }

    public Object[] getKeywordArray() {
        return keywords.getArray();
    }
     
    public void setResultType(String rt) {
        resultType = rt;
    }
    
    public void setSampleType(String st) { 
        sampleType = st;
    }
        
    public void setMethodName(String mn) {
        methodName = mn;
    }
    
    public void setCircumstance(String c) {
        circumstance = c;
    }
    
    public void setDetails(String d) {
        details = d;
    }
    
    public void setTimeInstant(String ti) throws PhenotypeMethodException {
        if(timePeriod == null) {
            timeInstant = ti;
        }
        else {
            throw new PhenotypeMethodException("Setting time instance when time period is already set is not allowed");
        }
    }
    
    public void setTimePeriod(String tp) throws PhenotypeMethodException {
        if(timeInstant == null) {
            timePeriod = tp;
        }
        else {
            throw new PhenotypeMethodException("Setting time period when time instance is already set is not allowed");
        }
    }
    
    public String getResultType() {
        return resultType;
    }
    
    public String getSampleType() {
        return sampleType;
    }
        
    public String getMethodName() {
        return methodName;
    }
    
    public String getCircumstance() {
        return circumstance;
    }
    
    public String getDetails() {
        return details;
    }
    
    public String getPhenotypeName() {
        return phenotypeName;
    }
    
    public void setPhenotypeName(String s) {
        phenotypeName = s;
    }
    
    public String getTimeInstant() {
        return timeInstant;
    }
    
    public String getTimePeriod() {
        return timePeriod;
    }
    
    public void writeXML(PrintStream out, int os) {
        String offset = "";
        for(int i = 0; i < os; i++) {
            offset = offset + " ";
        }
        out.println(offset + "<phenotypeMethod>");
        out.println(offset + "  <resultType>" + resultType + "</resultType>");
        out.println(offset + "  <sampleType>" + sampleType + "</sampleType>");
        out.println(offset + "  <methodName>" + methodName + "</methodName>");
        out.println(offset + "  <phenotype>" + phenotypeName + "</phenotype>");
        out.println(offset + "  <circumstance>" + circumstance + "</circumstance>");
        out.println(offset + "  <details>" + details + "</details>");
        if(timeInstant != null) {
            out.println(offset + "  <timeInstant>" + timeInstant + "</timeInstant>");
        }
        else if(timePeriod != null) {
            out.println(offset + "  <timePeriod>" + timePeriod + "</timePeriod>");
        }
        for(int i = 0; i < keywords.nrOfElements(); i++) {
            out.println(offset + "  <keyword>" + (String)keywords.get(i) + "</keyword>");
        }
        for(int i = 0; i < citations.nrOfElements(); i++) {
            Citation c = (Citation)citations.get(i);
            out.println(offset + "  <citation>" + c.getID() + "</citation>");
        }
        out.println(offset + "</phenotypeMethod>");
    }
    
    public String toString() {
        return "Method for " + phenotypeName;
    }
}
