/*
 * PhenotypeGeneral.java
 *
 * Created on den 14 februari 2006, 14:40
 */

package phenobase.data;

import phenobase.storage.*;
import java.io.*;

/**
 *
 * @author fresjo
 */
public class PhenotypeProperty implements DataElement {
        
    private static int COUNT = 0;
    
    private int id;    
    private String propertyName;
    private String comment;    
    private DataArray keywords;    
    private DataArray citations;    
    private DataArray anatomicScales;    
    private DataArray diseaseAreas;    
    private DataArray subphenotypes;
    
    public PhenotypeProperty() {
        propertyName = "";
        comment = "";
        keywords = new DataArray();
        citations = new DataArray();
        anatomicScales = new DataArray();
        diseaseAreas = new DataArray();
        subphenotypes = new DataArray();
        id = COUNT;
        COUNT++;
    }
    
    public int getID() {
        return id;
    }
    
    public void setPropertyName(String s) {
        propertyName = s;
    }
    
    public String getPropertyName() {
        return propertyName;
    }
    
    public void setComment(String s) {
        comment = s;
    }
    
    public String getComment() {
        return comment;
    }
    
    public void addKeyword(String s) {
        keywords.add(s);
    }
    
    public Object[] getKeywords() {
        return keywords.getArray();
    }
    
    public void addCitation(Citation c) {
        citations.add(c);
    }
    
    public Object[] getCitations() {
        return citations.getArray();
    }
    
    public void addAnatomicScale(String s) {
        anatomicScales.add(s);
    }
    
    public Object[] getAnatomicScales() {
        return anatomicScales.getArray();
    }
    
    public void addDiseaseArea(String s) {
        diseaseAreas.add(s);
    }
    
    public Object[] getDiseaseAreas() {
        return diseaseAreas.getArray();
    }
    
    public void addSubphenotype(String name) {
        subphenotypes.add(name);
    }
    
    public Object[] getSubphenotypes() {
        return subphenotypes.getArray();
    }
    
    public boolean isSubphenotype(PhenotypeProperty pp) {
        boolean res = false;
        for(int i = 0; i < subphenotypes.nrOfElements(); i++) {
            if(((PhenotypeProperty)subphenotypes.get(i)).getPropertyName().equals(pp.getPropertyName())) {
                res = true;
                break;
            }
        }
        return res;
    }
    
    public int getType() {
        return DataElement.PHENOTYPE_PROPERTY;
    }
    
    public String toString() {
        return propertyName;
    }
    
    public void writeXML(PrintStream out, int offset) {
        String os = "";
        for(int i = 0; i < offset; i++) {
            os = os + " ";
        }
        out.println(os + "<phenotypeProperty>");
        out.println(os + "  <propertyName>" + propertyName + "</propertyName>");
        out.println(os + "  <comment>" + comment + "</comment>");
        for(int i = 0; i < subphenotypes.nrOfElements(); i++) {
            out.println("  <subphenotypeID>" + (String)subphenotypes.get(i) + "</subphenotypeID>");
        }
        for(int i = 0; i < keywords.nrOfElements(); i++) {
            out.println(os + "  <keyword>" + keywords.get(i) + "</keyword>");
        }
        for(int i = 0; i < anatomicScales.nrOfElements(); i++) {
            out.println(os + "  <anatomicScale>" + anatomicScales.get(i) + "</anatomicScale>");
        }
        for(int i = 0; i < diseaseAreas.nrOfElements(); i++) {
            out.println(os + "  <diseaseArea>" + diseaseAreas.get(i) + "</diseaseArea>");
        }
        for(int i = 0; i < citations.nrOfElements(); i++) {
            Citation c = (Citation)citations.get(i);
            out.println(os + "  <citation>" + c.getID() + "</citation>");
        }
        out.println(os + "</phenotypeProperty>");
    }
}
