/*
 * Researcher.java
 *
 * Created on den 17 oktober 2005, 16:36
 */

package phenobase.data;

import java.io.*;

/**
 * Data Element for keeping track of Researcher data.
 *
 * @author Fredrik Sjholm
 */
public class Researcher implements DataElement {
    
    private static int COUNT;
    
    private String firstName;
    private String otherNames;
    private String lastName;
    private String department;
    private String institution;
    private String address;
    private String phone;
    private String fax;
    private String email;
    private String www;
    private int order;
    private boolean isCorrespondingAuthor;
    private boolean isAuthor;
    private int id;
    
    /** 
     * Creates a new instance of Researcher 
     */
    public Researcher() {
    firstName = "";
    otherNames = "";
    lastName = "";
    department = "";
    institution = "";
    address = "";
    phone = "";
    fax = "";
    email = "";
    www = "";
    order = 0;
    id = COUNT;
    isCorrespondingAuthor = false;
    isAuthor = false;
    COUNT++;
    }
    
    public String getFirstName() {
        return firstName;
    }
    
    public void setFirstName(String s) {
        firstName = s;
    }
    
    public String getOtherNames() {
        return otherNames;
    }
    
    public void setOtherNames(String s) {
        otherNames = s;
    }
    
    public String getLastName() {
        return lastName;
    }
    
    public void setLastName(String s) {
        lastName = s;
    }
    
    public String getDepartment() {
        return department;
    }
    
    public void setDepartment(String s) {
        department = s;
    }
    
    public String getInstitution() {
        return institution;
    }
    
    public void setInstitution(String s) {
        institution = s;
    }
    
    public String getAddress() {
        return address;
    }
    
    public void setAddress(String s) {
        address = s;
    }
    
    public String getPhone() {
        return phone;
    }
    
    public void setPhone(String s) {
        phone = s;
    }
    
    public String getFax() {
        return fax;
    }
    
    public void setFax(String s) {
        fax = s;
    }
    
    public String getEmail() {
        return email;
    }
    
    public void setEmail(String s) {
        email = s;
    }
    
    public String getWWW() {
        return www;
    }
    
    public void setWWW(String s) {
        www = s;
    }
    
    public void setIsCorrespondingAuthor(boolean b) {
        isCorrespondingAuthor = b;
    }
    
    public boolean getIsCorrespondingAuthor() {
        return isCorrespondingAuthor;
    }
    
    public void setIsAuthor(boolean b) {
        isAuthor = b;
    }
    
    public boolean getIsAuthor() {
        return isAuthor;
    }
    
    public int getOrder() {
        return order;
    }
    
    public void increaseOrder() {
        order++;
    }
    
    public int getID() {
        return id;
    }
    
    /**
     * Returns a <code>String</code> representation of this <code>Researcher</code>.
     *
     * @return      the names followed by institution for this <code>Researcher</code>.
     */
    public String toString() {
        String res = "";
        if(order > 0) {
            res = res + "[" + order + "] ";
        }
        res = res + firstName + " " + lastName + " (" + institution + ")";
        if(isCorrespondingAuthor) {
            res = res + "[Corresponding Author]";
        }
        else {
            res = res + "[Author]";
        }
        return res;
    }

    public int getType() {
        return DataElement.RESEARCHER;
    }
    
    /**
     * Compares the fist names and institutions of this <code>Researcher</code> with 
     * another to determine if they are the same or not.
     * 
     * @param r     the <code>Researcher</code> being compared with this one.
     *
     * @return      <code>true</code> if they are the same, <code>false</code> otherwise.
     */
    public boolean equals(Researcher r) {
        return (r.getFirstName().equals(firstName) && r.getLastName().equals(lastName) && r.getInstitution().equals(institution));
    }
    
    /**
     * Writes this <code>Researcher</code> as XML on the given stream.
     *
     * @param out       the stream where the XML should be written out
     * @param offset    specifies the number of blank spaces that precedes the 
     *                  first line of the XML, to make the text easier to read.
     */
    public void writeXML(PrintStream out, int offset) {
        String os = "";
        for(int i = 0; i < offset; i++) {
            os = os + " ";
        }
        out.println(os + "<researcher>");
        out.println(os + "  <isAuthor>" + isAuthor + "</isAuthor>");
        out.println(os + "  <isCorrespondingAuthor>" + isCorrespondingAuthor + "</isCorrespondingAuthor>");
        out.println(os + "  <firstName>" + firstName + "</firstName>");
        out.println(os + "  <lastName>" + lastName + "</lastName>");
        out.println(os + "  <otherNames>" + otherNames + "</otherNames>");
        out.println(os + "  <department>" + department + "</department>");
        out.println(os + "  <institution>" + institution + "</institution>");
        out.println(os + "  <address>" + address + "</address>");
        out.println(os + "  <phone>" + phone + "</phone>");
        out.println(os + "  <fax>" + fax + "</fax>");
        out.println(os + "  <email>" + email + "</email>");
        out.println(os + "  <www>" + www + "</www>");
        out.println(os + "</researcher>");
    }
}
