/*
 * Phenobase.java
 *
 * Created on den 19 april 2005, 13:44
 */

package phenobase.data;

import phenobase.storage.*;

import java.io.*;
import java.util.*;

/**
 *
 * @author fresjo
 */
public class Study extends Observable implements DataElement {
    
    public static int COUNT;
    
    private DataArray researchers;
    private DataArray citations;
    private DataArray samplepanels;
    private DataArray phenotypeProperties;
    private DataArray phenotypeMethods;
    private DataArray assayedpanels;
    private DataArray phenotypeValues;
    private DataArray markers;
    private DataArray oligos;
    private DataArray assays;
    private DataArray experiments;
    private DataArray genotypeFrequencyClusters;
    private DataArray genotypeSignificances;
    private DataArray alleleFrequencyClusters;
    private DataArray alleleSignificances;
    private int id;
    
    /** Creates a new instance of Phenobase */
    public Study() {
        researchers = new DataArray();
        citations = new DataArray();
        samplepanels = new DataArray();
        phenotypeProperties = new DataArray();
        phenotypeMethods = new DataArray();
        assayedpanels = new DataArray();
        phenotypeValues = new DataArray();
        markers = new DataArray();
        oligos = new DataArray();
        assays = new DataArray();
        experiments = new DataArray();
        genotypeFrequencyClusters = new DataArray();
        genotypeSignificances = new DataArray();
        alleleFrequencyClusters = new DataArray();
        alleleSignificances = new DataArray();
        id = COUNT;
        COUNT++;
    }
        
    public int getType() {
        return DataElement.SUBMISSION;
    }
    
    public int getID() {
        return id;
    }

    public void addResearcher(Researcher r) {
        for(int i = 0; i < researchers.nrOfElements(); i++) {
            if(r.equals((Researcher)researchers.get(i))) {
                r.increaseOrder();
            }
        }
        researchers.add(r);
        signalChange();
    }
    
    public void updateResearcher(Researcher r, int id) {
        try {
            for(int i = 0; i < researchers.nrOfElements(); i++) {
                Researcher tmp = (Researcher)researchers.get(i);
                if(tmp.getID() == id) {
                    researchers.replace(r, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getResearcherArray() {
        return researchers.getArray();
    }
    
    public void deleteResearcher(int id) {
        try {
            for(int i = 0; i < researchers.nrOfElements(); i++) {
                Researcher tmp = (Researcher)researchers.get(i);
                if(tmp.getID() == id) {
                    researchers.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public void addCitation(Citation c) {
        citations.add(c);
        signalChange();
    }
    
    public void updateCitation(Citation c, int id) {
        try {
            for(int i = 0; i < citations.nrOfElements(); i++) {
                Citation tmp = (Citation)citations.get(i);
                if(tmp.getID() == id) {
                    citations.replace(c, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getCitationArray() {
        return citations.getArray();
    }
    
    public void deleteCitation(int id) {
        try {
            for(int i = 0; i < citations.nrOfElements(); i++) {
                Citation tmp = (Citation)citations.get(i);
                if(tmp.getID() == id) {
                    citations.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Citation getCitationWithID(int id) {
        Citation c = null;
        for(int i = 0; i < citations.nrOfElements(); i++) {
            if(((Citation)citations.get(i)).getID() == id) {
                c = (Citation)citations.get(i);
            }
        }
        return c;
    } 

    public void addPhenotypeProperty(PhenotypeProperty pp) {
        phenotypeProperties.add(pp);
        signalChange();
    }
    
    public void updatePhenotypeProperty(PhenotypeProperty pp, int id) {
        try {
            for(int i = 0; i < phenotypeProperties.nrOfElements(); i++) {
                PhenotypeProperty tmp = (PhenotypeProperty)phenotypeProperties.get(i);
                if(tmp.getID() == id) {
                    phenotypeProperties.replace(pp, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getPhenotypePropertyArray() {
        return phenotypeProperties.getArray();
    }
    
    public String[] getPhenotypePropertyNames() {
        String[] names = new String[phenotypeProperties.nrOfElements()];
        for(int i = 0; i < phenotypeProperties.nrOfElements(); i++) {
            names[i] = ((PhenotypeProperty)phenotypeProperties.get(i)).getPropertyName();
        }
        return names;
    }
    
    public String[] getPossibleSubphenotypeNames(PhenotypeProperty pp) {
        DataArray names = new DataArray();
        for(int i = 0; i < phenotypeProperties.nrOfElements(); i++) {
            PhenotypeProperty tmp = (PhenotypeProperty)phenotypeProperties.get(i);
            if(!tmp.getPropertyName().equals(pp.getPropertyName()) && !pp.isSubphenotype(tmp)) {
                names.add(tmp.getPropertyName());
            }
        }
        String[] possibleNames = new String[names.nrOfElements()];
        for(int j = 0; j < names.nrOfElements(); j++) {
            possibleNames[j] = (String)names.get(j);
        }
        return possibleNames;
    }
    
    public void deletePhenotypeProperty(int id) {
        try {
            for(int i = 0; i < phenotypeProperties.nrOfElements(); i++) {
                PhenotypeProperty tmp = (PhenotypeProperty)phenotypeProperties.get(i);
                if(tmp.getID() == id) {
                    phenotypeProperties.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public boolean isAddedProperty(String name) {
        boolean res = false;
        for(int i = 0; i < phenotypeProperties.nrOfElements(); i++) {
            if(((PhenotypeProperty)phenotypeProperties.get(i)).getPropertyName().equals(name)) {
                res = true;
                break;
            }
        }
        return res;
    }

    public void addPhenotypeMethod(PhenotypeMethod pm) {
        phenotypeMethods.add(pm);
        signalChange();
    }
    
    public void updatePhenotypeMethod(PhenotypeMethod pm, int id) {
        try {
            for(int i = 0; i < phenotypeMethods.nrOfElements(); i++) {
                PhenotypeMethod tmp = (PhenotypeMethod)phenotypeMethods.get(i);
                if(tmp.getID() == id) {
                    phenotypeMethods.replace(pm, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getPhenotypeMethodArray() {
        return phenotypeMethods.getArray();
    }
       
    public String[] getMethodNames() {
        String[] names = new String[phenotypeMethods.nrOfElements()];
        for(int i = 0; i < phenotypeMethods.nrOfElements(); i++) {
            names[i] = ((PhenotypeMethod)phenotypeMethods.get(i)).getMethodName();
        }
        return names;
    }
    
    public void deletePhenotypeMethod(int id) {
        try {
            for(int i = 0; i < phenotypeMethods.nrOfElements(); i++) {
                PhenotypeMethod tmp = (PhenotypeMethod)phenotypeMethods.get(i);
                if(tmp.getID() == id) {
                    phenotypeMethods.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }

    
    public void addSamplepanel(Samplepanel s) {
        samplepanels.add(s);
        signalChange();
    }
    
    public void updateSamplepanel(Samplepanel s, int id) {
        try {
            for(int i = 0; i < samplepanels.nrOfElements(); i++) {
                Samplepanel tmp = (Samplepanel)samplepanels.get(i);
                if(tmp.getID() == id) {
                    samplepanels.replace(s, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getSamplepanelArray() {
        return samplepanels.getArray();
    }
    
    public String[] getSamplepanelNames() {
        String[] names = new String[samplepanels.nrOfElements()];
        for(int i = 0; i < samplepanels.nrOfElements(); i++) {
            names[i] = ((Samplepanel)samplepanels.get(i)).getLabID();
        }
        return names;
    }

    public void deleteSamplepanel(int id) {
        try {
            for(int i = 0; i < samplepanels.nrOfElements(); i++) {
                Samplepanel tmp = (Samplepanel)samplepanels.get(i);
                if(tmp.getID() == id) {
                    samplepanels.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }

    
    public void addAssayedpanel(Assayedpanel a) {
        assayedpanels.add(a);
        signalChange();
    }
    
    public void updateAssayedpanel(Assayedpanel a, int id) {
        try {
            for(int i = 0; i < assayedpanels.nrOfElements(); i++) {
                Assayedpanel tmp = (Assayedpanel)assayedpanels.get(i);
                if(tmp.getID() == id) {
                    assayedpanels.replace(a, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getAssayedpanelArray() {
        return assayedpanels.getArray();
    }

    public String[] getAssayedpanelNames() {
        String[] names = new String[assayedpanels.nrOfElements()];
        for(int i = 0; i < assayedpanels.nrOfElements(); i++) {
            names[i] = ((Assayedpanel)assayedpanels.get(i)).getLabID();
        }
        return names;
    }
    
    public void deleteAssayedpanel(int id) {
        try {
            for(int i = 0; i < assayedpanels.nrOfElements(); i++) {
                Assayedpanel tmp = (Assayedpanel)assayedpanels.get(i);
                if(tmp.getID() == id) {
                    assayedpanels.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Assayedpanel getAssayedpanelWithID(int id) {
        Assayedpanel a = null;
        for(int i = 0; i < assayedpanels.nrOfElements(); i++) {
            if(((Assayedpanel)assayedpanels.get(i)).getID() == id) {
                a = (Assayedpanel)assayedpanels.get(i);
            }
        }
        return a;
    } 
    
    public void addPhenotypeValue(PhenotypeValue o) {
        phenotypeValues.add(o);
        signalChange();
    }
    
    public void updatePhenotypeValue(PhenotypeValue o, int id) {
        try {
            for(int i = 0; i < phenotypeValues.nrOfElements(); i++) {
                PhenotypeValue tmp = (PhenotypeValue)phenotypeValues.get(i);
                if(tmp.getID() == id) {
                    phenotypeValues.replace(o, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getPhenotypeValueArray() {
        return phenotypeValues.getArray();
    }
    
    public void deletePhenotypeValue(int id) {
        try {
            for(int i = 0; i < phenotypeValues.nrOfElements(); i++) {
                PhenotypeValue tmp = (PhenotypeValue)phenotypeValues.get(i);
                if(tmp.getID() == id) {
                    phenotypeValues.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public void addMarker(Marker m) {
        markers.add(m);
        signalChange();
    }
    
    public void updateMarker(Marker m, int id) {
        try {
            for(int i = 0; i < markers.nrOfElements(); i++) {
                Marker tmp = (Marker)markers.get(i);
                if(tmp.getID() == id) {
                    markers.replace(m, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getMarkerArray() {
        return markers.getArray();
    }
    
    public void deleteMarker(int id) {
        try {
            for(int i = 0; i < markers.nrOfElements(); i++) {
                Marker tmp = (Marker)markers.get(i);
                if(tmp.getID() == id) {
                    markers.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Marker getMarkerWithID(int id) {
        Marker m = null;
        for(int i = 0; i < markers.nrOfElements(); i++) {
            if(((Marker)markers.get(i)).getID() == id) {
                m = (Marker)markers.get(i);
            }
        }
        return m;
    }
    
    public boolean isAddedMarker(String rsID) {
        boolean res = false;
        for(int i = 0; i < markers.nrOfElements(); i++) {
            if(((Marker)markers.get(i)).getRsID().equals(rsID)) {
                res = true;
                break;
            }
        }
        return res;
    }

    public void addOligo(Oligo o) {
        oligos.add(o);
        signalChange();
    }
    
    public void updateOligo(Oligo o, int id) {
        try {
            for(int i = 0; i < oligos.nrOfElements(); i++) {
                Oligo tmp = (Oligo)oligos.get(i);
                if(tmp.getID() == id) {
                    oligos.replace(o, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getOligoArray() {
        return oligos.getArray();
    }
    
    public void deleteOligo(int id) {
        try {
            for(int i = 0; i < oligos.nrOfElements(); i++) {
                Oligo tmp = (Oligo)oligos.get(i);
                if(tmp.getID() == id) {
                    oligos.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Oligo getOligoWithID(int id) {
        Oligo o = null;
        for(int i = 0; i < oligos.nrOfElements(); i++) {
            if(((Oligo)oligos.get(i)).getID() == id) {
                o = (Oligo)oligos.get(i);
            }
        }
        return o;
    } 
    
    public boolean isAddedOligo(String name) {
        boolean res = false;
        for(int i = 0; i < oligos.nrOfElements(); i++) {
            if(((Oligo)oligos.get(i)).getName().equals(name)) {
                res = true;
                break;
            }
        }
        return res;
    }
    
    public void addAssay(Assay a) {
        assays.add(a);
        signalChange();
    }
    
    public void updateAssay(Assay a, int id) {
        try {
            for(int i = 0; i < assays.nrOfElements(); i++) {
                Assay tmp = (Assay)assays.get(i);
                if(tmp.getID() == id) {
                    assays.replace(a, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getAssayArray() {
        return assays.getArray();
    }
    
    public void deleteAssay(int id) {
        try {
            for(int i = 0; i < assays.nrOfElements(); i++) {
                Assay tmp = (Assay)assays.get(i);
                if(tmp.getID() == id) {
                    assays.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public void addExperiment(Experiment e) {
        experiments.add(e);
        signalChange();
    }
    
    public void updateExperiment(Experiment e, int id) {
        try {
            for(int i = 0; i < experiments.nrOfElements(); i++) {
                Experiment tmp = (Experiment)experiments.get(i);
                if(tmp.getID() == id) {
                    experiments.replace(e, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getExperimentArray() {
        return experiments.getArray();
    }
    
    public void deleteExperiment(int id) {
        try {
            for(int i = 0; i < experiments.nrOfElements(); i++) {
                Experiment tmp = (Experiment)experiments.get(i);
                if(tmp.getID() == id) {
                    experiments.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public void addGenotypeFrequencyCluster(GenotypeFrequencyCluster gfc) {
        genotypeFrequencyClusters.add(gfc);
        signalChange();
    }
    
    public void updateGenotypeFrequencyCluster(GenotypeFrequencyCluster gfc, int id) {
        try {
            for(int i = 0; i < genotypeFrequencyClusters.nrOfElements(); i++) {
                GenotypeFrequencyCluster tmp = (GenotypeFrequencyCluster)genotypeFrequencyClusters.get(i);
                if(tmp.getID() == id) {
                    genotypeFrequencyClusters.replace(gfc, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getGenotypeFrequencyClusterArray() {
        return genotypeFrequencyClusters.getArray();
    }
    
    public void deleteGenotypeFrequencyCluster(int id) {
        try {
            for(int i = 0; i < genotypeFrequencyClusters.nrOfElements(); i++) {
                GenotypeFrequencyCluster tmp = (GenotypeFrequencyCluster)genotypeFrequencyClusters.get(i);
                if(tmp.getID() == id) {
                    genotypeFrequencyClusters.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public GenotypeFrequencyCluster getGenotypeFrequencyClusterWithID(int id) {
        GenotypeFrequencyCluster gfc = null;
        for(int i = 0; i < genotypeFrequencyClusters.nrOfElements(); i++) {
            if(((GenotypeFrequencyCluster)genotypeFrequencyClusters.get(i)).getID() == id) {
                gfc = (GenotypeFrequencyCluster)genotypeFrequencyClusters.get(i);
            }
        }
        return gfc;
    }
    
    public void addGenotypeSignificance(GenotypeSignificance gs) {
        genotypeSignificances.add(gs);
        signalChange();
    }
    
    public void updateGenotypeSignificance(GenotypeSignificance gs, int id) {
        try {
            for(int i = 0; i < genotypeSignificances.nrOfElements(); i++) {
                GenotypeSignificance tmp = (GenotypeSignificance)genotypeSignificances.get(i);
                if(tmp.getID() == id) {
                    genotypeSignificances.replace(gs, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getGenotypeSignificanceArray() {
        return genotypeSignificances.getArray();
    }
    
    public void deleteGenotypeSignificance(int id) {
        try {
            for(int i = 0; i < genotypeSignificances.nrOfElements(); i++) {
                GenotypeSignificance tmp = (GenotypeSignificance)genotypeSignificances.get(i);
                if(tmp.getID() == id) {
                    genotypeSignificances.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public GenotypeSignificance getGenotypeSignificanceWithID(int id) {
        GenotypeSignificance gs = null;
        for(int i = 0; i < genotypeSignificances.nrOfElements(); i++) {
            if(((GenotypeSignificance)genotypeSignificances.get(i)).getID() == id) {
                gs = (GenotypeSignificance)genotypeSignificances.get(i);
            }
        }
        return gs;
    }
    
    public void addAlleleFrequencyCluster(AlleleFrequencyCluster afc) {
        alleleFrequencyClusters.add(afc);
        signalChange();
    }
    
    public void updateAlleleFrequencyCluster(AlleleFrequencyCluster afc, int id) {
        try {
            for(int i = 0; i < alleleFrequencyClusters.nrOfElements(); i++) {
                AlleleFrequencyCluster tmp = (AlleleFrequencyCluster)alleleFrequencyClusters.get(i);
                if(tmp.getID() == id) {
                    alleleFrequencyClusters.replace(afc, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getAlleleFrequencyClusterArray() {
        return alleleFrequencyClusters.getArray();
    }
    
    public void deleteAlleleFrequencyCluster(int id) {
        try {
            for(int i = 0; i < alleleFrequencyClusters.nrOfElements(); i++) {
                AlleleFrequencyCluster tmp = (AlleleFrequencyCluster)alleleFrequencyClusters.get(i);
                if(tmp.getID() == id) {
                    alleleFrequencyClusters.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public AlleleFrequencyCluster getAlleleFrequencyClusterWithID(int id) {
        AlleleFrequencyCluster afc = null;
        for(int i = 0; i < alleleFrequencyClusters.nrOfElements(); i++) {
            if(((AlleleFrequencyCluster)alleleFrequencyClusters.get(i)).getID() == id) {
                afc = (AlleleFrequencyCluster)alleleFrequencyClusters.get(i);
            }
        }
        return afc;
    }
    
    public void addAlleleSignificance(AlleleSignificance as) {
        alleleSignificances.add(as);
        signalChange();
    }
    
    public void updateAlleleSignificance(AlleleSignificance as, int id) {
        try {
            for(int i = 0; i < alleleSignificances.nrOfElements(); i++) {
                AlleleSignificance tmp = (AlleleSignificance)alleleSignificances.get(i);
                if(tmp.getID() == id) {
                    alleleSignificances.replace(as, i);
                    signalChange();
                }
            }
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public Object[] getAlleleSignificanceArray() {
        return alleleSignificances.getArray();
    }
    
    public void deleteAlleleSignificance(int id) {
        try {
            for(int i = 0; i < alleleSignificances.nrOfElements(); i++) {
                AlleleSignificance tmp = (AlleleSignificance)alleleSignificances.get(i);
                if(tmp.getID() == id) {
                    alleleSignificances.remove(i);
                }
            }
            signalChange();
        }
        catch(StorageException se) {
            System.err.println("StorageException: " + se.getMessage());
        }
    }
    
    public AlleleSignificance getAlleleSignificanceWithID(int id) {
        AlleleSignificance as = null;
        for(int i = 0; i < alleleSignificances.nrOfElements(); i++) {
            if(((AlleleSignificance)alleleSignificances.get(i)).getID() == id) {
                as = (AlleleSignificance)alleleSignificances.get(i);
            }
        }
        return as;
    }
    
    public void signalChange() {
        setChanged();
        notifyObservers();
    }
        
    public void writeXML(PrintStream out, int offset) {
        String os = "";
        for(int i = 0; i < offset; i++) {
                os = os + " ";
            }
        out.println(os + "<submission>");
        for(int i = 0; i < researchers.nrOfElements(); i++) {
            Researcher r = (Researcher)researchers.get(i);
            r.writeXML(out, offset + 2);
        }
        for(int i = 0; i < citations.nrOfElements(); i++) {
            Citation c = (Citation)citations.get(i);
            c.writeXML(out, offset + 2);
        }
        for(int i = 0; i < phenotypeProperties.nrOfElements(); i++) {
            PhenotypeProperty pg = (PhenotypeProperty)phenotypeProperties.get(i);
            pg.writeXML(out, offset + 2);
        }
        for(int i = 0; i < phenotypeMethods.nrOfElements(); i++) {
            PhenotypeMethod pm = (PhenotypeMethod)phenotypeMethods.get(i);
            pm.writeXML(out, offset + 2);
        }
        for(int i = 0; i < samplepanels.nrOfElements(); i++) {
            Samplepanel s = (Samplepanel)samplepanels.get(i);
            s.writeXML(out, offset + 2);
        }
        for(int i = 0; i < assayedpanels.nrOfElements(); i++) {
            Assayedpanel s = (Assayedpanel)assayedpanels.get(i);
            s.writeXML(out, offset + 2);
        }
        for(int i = 0; i < phenotypeValues.nrOfElements(); i++) {
            PhenotypeValue o = (PhenotypeValue)phenotypeValues.get(i);
            o.writeXML(out, offset + 2);
        }
        for(int i = 0; i < markers.nrOfElements(); i++) {
            Marker m = (Marker)markers.get(i);
            m.writeXML(out, offset + 2);
        }
        for(int i = 0; i < oligos.nrOfElements(); i++) {
            Oligo o = (Oligo)oligos.get(i);
            o.writeXML(out, offset + 2);
        }
        for(int i = 0; i < assays.nrOfElements(); i++) {
            Assay a = (Assay)assays.get(i);
            a.writeXML(out, offset + 2);
        }
        for(int i = 0; i < genotypeFrequencyClusters.nrOfElements(); i++) {
            GenotypeFrequencyCluster gfc = (GenotypeFrequencyCluster)genotypeFrequencyClusters.get(i);
            gfc.writeXML(out, offset + 2);
        }
        for(int i = 0; i < genotypeSignificances.nrOfElements(); i++) {
            GenotypeSignificance gfc = (GenotypeSignificance)genotypeSignificances.get(i);
            gfc.writeXML(out, offset + 2);
        }
        for(int i = 0; i < alleleFrequencyClusters.nrOfElements(); i++) {
            AlleleFrequencyCluster afc = (AlleleFrequencyCluster)alleleFrequencyClusters.get(i);
            afc.writeXML(out, offset + 2);
        }
        out.println(os + "</submission>");
    }
}