/*
 * AssayPanel.java
 *
 * Created on den 16 november 2005, 14:28
 */

package phenobase.gui;

import phenobase.data.*;
import javax.swing.*;
import java.util.*;

/**
 *
 * @author  fresjo
 */
public class AssayPanel extends javax.swing.JPanel implements Observer {
    
    /** Creates new form AssayPanel */
    public AssayPanel(HGVbaseSubmissionTool mf) {
        mainFrame = mf;
        mainFrame.getCurrentStudy().addObserver(this);
        initComponents();
    }
    
    public void update(Observable o, Object arg) {
        Study s = (Study)o;
        addedAssaysList.setListData(s.getAssayArray());
        validate();
        repaint();
    }
    
    public Study getCurrentSubmission() {
        return mainFrame.getCurrentStudy();
    }
    
    public void addMarker(Marker m) {
        ListModel lm = markerList.getModel();
        Marker[] markerArray = new Marker[lm.getSize() + 1];
        for(int i = 0; i < lm.getSize(); i++) {
            markerArray[i] = (Marker)lm.getElementAt(i);
        }
        markerArray[lm.getSize()] = m;
        markerList.setListData(markerArray);
        validate();
        repaint();
    }
    
    private void deleteMarker() {
        int selectedIndex = markerList.getSelectedIndex();
        if(selectedIndex != -1) {
            ListModel lm = markerList.getModel();
            Marker[] markerArray = new Marker[lm.getSize() - 1];
            int count = 0;
            for(int i = 0; i < lm.getSize(); i++) {
                Marker tmpMarker = (Marker)lm.getElementAt(i);
                if(i != selectedIndex) {
                    markerArray[count] = tmpMarker;
                    count++;
                }
            }
            markerList.setListData(markerArray);
            validate();
            repaint();
        }
        else {
            JOptionPane.showMessageDialog(this,
                "You have to select a marker to be able to delete it.",
                "Error",
                JOptionPane.ERROR_MESSAGE);
        }
    }
    
    public void addOligo(Oligo o) {
        ListModel lm = oligoList.getModel();
        Oligo[] oligoArray = new Oligo[lm.getSize() + 1];
        for(int i = 0; i < lm.getSize(); i++) {
            oligoArray[i] = (Oligo)lm.getElementAt(i);
        }
        oligoArray[lm.getSize()] = o;
        oligoList.setListData(oligoArray);
        validate();
        repaint();
    }
    
    private void deleteOligo() {
        int selectedIndex = oligoList.getSelectedIndex();
        if(selectedIndex != -1) {
            ListModel lm = oligoList.getModel();
            Oligo[] oligoArray = new Oligo[lm.getSize() - 1];
            int count = 0;
            for(int i = 0; i < lm.getSize(); i++) {
                Oligo tmpOligo = (Oligo)lm.getElementAt(i);
                if(i != selectedIndex) {
                    oligoArray[count] = tmpOligo;
                    count++;
                }
            }
            oligoList.setListData(oligoArray);
            validate();
            repaint();
        }
        else {
            JOptionPane.showMessageDialog(this,
                "You have to select a oligo to be able to delete it.",
                "Error",
                JOptionPane.ERROR_MESSAGE);
        }
    }
    
    private void clearForm() {
        addedAssaysList.clearSelection();
        labNameField.setText("");
        typeComboBox.setSelectedIndex(0);
        methodComboBox.setSelectedIndex(0);
        conditionsField.setText("");
        markerList.setListData(new String[0]);
        oligoList.setListData(new String[0]);
        validate();
        repaint();
    }
    
    private void fillForm(Assay a) {
        labNameField.setText(a.getName());
        conditionsField.setText(a.getConditions());
        typeComboBox.setSelectedItem(a.getType());
        methodComboBox.setSelectedItem(a.getMethod());        
        Object[] markers = a.getMarkers();
        markerList.setListData(markers);
        Object[] oligos = a.getOligos();
        oligoList.setListData(oligos);
        validate();
        repaint();
    }
    
    private void deleteAssay() {
        Assay a = (Assay)addedAssaysList.getSelectedValue();
        if(a == null) {
            JOptionPane.showMessageDialog(this,
                "You have to select an assay to be able to delete it.",
                "Error",
                JOptionPane.ERROR_MESSAGE);
        } else {
            int answer = JOptionPane.showConfirmDialog(this,
                    "Do you wish to permanently delete the selected assay from the submission?",
                    "Warning",
                    JOptionPane.WARNING_MESSAGE,
                    JOptionPane.YES_NO_OPTION);
            if(answer == JOptionPane.YES_OPTION) {
                mainFrame.getCurrentStudy().deleteAssay(a.getID());
                clearForm();    
            }
        }
    }
    
    public Marker[] getAddedMarkers() {
        ListModel lm = markerList.getModel();
        Marker[] markerArray = new Marker[lm.getSize()];
        for(int i = 0; i < lm.getSize(); i++) {
            markerArray[i] = (Marker)lm.getElementAt(i);
        }
        return markerArray;
    }
    
    public Oligo[] getAddedOligos() {
        ListModel lm = oligoList.getModel();
        Oligo[] oligoArray = new Oligo[lm.getSize()];
        for(int i = 0; i < lm.getSize(); i++) {
            oligoArray[i] = (Oligo)lm.getElementAt(i);
        }
        return oligoArray;
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        buttonPanel = new javax.swing.JPanel();
        buttons = new javax.swing.JPanel();
        clearButton = new javax.swing.JButton();
        deleteAssayButton = new javax.swing.JButton();
        addAssayButton = new javax.swing.JButton();
        assayPanel = new javax.swing.JPanel();
        jLabel2 = new javax.swing.JLabel();
        jLabel4 = new javax.swing.JLabel();
        labNameField = new javax.swing.JTextField();
        String[] types = {"SNP:singleplex", "SNP:multiplex", "Haplotype"};
        typeComboBox = new javax.swing.JComboBox(types);
        jLabel5 = new javax.swing.JLabel();
        jLabel3 = new javax.swing.JLabel();
        jLabel6 = new javax.swing.JLabel();
        String[] methods = {"ABI 5'-Nuclease", "Affymetrix 10k array", "Affymetrix 100k array", "Affymetrix 500k array", "Allele-Specific PCR", "Amplifluor", "APEX", "Beacons", "DASH-1", "DASH-2", "Fluorescence-Polarization SBE", "GOOD", "Illumina Golden-Gate", "Illumina Infineon", "Invader", "MassArray", "MassCode", "MassEXTEND", "MGB Eclipse", "Padlock probe", "PinPoint", "Pyrosequencing", "RFLP-PCR", "SBE on Colored beads", "Scorpion", "Sentrix-96", "SNaPshot", "SNP-IT", "SNPlex", "SNPstream"};
        methodComboBox = new javax.swing.JComboBox(methods);
        jLabel7 = new javax.swing.JLabel();
        commentLabel = new javax.swing.JLabel();
        jLabel9 = new javax.swing.JLabel();
        markersPanel = new javax.swing.JPanel();
        markerScrollPane = new javax.swing.JScrollPane();
        markerList = new javax.swing.JList();
        jLabel12 = new javax.swing.JLabel();
        markerButtonPanel = new javax.swing.JPanel();
        markerButtons = new javax.swing.JPanel();
        deleteMarkerButton = new javax.swing.JButton();
        addMarkerButton = new javax.swing.JButton();
        oligosPanel = new javax.swing.JPanel();
        oligoScrollPane = new javax.swing.JScrollPane();
        oligoList = new javax.swing.JList();
        jLabel14 = new javax.swing.JLabel();
        oligoButtonPanel = new javax.swing.JPanel();
        oligoButtons = new javax.swing.JPanel();
        deleteOligoButton = new javax.swing.JButton();
        addOligoButton = new javax.swing.JButton();
        jScrollPane1 = new javax.swing.JScrollPane();
        conditionsField = new javax.swing.JTextArea();
        jPanel1 = new javax.swing.JPanel();
        jScrollPane2 = new javax.swing.JScrollPane();
        jLabel1 = new javax.swing.JLabel();
        jButton1 = new javax.swing.JButton();
        addedAssaysPanel = new javax.swing.JPanel();
        addedAssaysScrollPane = new javax.swing.JScrollPane();
        addedAssaysList = new javax.swing.JList();
        jLabel16 = new javax.swing.JLabel();

        setLayout(new java.awt.BorderLayout());

        setBorder(javax.swing.BorderFactory.createTitledBorder("Assays: optionally, enter the Assays that were used to genotype the Markers in your study"));
        buttonPanel.setLayout(new java.awt.BorderLayout());

        clearButton.setText("Clear Form");
        clearButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                clearButtonActionPerformed(evt);
            }
        });

        buttons.add(clearButton);

        deleteAssayButton.setText("Delete Assay");
        deleteAssayButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteAssayButtonActionPerformed(evt);
            }
        });

        buttons.add(deleteAssayButton);

        addAssayButton.setText("Add new Assay");
        addAssayButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addAssayButtonActionPerformed(evt);
            }
        });

        buttons.add(addAssayButton);

        buttonPanel.add(buttons, java.awt.BorderLayout.EAST);

        add(buttonPanel, java.awt.BorderLayout.SOUTH);

        assayPanel.setLayout(new java.awt.GridBagLayout());

        assayPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Assay Detail"));
        jLabel2.setForeground(java.awt.SystemColor.textHighlight);
        jLabel2.setText("Name or ID");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        assayPanel.add(jLabel2, gridBagConstraints);

        jLabel4.setForeground(java.awt.SystemColor.textHighlight);
        jLabel4.setText("Type");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        assayPanel.add(jLabel4, gridBagConstraints);

        labNameField.setBorder(javax.swing.BorderFactory.createLineBorder(java.awt.Color.blue, 2));
        labNameField.setPreferredSize(new java.awt.Dimension(300, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        assayPanel.add(labNameField, gridBagConstraints);

        typeComboBox.setPreferredSize(new java.awt.Dimension(300, 22));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        assayPanel.add(typeComboBox, gridBagConstraints);

        jLabel5.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel5.setForeground(new java.awt.Color(255, 51, 51));
        jLabel5.setText("Further details of how the assay was run");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 9;
        gridBagConstraints.gridwidth = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        assayPanel.add(jLabel5, gridBagConstraints);

        jLabel3.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel3.setForeground(new java.awt.Color(255, 51, 51));
        jLabel3.setText("Short, convenient, and unique name for the Assay");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        assayPanel.add(jLabel3, gridBagConstraints);

        jLabel6.setForeground(java.awt.SystemColor.textHighlight);
        jLabel6.setText("Method");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 4;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        assayPanel.add(jLabel6, gridBagConstraints);

        methodComboBox.setPreferredSize(new java.awt.Dimension(300, 22));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 4;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        assayPanel.add(methodComboBox, gridBagConstraints);

        jLabel7.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel7.setForeground(new java.awt.Color(255, 51, 51));
        jLabel7.setText("Assay chemistry and/or method. To enter a value not in the list, simply type it in the field");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 4;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        assayPanel.add(jLabel7, gridBagConstraints);

        commentLabel.setForeground(java.awt.SystemColor.textHighlight);
        commentLabel.setText("Conditions");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.gridwidth = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        assayPanel.add(commentLabel, gridBagConstraints);

        jLabel9.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel9.setForeground(new java.awt.Color(255, 51, 51));
        jLabel9.setText("Nature and plexity of the assay. To enter a value not in the list, simply type it in the field");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        assayPanel.add(jLabel9, gridBagConstraints);

        markersPanel.setLayout(new java.awt.GridBagLayout());

        markersPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Added Markers"));
        markerScrollPane.setPreferredSize(new java.awt.Dimension(420, 80));
        markerList.setBackground(new java.awt.Color(255, 255, 204));
        markerList.addKeyListener(new java.awt.event.KeyAdapter() {
            public void keyPressed(java.awt.event.KeyEvent evt) {
                markerListKeyPressed(evt);
            }
        });

        markerScrollPane.setViewportView(markerList);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        markersPanel.add(markerScrollPane, gridBagConstraints);

        jLabel12.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel12.setForeground(new java.awt.Color(255, 51, 51));
        jLabel12.setText("Markers scored by the selected Assay");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        markersPanel.add(jLabel12, gridBagConstraints);

        markerButtonPanel.setLayout(new java.awt.BorderLayout());

        deleteMarkerButton.setText("Delete Marker");
        deleteMarkerButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteMarkerButtonActionPerformed(evt);
            }
        });

        markerButtons.add(deleteMarkerButton);

        addMarkerButton.setText("Add Marker");
        addMarkerButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addMarkerButtonActionPerformed(evt);
            }
        });

        markerButtons.add(addMarkerButton);

        markerButtonPanel.add(markerButtons, java.awt.BorderLayout.EAST);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        markersPanel.add(markerButtonPanel, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 10;
        gridBagConstraints.gridwidth = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        assayPanel.add(markersPanel, gridBagConstraints);

        oligosPanel.setLayout(new java.awt.GridBagLayout());

        oligosPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Added Oligos"));
        oligoScrollPane.setPreferredSize(new java.awt.Dimension(420, 80));
        oligoList.setBackground(new java.awt.Color(255, 255, 204));
        oligoList.addKeyListener(new java.awt.event.KeyAdapter() {
            public void keyPressed(java.awt.event.KeyEvent evt) {
                oligoListKeyPressed(evt);
            }
        });

        oligoScrollPane.setViewportView(oligoList);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        oligosPanel.add(oligoScrollPane, gridBagConstraints);

        jLabel14.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel14.setForeground(new java.awt.Color(255, 51, 51));
        jLabel14.setText("Oligos used in the selected Assay");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        oligosPanel.add(jLabel14, gridBagConstraints);

        oligoButtonPanel.setLayout(new java.awt.BorderLayout());

        deleteOligoButton.setText("Delete Oligo");
        deleteOligoButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteOligoButtonActionPerformed(evt);
            }
        });

        oligoButtons.add(deleteOligoButton);

        addOligoButton.setText("Add Oligo");
        addOligoButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addOligoButtonActionPerformed(evt);
            }
        });

        oligoButtons.add(addOligoButton);

        oligoButtonPanel.add(oligoButtons, java.awt.BorderLayout.EAST);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        oligosPanel.add(oligoButtonPanel, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 3;
        gridBagConstraints.gridy = 10;
        gridBagConstraints.gridwidth = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        assayPanel.add(oligosPanel, gridBagConstraints);

        conditionsField.setColumns(20);
        conditionsField.setLineWrap(true);
        conditionsField.setRows(2);
        conditionsField.setWrapStyleWord(true);
        jScrollPane1.setViewportView(conditionsField);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 8;
        gridBagConstraints.gridwidth = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        assayPanel.add(jScrollPane1, gridBagConstraints);

        jPanel1.setLayout(new java.awt.GridBagLayout());

        jPanel1.setBorder(javax.swing.BorderFactory.createTitledBorder("Added Citations"));
        jScrollPane2.setPreferredSize(new java.awt.Dimension(380, 80));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        jPanel1.add(jScrollPane2, gridBagConstraints);

        jLabel1.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel1.setText("jLabel1");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        jPanel1.add(jLabel1, gridBagConstraints);

        jButton1.setText("jButton1");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1.add(jButton1, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridwidth = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        assayPanel.add(jPanel1, gridBagConstraints);

        add(assayPanel, java.awt.BorderLayout.CENTER);

        addedAssaysPanel.setLayout(new java.awt.GridBagLayout());

        addedAssaysPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Added Assays"));
        addedAssaysScrollPane.setPreferredSize(new java.awt.Dimension(810, 80));
        addedAssaysList.setBackground(new java.awt.Color(255, 255, 204));
        addedAssaysList.addKeyListener(new java.awt.event.KeyAdapter() {
            public void keyPressed(java.awt.event.KeyEvent evt) {
                addedAssaysListKeyPressed(evt);
            }
        });
        addedAssaysList.addListSelectionListener(new javax.swing.event.ListSelectionListener() {
            public void valueChanged(javax.swing.event.ListSelectionEvent evt) {
                addedAssaysListValueChanged(evt);
            }
        });

        addedAssaysScrollPane.setViewportView(addedAssaysList);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        addedAssaysPanel.add(addedAssaysScrollPane, gridBagConstraints);

        jLabel16.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel16.setForeground(new java.awt.Color(255, 51, 51));
        jLabel16.setText("Assays already entered (click entries to view and edit)");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        addedAssaysPanel.add(jLabel16, gridBagConstraints);

        add(addedAssaysPanel, java.awt.BorderLayout.NORTH);

    }// </editor-fold>//GEN-END:initComponents

    private void addAssayButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addAssayButtonActionPerformed
        Assay a = new Assay();
        a.setName(labNameField.getText());
        a.setMethodType((String)typeComboBox.getSelectedItem());
        a.setMethod((String)methodComboBox.getSelectedItem());
        a.setConditions(conditionsField.getText());
        Marker[] markers = getAddedMarkers();
        for(int i = 0; i < markers.length; i++) {
            a.addMarker(markers[i]);
        }
        Oligo[] oligos = getAddedOligos();
        for(int i = 0; i < oligos.length; i++) {
            a.addOligo(oligos[i]);
        }
        if(addedAssaysList.getSelectedValue() == null) {
            mainFrame.getCurrentStudy().addAssay(a);
            clearForm();
        }
        else {
            int answer = JOptionPane.showConfirmDialog(this,
                    "Do you wish to update the selected assay?",
                    "Warning",
                    JOptionPane.WARNING_MESSAGE,
                    JOptionPane.YES_NO_OPTION);
            if(answer == JOptionPane.YES_OPTION) {
                Assay selectedAssay = (Assay)addedAssaysList.getSelectedValue();
                int id = selectedAssay.getID();
                mainFrame.getCurrentStudy().updateAssay(a, id);
                clearForm();    
            }
        }
    }//GEN-LAST:event_addAssayButtonActionPerformed

    private void addedAssaysListValueChanged(javax.swing.event.ListSelectionEvent evt) {//GEN-FIRST:event_addedAssaysListValueChanged
        Assay a = (Assay)addedAssaysList.getSelectedValue();
        if(a != null) {
            fillForm(a);
        }
    }//GEN-LAST:event_addedAssaysListValueChanged

    private void addedAssaysListKeyPressed(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_addedAssaysListKeyPressed
        if(evt.getKeyCode() == java.awt.event.KeyEvent.VK_DELETE) {
            deleteAssay();
        }
    }//GEN-LAST:event_addedAssaysListKeyPressed

    private void deleteAssayButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteAssayButtonActionPerformed
        deleteAssay();
    }//GEN-LAST:event_deleteAssayButtonActionPerformed

    private void oligoListKeyPressed(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_oligoListKeyPressed
        if(evt.getKeyCode() == java.awt.event.KeyEvent.VK_DELETE) {
            deleteOligo();
        }
    }//GEN-LAST:event_oligoListKeyPressed

    private void deleteOligoButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteOligoButtonActionPerformed
        deleteOligo();
    }//GEN-LAST:event_deleteOligoButtonActionPerformed

    private void addOligoButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addOligoButtonActionPerformed
        OligosFrame of = new OligosFrame(this, (int)(getLocationOnScreen()).getX(), (int)(getLocationOnScreen()).getY());
    }//GEN-LAST:event_addOligoButtonActionPerformed

    private void markerListKeyPressed(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_markerListKeyPressed
        if(evt.getKeyCode() == java.awt.event.KeyEvent.VK_DELETE) {
            deleteMarker();
        }
    }//GEN-LAST:event_markerListKeyPressed

    private void deleteMarkerButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteMarkerButtonActionPerformed
        deleteMarker();
    }//GEN-LAST:event_deleteMarkerButtonActionPerformed

    private void addMarkerButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addMarkerButtonActionPerformed
        MarkersFrame mf = new MarkersFrame(this, (int)(getLocationOnScreen()).getX(), (int)(getLocationOnScreen()).getY());
    }//GEN-LAST:event_addMarkerButtonActionPerformed

    private void clearButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_clearButtonActionPerformed
        clearForm();
    }//GEN-LAST:event_clearButtonActionPerformed
    
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton addAssayButton;
    private javax.swing.JButton addMarkerButton;
    private javax.swing.JButton addOligoButton;
    private javax.swing.JList addedAssaysList;
    private javax.swing.JPanel addedAssaysPanel;
    private javax.swing.JScrollPane addedAssaysScrollPane;
    private javax.swing.JPanel assayPanel;
    private javax.swing.JPanel buttonPanel;
    private javax.swing.JPanel buttons;
    private javax.swing.JButton clearButton;
    private javax.swing.JLabel commentLabel;
    private javax.swing.JTextArea conditionsField;
    private javax.swing.JButton deleteAssayButton;
    private javax.swing.JButton deleteMarkerButton;
    private javax.swing.JButton deleteOligoButton;
    private javax.swing.JButton jButton1;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel12;
    private javax.swing.JLabel jLabel14;
    private javax.swing.JLabel jLabel16;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JScrollPane jScrollPane2;
    private javax.swing.JTextField labNameField;
    private javax.swing.JPanel markerButtonPanel;
    private javax.swing.JPanel markerButtons;
    private javax.swing.JList markerList;
    private javax.swing.JScrollPane markerScrollPane;
    private javax.swing.JPanel markersPanel;
    private javax.swing.JComboBox methodComboBox;
    private javax.swing.JPanel oligoButtonPanel;
    private javax.swing.JPanel oligoButtons;
    private javax.swing.JList oligoList;
    private javax.swing.JScrollPane oligoScrollPane;
    private javax.swing.JPanel oligosPanel;
    private javax.swing.JComboBox typeComboBox;
    // End of variables declaration//GEN-END:variables
    private HGVbaseSubmissionTool mainFrame;
    
}
