/*
 * GenotypeFrequencyPanel.java
 *
 * Created on den 15 december 2006, 17:15
 */

package phenobase.gui;

import java.util.*;
import phenobase.data.*;
import phenobase.handling.*;
import phenobase.storage.*;
import javax.swing.*;
import javax.swing.event.*;

/**
 *
 * @author  fredrik
 */
public class GenotypeFrequencyClusterPanel extends javax.swing.JPanel implements Observer {
    
    /** Creates new form GenotypeFrequencyPanel */
    public GenotypeFrequencyClusterPanel(HGVbaseSubmissionTool h) {
        mainFrame = h;
        mainFrame.getCurrentStudy().addObserver(this);
        initComponents();
    }
    
    public void update(Observable o, Object arg) {
        Study s = (Study)o;
        clusterList.setListData(s.getGenotypeFrequencyClusterArray());
        experimentComboBox.setModel(new javax.swing.DefaultComboBoxModel(s.getExperimentArray()));
        updateComboBoxes();
        updateGenotypeComboBox();
        validate();
        repaint();
    }
    
    public String getGenotypeType() {
        return (String)genotypeTypeComboBox.getSelectedItem();
    }
    
    public void clearForm() {
        clusterList.clearSelection();
        if(experimentComboBox.getItemCount() > 0) {
            experimentComboBox.setSelectedIndex(0);
        }
        if(assayedpanelComboBox.getItemCount() > 0) {
            assayedpanelComboBox.setSelectedIndex(0);
        }
        if(markerComboBox.getItemCount() > 0) {
            markerComboBox.setSelectedIndex(0);
        }
        nrGenotypedSamplesField.setText("");
        pValueHWEField.setText("");
        ((GenotypeFrequencyTableModel)frequencyTable.getModel()).removeAllGenotypeFrequencies();
        clearFrequencyForm();
    }
    
    public void clearFrequencyForm() {
        frequencyTable.clearSelection();
        genotypeTypeComboBox.setSelectedIndex(0);
        if(genotypeComboBox.getItemCount() > 0) {
            genotypeComboBox.setSelectedIndex(0);
        }
        frequencyField.setText("");
        countField.setText("");
    }

    public void fillForm(GenotypeFrequencyCluster gfc) {
        experimentComboBox.setSelectedItem(gfc.getExperiment());
        assayedpanelComboBox.setSelectedItem(gfc.getAssayedpanel());
        markerComboBox.setSelectedItem(gfc.getMarker());
        nrGenotypedSamplesField.setText("" + gfc.getNrGenotypedSamples());
        pValueHWEField.setText("" + gfc.getPValueHWE());
        Object[] genotypeFrequencies = gfc.getGenotypeComboArray();
        ((GenotypeFrequencyTableModel)frequencyTable.getModel()).setGenotypeFrequencies(genotypeFrequencies);
        validate();
        repaint();
    }
    
    public void fillFrequencyForm(GenotypeFrequency gf) {
        genotypeComboBox.setSelectedItem(gf.getGenotypeCombo());
        frequencyField.setText("" + gf.getFrequency());
        countField.setText("" + gf.getNrSamples());
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        addedClustersPanel = new javax.swing.JPanel();
        jLabel1 = new javax.swing.JLabel();
        clusterScrollPane = new javax.swing.JScrollPane();
        clusterList = new javax.swing.JList();
        jLabel2 = new javax.swing.JLabel();
        clusterPanel = new javax.swing.JPanel();
        frequencyPanel = new javax.swing.JPanel();
        frequencyButtonPanel = new javax.swing.JPanel();
        frequencyButtonPanelEast = new javax.swing.JPanel();
        clearFrequencyFormButton = new javax.swing.JButton();
        deleteFrequencyButton = new javax.swing.JButton();
        addModifyFrequencyButton = new javax.swing.JButton();
        jLabel10 = new javax.swing.JLabel();
        countField = new javax.swing.JTextField();
        jLabel9 = new javax.swing.JLabel();
        jLabel8 = new javax.swing.JLabel();
        frequencyField = new javax.swing.JTextField();
        jLabel7 = new javax.swing.JLabel();
        jLabel6 = new javax.swing.JLabel();
        genotypeComboBox = new javax.swing.JComboBox();
        jLabel5 = new javax.swing.JLabel();
        jLabel4 = new javax.swing.JLabel();
        frequencyScrollPane = new javax.swing.JScrollPane();
        frequencyTable = new javax.swing.JTable();
        jScrollPane1 = new javax.swing.JScrollPane();
        genotypeDetailTable = new javax.swing.JTable();
        jLabel19 = new javax.swing.JLabel();
        jLabel20 = new javax.swing.JLabel();
        jLabel21 = new javax.swing.JLabel();
        genotypeTypeComboBox = new javax.swing.JComboBox();
        jLabel22 = new javax.swing.JLabel();
        jPanel1 = new javax.swing.JPanel();
        constructGenotypeButton = new javax.swing.JButton();
        jLabel3 = new javax.swing.JLabel();
        assayedpanelComboBox = new javax.swing.JComboBox();
        jLabel11 = new javax.swing.JLabel();
        jLabel12 = new javax.swing.JLabel();
        markerComboBox = new javax.swing.JComboBox();
        jLabel13 = new javax.swing.JLabel();
        jLabel14 = new javax.swing.JLabel();
        jLabel15 = new javax.swing.JLabel();
        nrGenotypedSamplesField = new javax.swing.JTextField();
        jLabel16 = new javax.swing.JLabel();
        jLabel17 = new javax.swing.JLabel();
        pValueHWEField = new javax.swing.JTextField();
        jLabel18 = new javax.swing.JLabel();
        jLabel23 = new javax.swing.JLabel();
        experimentComboBox = new javax.swing.JComboBox();
        jLabel24 = new javax.swing.JLabel();
        buttonPanel = new javax.swing.JPanel();
        buttonPanelEast = new javax.swing.JPanel();
        clearButton = new javax.swing.JButton();
        deleteButton = new javax.swing.JButton();
        addModifyButton = new javax.swing.JButton();

        setLayout(new java.awt.BorderLayout());

        setBorder(javax.swing.BorderFactory.createTitledBorder("Genotype Frequency Clusters"));
        addedClustersPanel.setLayout(new java.awt.GridBagLayout());

        addedClustersPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Added Genotype Frequency Clusters"));
        jLabel1.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 10));
        jLabel1.setForeground(new java.awt.Color(102, 102, 255));
        jLabel1.setText("Genotype Frequency Clusters that has been added so far");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        addedClustersPanel.add(jLabel1, gridBagConstraints);

        clusterScrollPane.setPreferredSize(new java.awt.Dimension(810, 80));
        clusterList.setBackground(new java.awt.Color(255, 255, 204));
        clusterList.addListSelectionListener(new javax.swing.event.ListSelectionListener() {
            public void valueChanged(javax.swing.event.ListSelectionEvent evt) {
                clusterListValueChanged(evt);
            }
        });

        clusterScrollPane.setViewportView(clusterList);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        addedClustersPanel.add(clusterScrollPane, gridBagConstraints);

        jLabel2.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel2.setForeground(new java.awt.Color(255, 51, 51));
        jLabel2.setText("jLabel2");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        addedClustersPanel.add(jLabel2, gridBagConstraints);

        add(addedClustersPanel, java.awt.BorderLayout.NORTH);

        clusterPanel.setLayout(new java.awt.GridBagLayout());

        clusterPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Genotype Frequency Cluster"));
        frequencyPanel.setLayout(new java.awt.GridBagLayout());

        frequencyPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Genotype Frequencies"));
        frequencyButtonPanel.setLayout(new java.awt.BorderLayout());

        clearFrequencyFormButton.setText("Clear Form");
        clearFrequencyFormButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                clearFrequencyFormButtonActionPerformed(evt);
            }
        });

        frequencyButtonPanelEast.add(clearFrequencyFormButton);

        deleteFrequencyButton.setText("Delete Frequency");
        deleteFrequencyButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteFrequencyButtonActionPerformed(evt);
            }
        });

        frequencyButtonPanelEast.add(deleteFrequencyButton);

        addModifyFrequencyButton.setText("Add/Modify Frequency");
        addModifyFrequencyButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addModifyFrequencyButtonActionPerformed(evt);
            }
        });

        frequencyButtonPanelEast.add(addModifyFrequencyButton);

        frequencyButtonPanel.add(frequencyButtonPanelEast, java.awt.BorderLayout.EAST);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 9;
        gridBagConstraints.gridwidth = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        frequencyPanel.add(frequencyButtonPanel, gridBagConstraints);

        jLabel10.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel10.setForeground(new java.awt.Color(255, 51, 51));
        jLabel10.setText("jLabel10");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 8;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        frequencyPanel.add(jLabel10, gridBagConstraints);

        countField.setPreferredSize(new java.awt.Dimension(250, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        frequencyPanel.add(countField, gridBagConstraints);

        jLabel9.setForeground(java.awt.SystemColor.textHighlight);
        jLabel9.setText("Count");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        frequencyPanel.add(jLabel9, gridBagConstraints);

        jLabel8.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel8.setForeground(new java.awt.Color(255, 51, 51));
        jLabel8.setText("jLabel8");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 8;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        frequencyPanel.add(jLabel8, gridBagConstraints);

        frequencyField.setPreferredSize(new java.awt.Dimension(250, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        frequencyPanel.add(frequencyField, gridBagConstraints);

        jLabel7.setForeground(java.awt.SystemColor.textHighlight);
        jLabel7.setText("Frequency");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        frequencyPanel.add(jLabel7, gridBagConstraints);

        jLabel6.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel6.setForeground(new java.awt.Color(255, 51, 51));
        jLabel6.setText("Genotype or Genotype combination");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 8;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        frequencyPanel.add(jLabel6, gridBagConstraints);

        genotypeComboBox.setPreferredSize(new java.awt.Dimension(250, 22));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        frequencyPanel.add(genotypeComboBox, gridBagConstraints);

        jLabel5.setForeground(java.awt.SystemColor.textHighlight);
        jLabel5.setText("Genotype");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        frequencyPanel.add(jLabel5, gridBagConstraints);

        jLabel4.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel4.setForeground(new java.awt.Color(255, 51, 51));
        jLabel4.setText("jLabel4");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        frequencyPanel.add(jLabel4, gridBagConstraints);

        frequencyScrollPane.setPreferredSize(new java.awt.Dimension(750, 80));
        frequencyTable.setModel(new GenotypeFrequencyTableModel());
        frequencyTable.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        //Ask to be notified of selection changes.
        ListSelectionModel rowSM = frequencyTable.getSelectionModel();
        rowSM.addListSelectionListener(new ListSelectionListener() {
            public void valueChanged(ListSelectionEvent e) {
                //Ignore extra messages.
                if (e.getValueIsAdjusting()) return;
                ListSelectionModel lsm = (ListSelectionModel)e.getSource();
                if (lsm.isSelectionEmpty()) {
                }
                else {
                    int selectedRow = lsm.getMinSelectionIndex();
                    GenotypeFrequency selectedGenotypeFrequency = ((GenotypeFrequencyTableModel)frequencyTable.getModel()).getGenotypeFrequency(selectedRow);
                    fillFrequencyForm(selectedGenotypeFrequency);
                }
            }
        });

        frequencyScrollPane.setViewportView(frequencyTable);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.gridwidth = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        frequencyPanel.add(frequencyScrollPane, gridBagConstraints);

        jScrollPane1.setPreferredSize(new java.awt.Dimension(250, 80));
        genotypeDetailTable.setModel(new GenotypeDetailTableModel(this));
        genotypeDetailTable.setEnabled(false);
        jScrollPane1.setViewportView(genotypeDetailTable);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.gridheight = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        frequencyPanel.add(jScrollPane1, gridBagConstraints);

        jLabel19.setForeground(java.awt.SystemColor.textHighlight);
        jLabel19.setText("Genotype Details");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        frequencyPanel.add(jLabel19, gridBagConstraints);

        jLabel20.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel20.setForeground(new java.awt.Color(255, 51, 51));
        jLabel20.setText("jLabel20");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        frequencyPanel.add(jLabel20, gridBagConstraints);

        jLabel21.setForeground(java.awt.SystemColor.textHighlight);
        jLabel21.setText("Type of Genotype");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        frequencyPanel.add(jLabel21, gridBagConstraints);

        genotypeTypeComboBox.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Observed", "Ratio", "Count" }));
        genotypeTypeComboBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                genotypeTypeComboBoxActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        frequencyPanel.add(genotypeTypeComboBox, gridBagConstraints);

        jLabel22.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel22.setForeground(new java.awt.Color(255, 51, 51));
        jLabel22.setText("jLabel22");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        frequencyPanel.add(jLabel22, gridBagConstraints);

        jPanel1.setLayout(new java.awt.BorderLayout());

        constructGenotypeButton.setText("Construct Genotype");
        constructGenotypeButton.setEnabled(false);
        constructGenotypeButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                constructGenotypeButtonActionPerformed(evt);
            }
        });

        jPanel1.add(constructGenotypeButton, java.awt.BorderLayout.WEST);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        frequencyPanel.add(jPanel1, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.gridwidth = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        clusterPanel.add(frequencyPanel, gridBagConstraints);

        jLabel3.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 10));
        jLabel3.setForeground(new java.awt.Color(102, 102, 255));
        jLabel3.setText("Add a new Genotype Frequency Cluster to the Study");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridwidth = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        clusterPanel.add(jLabel3, gridBagConstraints);

        assayedpanelComboBox.setPreferredSize(new java.awt.Dimension(400, 22));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        clusterPanel.add(assayedpanelComboBox, gridBagConstraints);

        jLabel11.setForeground(java.awt.SystemColor.textHighlight);
        jLabel11.setText("Assayedpanel");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        clusterPanel.add(jLabel11, gridBagConstraints);

        jLabel12.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel12.setForeground(new java.awt.Color(255, 51, 51));
        jLabel12.setText("jLabel12");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        clusterPanel.add(jLabel12, gridBagConstraints);

        markerComboBox.setPreferredSize(new java.awt.Dimension(400, 22));
        markerComboBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                markerComboBoxActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        clusterPanel.add(markerComboBox, gridBagConstraints);

        jLabel13.setForeground(java.awt.SystemColor.textHighlight);
        jLabel13.setText("Marker");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        clusterPanel.add(jLabel13, gridBagConstraints);

        jLabel14.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel14.setForeground(new java.awt.Color(255, 51, 51));
        jLabel14.setText("jLabel14");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        clusterPanel.add(jLabel14, gridBagConstraints);

        jLabel15.setForeground(java.awt.SystemColor.textHighlight);
        jLabel15.setText("Number of Genotyped Samples");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        clusterPanel.add(jLabel15, gridBagConstraints);

        nrGenotypedSamplesField.setPreferredSize(new java.awt.Dimension(190, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        clusterPanel.add(nrGenotypedSamplesField, gridBagConstraints);

        jLabel16.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel16.setForeground(new java.awt.Color(255, 51, 51));
        jLabel16.setText("jLabel16");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        clusterPanel.add(jLabel16, gridBagConstraints);

        jLabel17.setForeground(java.awt.SystemColor.textHighlight);
        jLabel17.setText("p-Value HWE");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        clusterPanel.add(jLabel17, gridBagConstraints);

        pValueHWEField.setPreferredSize(new java.awt.Dimension(190, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        clusterPanel.add(pValueHWEField, gridBagConstraints);

        jLabel18.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel18.setForeground(new java.awt.Color(255, 51, 51));
        jLabel18.setText("jLabel18");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 2;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        clusterPanel.add(jLabel18, gridBagConstraints);

        jLabel23.setForeground(java.awt.SystemColor.textHighlight);
        jLabel23.setText("Experiment");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        clusterPanel.add(jLabel23, gridBagConstraints);

        experimentComboBox.setPreferredSize(new java.awt.Dimension(400, 22));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        clusterPanel.add(experimentComboBox, gridBagConstraints);

        jLabel24.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel24.setForeground(new java.awt.Color(255, 51, 51));
        jLabel24.setText("jLabel24");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        clusterPanel.add(jLabel24, gridBagConstraints);

        add(clusterPanel, java.awt.BorderLayout.CENTER);

        buttonPanel.setLayout(new java.awt.BorderLayout());

        clearButton.setText("Clear Form");
        clearButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                clearButtonActionPerformed(evt);
            }
        });

        buttonPanelEast.add(clearButton);

        deleteButton.setText("Delete Cluster");
        deleteButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteButtonActionPerformed(evt);
            }
        });

        buttonPanelEast.add(deleteButton);

        addModifyButton.setText("Add/Modify Cluster");
        addModifyButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addModifyButtonActionPerformed(evt);
            }
        });

        buttonPanelEast.add(addModifyButton);

        buttonPanel.add(buttonPanelEast, java.awt.BorderLayout.EAST);

        add(buttonPanel, java.awt.BorderLayout.SOUTH);

    }// </editor-fold>//GEN-END:initComponents

    private void constructGenotypeButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_constructGenotypeButtonActionPerformed
        DataArray alleleData = ((GenotypeDetailTableModel)genotypeDetailTable.getModel()).getAllAlleleData();
        String genotypeString = ((Marker)markerComboBox.getSelectedItem()).getUpstream5bp() + "[";
        if(((String)genotypeTypeComboBox.getSelectedItem()).equals("Ratio")) {
            int countRatios = 0;
            for(int i = 0; i < alleleData.nrOfElements(); i++) {
                AlleleData tmp = (AlleleData)alleleData.get(i);
                if(tmp.getRatio() > 0) {
                    genotypeString = genotypeString + tmp.getRatio() + "(" + tmp.getAllele() + ") + ";
                    countRatios++;
                }
            }
            if(countRatios < 2) {
                JOptionPane.showMessageDialog(this,
                "You must enter at least two ratio entries to be able to construct a ratio Genotype",
                "Error",
                JOptionPane.ERROR_MESSAGE);   
                return;
            } 
            genotypeString = genotypeString.substring(0, genotypeString.length() - 2);
        }
        else if(((String)genotypeTypeComboBox.getSelectedItem()).equals("Count")) {
            int countCounts = 0;
            for(int i = 0; i < alleleData.nrOfElements(); i++) {
                AlleleData tmp = (AlleleData)alleleData.get(i);
                if(tmp.getCount() > 0) {
                    genotypeString = genotypeString + "(" + tmp.getCount() + "x" + tmp.getAllele() + ") + ";
                    countCounts++;
                }
            }
            if(countCounts < 1) {
                JOptionPane.showMessageDialog(this,
                "You must enter at least 1 count entry to be able to construct a quantified Genotype",
                "Error",
                JOptionPane.ERROR_MESSAGE);   
                return;
            } 
            genotypeString = genotypeString.substring(0, genotypeString.length() - 2);
        }
        genotypeString = genotypeString + "]" + ((Marker)markerComboBox.getSelectedItem()).getDownstream5bp();
        String[] array = {genotypeString};
        genotypeComboBox.setModel(new javax.swing.DefaultComboBoxModel(array));
        validate();
        repaint();
    }//GEN-LAST:event_constructGenotypeButtonActionPerformed

    private void genotypeTypeComboBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_genotypeTypeComboBoxActionPerformed
        if(((String)genotypeTypeComboBox.getSelectedItem()).equals("Observed")) {
            genotypeDetailTable.setEnabled(false);
            constructGenotypeButton.setEnabled(false);
            updateGenotypeComboBox();
            ((GenotypeDetailTableModel)genotypeDetailTable.getModel()).removeAllAlleleDatas();
        }
        else {
            genotypeDetailTable.setEnabled(true);
            constructGenotypeButton.setEnabled(true);
            updateGenotypeDetailTable();
        }
    }//GEN-LAST:event_genotypeTypeComboBoxActionPerformed

    private void deleteButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteButtonActionPerformed
        deleteGenotypeFrequencyCluster();
    }//GEN-LAST:event_deleteButtonActionPerformed

    private void clearButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_clearButtonActionPerformed
        clearForm();
    }//GEN-LAST:event_clearButtonActionPerformed

    private void clusterListValueChanged(javax.swing.event.ListSelectionEvent evt) {//GEN-FIRST:event_clusterListValueChanged
        GenotypeFrequencyCluster gfc = (GenotypeFrequencyCluster)clusterList.getSelectedValue();
        if(gfc != null) {
            fillForm(gfc);
        }
    }//GEN-LAST:event_clusterListValueChanged

    private void addModifyButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addModifyButtonActionPerformed
        try {
            GenotypeFrequencyCluster gfc = new GenotypeFrequencyCluster();
            gfc.setExperiment((Experiment)experimentComboBox.getSelectedItem());
            gfc.setAssayedpanel((Assayedpanel)assayedpanelComboBox.getSelectedItem());
            gfc.setMarker((Marker)markerComboBox.getSelectedItem());
            gfc.setNrGenotypedSamples(Integer.parseInt(nrGenotypedSamplesField.getText()));
            gfc.setPValueHWE(Float.parseFloat(pValueHWEField.getText()));
            DataArray genotypeFrequencies = ((GenotypeFrequencyTableModel)frequencyTable.getModel()).getAllGenotypeFrequencies();
            for(int i = 0; i < genotypeFrequencies.nrOfElements(); i++) {
                gfc.addGenotypeFrequency((GenotypeFrequency)genotypeFrequencies.get(i));
            }
            if(clusterList.getSelectedValue() == null) {
                mainFrame.getCurrentStudy().addGenotypeFrequencyCluster(gfc);
                clearForm();
            }
            else {
                int answer = JOptionPane.showConfirmDialog(this,
                    "Do you wish to update the selected genotype frequency cluster?",
                    "Warning",
                    JOptionPane.WARNING_MESSAGE,
                    JOptionPane.YES_NO_OPTION);
                if(answer == JOptionPane.YES_OPTION) {
                    GenotypeFrequencyCluster selectedGenotypeFrequencyCluster = (GenotypeFrequencyCluster)clusterList.getSelectedValue();
                    int id = selectedGenotypeFrequencyCluster.getID();
                    mainFrame.getCurrentStudy().updateGenotypeFrequencyCluster(gfc, id);
                    clearForm(); 
                }
            }
        }
        catch(NumberFormatException nfe) {
            JOptionPane.showMessageDialog(this,
                nfe.getMessage(),
                "Error",
                JOptionPane.ERROR_MESSAGE);    
        }
    }//GEN-LAST:event_addModifyButtonActionPerformed

    private void deleteFrequencyButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteFrequencyButtonActionPerformed
        if(frequencyTable.getSelectedRow() == -1) {
            JOptionPane.showMessageDialog(this,
                "You must select a Genotype Frequency to be able to delete it",
                "Error",
                JOptionPane.ERROR_MESSAGE);       
        }
        else {
            ((GenotypeFrequencyTableModel)frequencyTable.getModel()).deleteGenotypeFrequency(frequencyTable.getSelectedRow());
            clearFrequencyForm();
        }
    }//GEN-LAST:event_deleteFrequencyButtonActionPerformed

    private void clearFrequencyFormButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_clearFrequencyFormButtonActionPerformed
        clearFrequencyForm();
    }//GEN-LAST:event_clearFrequencyFormButtonActionPerformed

    private void addModifyFrequencyButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addModifyFrequencyButtonActionPerformed
        try {
            GenotypeFrequency gf = new GenotypeFrequency();
            gf.setGenotypeCombo((String)genotypeComboBox.getSelectedItem());
            gf.setFrequency(Float.parseFloat(frequencyField.getText()));
            gf.setNrSamples(Integer.parseInt(countField.getText()));
            if(frequencyTable.getSelectedRow() == -1) {
                ((GenotypeFrequencyTableModel)frequencyTable.getModel()).addGenotypeFrequency(gf);
            }
            else {
                ((GenotypeFrequencyTableModel)frequencyTable.getModel()).updateGenotypeFrequency(frequencyTable.getSelectedRow(), gf);
            }
            clearFrequencyForm();
            validate();
            repaint();
        }
        catch(NumberFormatException nfe) {
            JOptionPane.showMessageDialog(this,
                nfe.getMessage(),
                "Error",
                JOptionPane.ERROR_MESSAGE);
        }
    }//GEN-LAST:event_addModifyFrequencyButtonActionPerformed

    private void markerComboBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_markerComboBoxActionPerformed
        updateGenotypeComboBox();
    }//GEN-LAST:event_markerComboBoxActionPerformed
    
    private void updateComboBoxes() {
        if(experimentComboBox.getItemCount() > 0) {
            Experiment selectedExp = (Experiment)experimentComboBox.getSelectedItem();
            Object[] markers = selectedExp.getMarkerArray();
            markerComboBox.setModel(new javax.swing.DefaultComboBoxModel(markers));
            Object[] assayedpanels = selectedExp.getAssayedpanelArray();
            assayedpanelComboBox.setModel(new javax.swing.DefaultComboBoxModel(assayedpanels));
            validate();
            repaint();
        }
    }
    
    private void updateGenotypeComboBox() {
        if(markerComboBox.getItemCount() > 0) {
            Marker selectedMarker = (Marker)markerComboBox.getSelectedItem();
            Object[] genotypes = selectedMarker.getGenotypes();
            genotypeComboBox.setModel(new javax.swing.DefaultComboBoxModel(genotypes));
            validate();
            repaint();
        }
    }
    
    private void updateGenotypeDetailTable() {
        if(markerComboBox.getItemCount() > 0) {
            Marker selectedMarker = (Marker)markerComboBox.getSelectedItem();
            Object[] seqs = selectedMarker.getAlleleSequences();
            DataArray alleleData = new DataArray();
            for(int i = 0; i < seqs.length; i++) {
                AlleleData tmp = new AlleleData();
                tmp.setAllele((String)seqs[i]);
                alleleData.add(tmp);
            }
            ((GenotypeDetailTableModel)genotypeDetailTable.getModel()).setAlleleDatas(alleleData.getArray());
            validate();
            repaint();
        }
    }
    
    private void deleteGenotypeFrequencyCluster() {
        GenotypeFrequencyCluster gfc = (GenotypeFrequencyCluster)clusterList.getSelectedValue();
        if(gfc == null) {
            JOptionPane.showMessageDialog(this,
                "You have to select a genotype frequency cluster to be able to delete it.",
                "Error",
                JOptionPane.ERROR_MESSAGE);
        } else {
            int answer = JOptionPane.showConfirmDialog(this,
                    "Do you wish to permanently delete the selected genotype frequency cluster from the submission?",
                    "Warning",
                    JOptionPane.WARNING_MESSAGE,
                    JOptionPane.YES_NO_OPTION);
            if(answer == JOptionPane.YES_OPTION) {
                mainFrame.getCurrentStudy().deleteGenotypeFrequencyCluster(gfc.getID());
                clearForm();    
            }
        }
    }
    
    private HGVbaseSubmissionTool mainFrame;
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton addModifyButton;
    private javax.swing.JButton addModifyFrequencyButton;
    private javax.swing.JPanel addedClustersPanel;
    private javax.swing.JComboBox assayedpanelComboBox;
    private javax.swing.JPanel buttonPanel;
    private javax.swing.JPanel buttonPanelEast;
    private javax.swing.JButton clearButton;
    private javax.swing.JButton clearFrequencyFormButton;
    private javax.swing.JList clusterList;
    private javax.swing.JPanel clusterPanel;
    private javax.swing.JScrollPane clusterScrollPane;
    private javax.swing.JButton constructGenotypeButton;
    private javax.swing.JTextField countField;
    private javax.swing.JButton deleteButton;
    private javax.swing.JButton deleteFrequencyButton;
    private javax.swing.JComboBox experimentComboBox;
    private javax.swing.JPanel frequencyButtonPanel;
    private javax.swing.JPanel frequencyButtonPanelEast;
    private javax.swing.JTextField frequencyField;
    private javax.swing.JPanel frequencyPanel;
    private javax.swing.JScrollPane frequencyScrollPane;
    private javax.swing.JTable frequencyTable;
    private javax.swing.JComboBox genotypeComboBox;
    private javax.swing.JTable genotypeDetailTable;
    private javax.swing.JComboBox genotypeTypeComboBox;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel10;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel12;
    private javax.swing.JLabel jLabel13;
    private javax.swing.JLabel jLabel14;
    private javax.swing.JLabel jLabel15;
    private javax.swing.JLabel jLabel16;
    private javax.swing.JLabel jLabel17;
    private javax.swing.JLabel jLabel18;
    private javax.swing.JLabel jLabel19;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel20;
    private javax.swing.JLabel jLabel21;
    private javax.swing.JLabel jLabel22;
    private javax.swing.JLabel jLabel23;
    private javax.swing.JLabel jLabel24;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JComboBox markerComboBox;
    private javax.swing.JTextField nrGenotypedSamplesField;
    private javax.swing.JTextField pValueHWEField;
    // End of variables declaration//GEN-END:variables
    
}
