/*
 * HGVbaseSubmissionTool.java
 *
 * Created on den 1 februari 2005, 11:17
 */

package phenobase.gui;

import phenobase.data.*;
import phenobase.handling.*;
import java.io.File;
import javax.xml.parsers.*;
import javax.swing.*;
import javax.swing.filechooser.*;
import java.io.*;
import java.util.*;
import java.net.*;
import org.w3c.dom.*;
import org.xml.sax.*;

/**
 * The Frame for the submission tool and also the main class. Keeps track of the
 * XML file, the directories used and the submission data currently being built. Therefore, 
 * most other classes in the GUI needs to be able to access this class to get to the 
 * submission data. 
 *
 * @author  Fredrik Sjholm
 */
public class HGVbaseSubmissionTool extends javax.swing.JFrame {
    
    /**
     * Keeps track of the directory used for settings and makes it accessible from other classes
     */
    public static String SETTINGS_DIR;
    
    /**
     * Keeps track of the directory used for studies that has not yet been submitted and makes 
     * it accessible from other classes
     */
    public static String NOT_SUBMITTED_DIR;
    
    /**
     * Keeps track of the directory used for studies that has been submitted and makes 
     * it accessible from other classes
     */
    public static String SUBMITTED_DIR;
    
    /** 
     * Creates a new <code>HGVbaseSubmissionTool</code> object 
     */
    public HGVbaseSubmissionTool() {
        oldFile = null;
        initComponents();
        java.awt.Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        int width = 1100;
        int height = 935;
        if(screenSize.width < 1000) {
            width = screenSize.width;
        }
        if(screenSize.height < 1000) {
            height = screenSize.height - 50;
        }
        setBounds(0, 0, width, height);
        createSystemDirectories();
        LogoPanel logoPanel = new LogoPanel();
        northPanel.add(logoPanel, java.awt.BorderLayout.CENTER);
        xmlHandler = new XMLFileHandler();
   }
    
    /**
     * Makes the data of the <code>Study</code> that is currently worked on available to 
     * other classes.
     *
     * @return      the current <code>Study</code> being built for submission 
     */
    public Study getCurrentStudy() {
        return currentStudy;
    }
    
    /**
     * The main method that is invoked to start up the application
     *
     * @param   args the command line arguments
     */ 
    public static void main(String args[]) {
        java.awt.EventQueue.invokeLater(new Runnable() {
            public void run() {
                new HGVbaseSubmissionTool().setVisible(true);
            }
        });
    }
            
    /** This method is called from within the constructor to
     * initialize the form.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        mainPanel = new javax.swing.JPanel();
        northPanel = new javax.swing.JPanel();
        centerPanel = new javax.swing.JPanel();
        westPanel = new javax.swing.JPanel();
        menuBar = new javax.swing.JMenuBar();
        fileMenu = new javax.swing.JMenu();
        newItem = new javax.swing.JMenuItem();
        openItem = new javax.swing.JMenuItem();
        saveItem = new javax.swing.JMenuItem();
        saveAsItem = new javax.swing.JMenuItem();
        jSeparator1 = new javax.swing.JSeparator();
        submittItem = new javax.swing.JMenuItem();
        jSeparator2 = new javax.swing.JSeparator();
        exitItem = new javax.swing.JMenuItem();
        editMenu = new javax.swing.JMenu();
        settingsMenu = new javax.swing.JMenuItem();
        helpMenu = new javax.swing.JMenu();

        setDefaultCloseOperation(javax.swing.WindowConstants.DO_NOTHING_ON_CLOSE);
        setTitle("Hgvbase phenotype submission tool ver 0.2");
        setResizable(false);
        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                formWindowClosing(evt);
            }
        });

        mainPanel.setLayout(new java.awt.BorderLayout());

        mainPanel.setBorder(javax.swing.BorderFactory.createEmptyBorder(10, 10, 10, 10));
        northPanel.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 10, 0));
        mainPanel.add(northPanel, java.awt.BorderLayout.NORTH);

        centerPanel.setLayout(new java.awt.BorderLayout());

        mainPanel.add(centerPanel, java.awt.BorderLayout.CENTER);

        westPanel.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 10));
        mainPanel.add(westPanel, java.awt.BorderLayout.WEST);

        getContentPane().add(mainPanel, java.awt.BorderLayout.CENTER);

        fileMenu.setText("File");
        newItem.setText("New");
        newItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                newItemActionPerformed(evt);
            }
        });

        fileMenu.add(newItem);

        openItem.setText("Open");
        openItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                openItemActionPerformed(evt);
            }
        });

        fileMenu.add(openItem);

        saveItem.setText("Save");
        saveItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                saveItemActionPerformed(evt);
            }
        });

        fileMenu.add(saveItem);

        saveAsItem.setText("Save As");
        saveAsItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                saveAsItemActionPerformed(evt);
            }
        });

        fileMenu.add(saveAsItem);

        fileMenu.add(jSeparator1);

        submittItem.setText("Submit");
        fileMenu.add(submittItem);

        fileMenu.add(jSeparator2);

        exitItem.setText("Exit");
        exitItem.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                exitItemActionPerformed(evt);
            }
        });

        fileMenu.add(exitItem);

        menuBar.add(fileMenu);

        editMenu.setText("Edit");
        settingsMenu.setText("Settings");
        settingsMenu.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                settingsMenuActionPerformed(evt);
            }
        });

        editMenu.add(settingsMenu);

        menuBar.add(editMenu);

        helpMenu.setText("Help");
        menuBar.add(helpMenu);

        setJMenuBar(menuBar);

        java.awt.Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        setBounds((screenSize.width-1030)/2, (screenSize.height-1036)/2, 1030, 1036);
    }// </editor-fold>//GEN-END:initComponents

    //Invoked when the save menu item is clicked
    private void saveItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_saveItemActionPerformed
        saveFile();
    }//GEN-LAST:event_saveItemActionPerformed

    //Invoked when the exit menu item is clicked
    private void exitItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_exitItemActionPerformed
        closeApplication();
    }//GEN-LAST:event_exitItemActionPerformed

    //Invoked when the 'x' in the upper corner of the window that closes the window 
    //is clicked
    private void formWindowClosing(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_formWindowClosing
        closeApplication();
    }//GEN-LAST:event_formWindowClosing

    //Invoked when the save as menu item is clicked
    private void saveAsItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_saveAsItemActionPerformed
        saveFileAs();
    }//GEN-LAST:event_saveAsItemActionPerformed

    //Invoked when the open menu item is clicked
    private void openItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_openItemActionPerformed
        JFileChooser fc = new JFileChooser(NOT_SUBMITTED_DIR);
        fc.addChoosableFileFilter(new XMLFileFilter());
        int returnValue = fc.showOpenDialog(this);
        if(returnValue == JFileChooser.APPROVE_OPTION) {
            oldFile = fc.getSelectedFile();
            loadStudyFromFile(oldFile);
            mp = new MainPanel(this);
            setCenterPanel(mp);
            currentStudy.signalChange();
            xmlHandler.saveFile();
        }
    }//GEN-LAST:event_openItemActionPerformed

    //Invoked when the new menu item is clicked.
    private void newItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_newItemActionPerformed
        currentStudy = new Study();
        currentStudy.addObserver(xmlHandler);
        mp = new MainPanel(this);
        setCenterPanel(mp);
    }//GEN-LAST:event_newItemActionPerformed

    //Invoked when the settings menu item is clicked. WILL THIS BE USED????
    private void settingsMenuActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_settingsMenuActionPerformed
        //setCenterPanel(new SettingsPanel(this, mp));
    }//GEN-LAST:event_settingsMenuActionPerformed

    //Sets the center panel thus enabeling the switch between the different panels
    private void setCenterPanel(JPanel p) {
        centerPanel.add(p, java.awt.BorderLayout.CENTER);
        validate();
        repaint();
    }
   
    //Creates the system directories if these doesn't exist and sets the 
    //static variables that keep track of their names
    private void createSystemDirectories() {
        String userHome = System.getProperty("user.home");
        SETTINGS_DIR = userHome + "\\hgvbase\\settings";
        NOT_SUBMITTED_DIR = userHome + "\\hgvbase\\submissions\\not submitted";
        SUBMITTED_DIR = userHome + "\\hgvbase\\submissions\\submitted";
        File f = new File(SETTINGS_DIR);
        if(!f.exists()) {
            f.mkdirs();
        }
        f = new File(NOT_SUBMITTED_DIR);
        if(!f.exists()) {
            f.mkdirs();
        }
        f = new File(SUBMITTED_DIR);
        if(!f.exists()) {
            f.mkdirs();
        }
    }
  
    //Loads a Study from an xml file.
    private void loadStudyFromFile(File f) {
        try {
            StudyDOMParser parser = new StudyDOMParser();
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            DocumentBuilder builder = factory.newDocumentBuilder();
            Document doc = builder.parse(f);
            currentStudy = parser.unmarshallStudy(doc.getDocumentElement());
            currentStudy.addObserver(xmlHandler);
        }
        catch(ParserConfigurationException pce) {
            System.err.println("ParserConfigurationException: " + pce.getMessage());
        }
        catch(SAXException saxe) {
            System.err.println("SAXException: " + saxe.getMessage());
        }
        catch(XMLException xmle) {
            System.err.println("XMLException: " + xmle.getMessage());
        }
        catch(IOException ioe) {
            System.err.println("IOException: " + ioe.getMessage());
        }
    }
    
    //Saves the current study to a file
    private void saveFile() {
        if(oldFile != null) {
            try {
                xmlHandler.writeToFile(oldFile, currentStudy);
                xmlHandler.saveFile();
            }
            catch(FileNotFoundException fnfe) {
                System.err.println("FileNotFoundException: " + fnfe.getMessage());
            }
            catch(IOException ioe) {
                System.err.println("IOException: " + ioe.getMessage());
            }
        } else {
            saveFileAs();
        }
    }
    
    //Saves the current study in a file that the user can specify 
    private void saveFileAs() {
        JFileChooser fc = new JFileChooser(NOT_SUBMITTED_DIR);
        fc.addChoosableFileFilter(new XMLFileFilter());
        int returnVal = fc.showSaveDialog(this);
            if (returnVal == JFileChooser.APPROVE_OPTION) {
                try {
                    File file = fc.getSelectedFile();
                    oldFile = file;
                    xmlHandler.writeToFile(oldFile, currentStudy);
                    xmlHandler.saveFile();
                }
                catch(FileNotFoundException fnfe) {
                    System.out.println("FileNotFoundException: " + fnfe.getMessage());
                }
                catch(IOException ioe) {
                    System.out.println("IOException: " + ioe.getMessage());
                }
            } 
    }
    
    //Closes down the application
    private void closeApplication() {
        if(!xmlHandler.isSaved()) {
            int answer = JOptionPane.showConfirmDialog(this,
                    "Current study has not been saved yet. Do you wish to save the study?",
                    "Warning",
                    JOptionPane.WARNING_MESSAGE,
                    JOptionPane.YES_NO_OPTION);
            if(answer == JOptionPane.YES_OPTION) {
                saveFile();
            }
        }
        this.dispose();    
        System.exit(0);
    }
    
    //Internal class for representing the filters used to make the FileChoosers
    //display only xml-files.
    private class XMLFileFilter extends javax.swing.filechooser.FileFilter {
        //Accept all directories and xml files.
        public boolean accept(File f) {
            if (f.isDirectory()) {
                return true;
            }
            else if(getExtension(f) == null) {
                return false;
            }
            else if(getExtension(f).equals("xml")) {
                return true;
            }
            else {
                return false;
            }
        }
        
        public String getExtension(File f) {
            String ext = null;
            String s = f.getName();
            int i = s.lastIndexOf('.');

            if (i > 0 &&  i < s.length() - 1) {
                ext = s.substring(i+1).toLowerCase();
            }
            return ext;
        }

        //The description of this filter
        public String getDescription() {
            return "XML files";
        }
    }
    
    private Study currentStudy;
    private MainPanel mp;
    private XMLFileHandler xmlHandler;
    private File oldFile;
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JPanel centerPanel;
    private javax.swing.JMenu editMenu;
    private javax.swing.JMenuItem exitItem;
    private javax.swing.JMenu fileMenu;
    private javax.swing.JMenu helpMenu;
    private javax.swing.JSeparator jSeparator1;
    private javax.swing.JSeparator jSeparator2;
    private javax.swing.JPanel mainPanel;
    private javax.swing.JMenuBar menuBar;
    private javax.swing.JMenuItem newItem;
    private javax.swing.JPanel northPanel;
    private javax.swing.JMenuItem openItem;
    private javax.swing.JMenuItem saveAsItem;
    private javax.swing.JMenuItem saveItem;
    private javax.swing.JMenuItem settingsMenu;
    private javax.swing.JMenuItem submittItem;
    private javax.swing.JPanel westPanel;
    // End of variables declaration//GEN-END:variables
    
}