/*
 * OligoPanel.java
 *
 * Created on den 10 juli 2006, 16:07
 */

package phenobase.gui;

import phenobase.handling.*;
import phenobase.data.*;
import java.util.*;
import javax.swing.*;

/**
 *
 * @author  fresjo
 */
public class OligoPanel extends javax.swing.JPanel implements Observer {
    
    /** Creates new form OligoPanel */
    public OligoPanel(HGVbaseSubmissionTool mf) {
        mainFrame = mf;
        mainFrame.getCurrentStudy().addObserver(this);
        initComponents();
    }
    
    public void update(Observable o, Object arg) {
        Study s = (Study)o;
        addedOligosList.setListData(s.getOligoArray());
        validate();
        repaint();
    }
    
    private void fillForm(Oligo o) {
        nameField.setText(o.getName());
        roleComboBox.setSelectedItem(o.getRole());
        sequenceField.setText(o.getSequence());
        modificationsField.setText(o.getModifications());
        validate();
        repaint();
    }
    
    private void clearForm() {
        addedOligosList.clearSelection();
        nameField.setText("");
        roleComboBox.setSelectedIndex(0);
        sequenceField.setText("");
        modificationsField.setText("");
        validate();
        repaint();
    }
    
    private void deleteOligo() {
        Oligo o = (Oligo)addedOligosList.getSelectedValue();
        if(o == null) {
            JOptionPane.showMessageDialog(this,
                "You have to select a Oligo to be able to delete it.",
                "Error",
                JOptionPane.ERROR_MESSAGE);
        } else {
            int answer = JOptionPane.showConfirmDialog(this,
                    "Do you wish to permanently delete the selected Oligo from the submission?",
                    "Warning",
                    JOptionPane.WARNING_MESSAGE,
                    JOptionPane.YES_NO_OPTION);
            if(answer == JOptionPane.YES_OPTION) {
                mainFrame.getCurrentStudy().deleteOligo(o.getID());
                clearForm();    
            }
        }
        validate();
        repaint();
    }
    
    
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        addedOligosPanel = new javax.swing.JPanel();
        jLabel1 = new javax.swing.JLabel();
        addedOligosScrollPane = new javax.swing.JScrollPane();
        addedOligosList = new javax.swing.JList();
        oligoPanel = new javax.swing.JPanel();
        jLabel4 = new javax.swing.JLabel();
        nameField = new javax.swing.JTextField();
        jLabel5 = new javax.swing.JLabel();
        jLabel6 = new javax.swing.JLabel();
        modificationsField = new javax.swing.JTextField();
        jLabel7 = new javax.swing.JLabel();
        jLabel8 = new javax.swing.JLabel();
        sequenceField = new javax.swing.JTextField();
        jLabel9 = new javax.swing.JLabel();
        jLabel10 = new javax.swing.JLabel();
        roleComboBox = new javax.swing.JComboBox();
        jLabel11 = new javax.swing.JLabel();
        buttonPanel = new javax.swing.JPanel();
        buttons = new javax.swing.JPanel();
        newButton = new javax.swing.JButton();
        deleteButton = new javax.swing.JButton();
        saveButton = new javax.swing.JButton();

        setLayout(new java.awt.BorderLayout());

        setBorder(javax.swing.BorderFactory.createTitledBorder("Oligos: optionally, list the Oligos that were used in genotyping Assays for the Markers in your study"));
        addedOligosPanel.setLayout(new java.awt.GridBagLayout());

        addedOligosPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Added Oligos"));
        jLabel1.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel1.setForeground(new java.awt.Color(255, 51, 51));
        jLabel1.setText("Oligos already entered (click entries to view and edit)");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        addedOligosPanel.add(jLabel1, gridBagConstraints);

        addedOligosScrollPane.setPreferredSize(new java.awt.Dimension(810, 80));
        addedOligosList.setBackground(new java.awt.Color(255, 255, 204));
        addedOligosList.addKeyListener(new java.awt.event.KeyAdapter() {
            public void keyPressed(java.awt.event.KeyEvent evt) {
                addedOligosListKeyPressed(evt);
            }
        });
        addedOligosList.addListSelectionListener(new javax.swing.event.ListSelectionListener() {
            public void valueChanged(javax.swing.event.ListSelectionEvent evt) {
                addedOligosListValueChanged(evt);
            }
        });

        addedOligosScrollPane.setViewportView(addedOligosList);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        addedOligosPanel.add(addedOligosScrollPane, gridBagConstraints);

        add(addedOligosPanel, java.awt.BorderLayout.NORTH);

        oligoPanel.setLayout(new java.awt.GridBagLayout());

        oligoPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Oligo Details"));
        jLabel4.setForeground(java.awt.SystemColor.textHighlight);
        jLabel4.setText("Name");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        oligoPanel.add(jLabel4, gridBagConstraints);

        nameField.setBorder(javax.swing.BorderFactory.createLineBorder(java.awt.Color.blue, 2));
        nameField.setPreferredSize(new java.awt.Dimension(400, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        oligoPanel.add(nameField, gridBagConstraints);

        jLabel5.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel5.setForeground(new java.awt.Color(255, 51, 51));
        jLabel5.setText("A unique name for the Oligo");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        oligoPanel.add(jLabel5, gridBagConstraints);

        jLabel6.setForeground(java.awt.SystemColor.textHighlight);
        jLabel6.setText("Modifications");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        oligoPanel.add(jLabel6, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 8;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        oligoPanel.add(modificationsField, gridBagConstraints);

        jLabel7.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel7.setForeground(new java.awt.Color(255, 51, 51));
        jLabel7.setText("Details of the site and nature of chemical modifications to the Oligo, such as added labels, linkers, atypical bases etc");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 9;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        oligoPanel.add(jLabel7, gridBagConstraints);

        jLabel8.setForeground(java.awt.SystemColor.textHighlight);
        jLabel8.setText("Sequence");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        oligoPanel.add(jLabel8, gridBagConstraints);

        sequenceField.setBorder(javax.swing.BorderFactory.createLineBorder(java.awt.Color.blue, 2));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        oligoPanel.add(sequenceField, gridBagConstraints);

        jLabel9.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel9.setForeground(new java.awt.Color(255, 51, 51));
        jLabel9.setText("The 5\u2019-3\u2019 DNA sequence of the Oligo");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        oligoPanel.add(jLabel9, gridBagConstraints);

        jLabel10.setForeground(java.awt.SystemColor.textHighlight);
        jLabel10.setText("Role");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        oligoPanel.add(jLabel10, gridBagConstraints);

        roleComboBox.setEditable(true);
        roleComboBox.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "-", "Primer", "Probe" }));
        roleComboBox.setPreferredSize(new java.awt.Dimension(400, 22));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        oligoPanel.add(roleComboBox, gridBagConstraints);

        jLabel11.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel11.setForeground(new java.awt.Color(255, 51, 51));
        jLabel11.setText("The function of the Oligo in the assay");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        oligoPanel.add(jLabel11, gridBagConstraints);

        add(oligoPanel, java.awt.BorderLayout.CENTER);

        buttonPanel.setLayout(new java.awt.BorderLayout());

        newButton.setText("New Oligo");
        newButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                newButtonActionPerformed(evt);
            }
        });

        buttons.add(newButton);

        deleteButton.setText("Delete Oligo");
        deleteButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteButtonActionPerformed(evt);
            }
        });

        buttons.add(deleteButton);

        saveButton.setText("Save Oligo");
        saveButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                saveButtonActionPerformed(evt);
            }
        });

        buttons.add(saveButton);

        buttonPanel.add(buttons, java.awt.BorderLayout.EAST);

        add(buttonPanel, java.awt.BorderLayout.SOUTH);

    }// </editor-fold>//GEN-END:initComponents

    private void addedOligosListKeyPressed(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_addedOligosListKeyPressed
        if(evt.getKeyCode() == java.awt.event.KeyEvent.VK_DELETE) {
            deleteOligo();
        }
    }//GEN-LAST:event_addedOligosListKeyPressed

    private void deleteButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteButtonActionPerformed
        deleteOligo();
    }//GEN-LAST:event_deleteButtonActionPerformed

    private void addedOligosListValueChanged(javax.swing.event.ListSelectionEvent evt) {//GEN-FIRST:event_addedOligosListValueChanged
        Oligo o = (Oligo)addedOligosList.getSelectedValue();
        if(o != null) {
            fillForm(o);
        }
    }//GEN-LAST:event_addedOligosListValueChanged

    private void newButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_newButtonActionPerformed
        clearForm();
    }//GEN-LAST:event_newButtonActionPerformed

    private void saveButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_saveButtonActionPerformed
        Oligo o = new Oligo();
        if(!nameField.getText().equals("") && !sequenceField.getText().equals("")) {
            o.setName(nameField.getText());
            o.setRole((String)roleComboBox.getSelectedItem());
            o.setSequence(sequenceField.getText());
            o.setModifications(modificationsField.getText());
            if(addedOligosList.getSelectedValue() == null) {
                if(!mainFrame.getCurrentStudy().isAddedOligo(o.getName())) {
                    mainFrame.getCurrentStudy().addOligo(o);
                    clearForm();
                }
                else {
                    JOptionPane.showMessageDialog(this,
                        "An Oligo with that name has allready been added.", 
                        "Error",
                        JOptionPane.ERROR_MESSAGE);
                }
            }
            else {
                int answer = JOptionPane.showConfirmDialog(this,
                        "Do you wish to update the selected Oligo?",
                        "Warning",
                        JOptionPane.WARNING_MESSAGE,
                        JOptionPane.YES_NO_OPTION);
                if(answer == JOptionPane.YES_OPTION) {
                    Oligo selectedOligo = (Oligo)addedOligosList.getSelectedValue();
                    int id = selectedOligo.getID();
                    mainFrame.getCurrentStudy().updateOligo(o, id);
                    clearForm();    
                }
            }
        }
        else {
            JOptionPane.showMessageDialog(this,
                    "All of the required information has not been entered", 
                    "Error",
                    JOptionPane.ERROR_MESSAGE);
        }
    }//GEN-LAST:event_saveButtonActionPerformed
    
    private HGVbaseSubmissionTool mainFrame;
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JList addedOligosList;
    private javax.swing.JPanel addedOligosPanel;
    private javax.swing.JScrollPane addedOligosScrollPane;
    private javax.swing.JPanel buttonPanel;
    private javax.swing.JPanel buttons;
    private javax.swing.JButton deleteButton;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel10;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JTextField modificationsField;
    private javax.swing.JTextField nameField;
    private javax.swing.JButton newButton;
    private javax.swing.JPanel oligoPanel;
    private javax.swing.JComboBox roleComboBox;
    private javax.swing.JButton saveButton;
    private javax.swing.JTextField sequenceField;
    // End of variables declaration//GEN-END:variables
    
}
