/*
 * PhenotypeMethodPanel.java
 *
 * Created on den 20 april 2006, 14:40
 */

package phenobase.gui;

import phenobase.data.*;
import javax.swing.*;
import java.awt.*;
import java.util.*;

/**
 *
 * @author  fresjo
 */
public class PhenotypeMethodPanel extends javax.swing.JPanel implements Observer {

    public static final int GENERAL = 0;
    
    public static final int OTHER = 1;
    
    /** Creates new form PhenotypeMethodPanel */
    public PhenotypeMethodPanel(HGVbaseSubmissionTool mf) {
        initComponents();
        mainFrame = mf;
        mainFrame.getCurrentStudy().addObserver(this);
        generalInfoPanel = new PhenotypeMethod_GeneralInformationPanel(this, mainFrame);
        otherInfoPanel = new PhenotypeMethod_OtherInformationPanel(this, mainFrame);
        methodPanel.add(generalInfoPanel, BorderLayout.NORTH);
    }
    
    public void update(Observable o, Object arg) {
        Study s = (Study)o;
        addedMethodsList.setListData(s.getPhenotypeMethodArray());
        generalInfoPanel.setPhenotypeNames(s.getPhenotypePropertyNames());
        validate();
        repaint();
    }
    
    public void switchPanel(int panel) {
        methodPanel.removeAll();
        if(panel == GENERAL) {
            methodPanel.add(generalInfoPanel, BorderLayout.NORTH);
        }
        else if(panel == OTHER) {
            methodPanel.add(otherInfoPanel, BorderLayout.NORTH);
        }
        validate();
        repaint();
    }
    
    public void clearForm() {
        generalInfoPanel.clearForm();
        otherInfoPanel.clearForm();
        addedMethodsList.clearSelection();
    }
    
    public void fillForm(PhenotypeMethod pm) {
        generalInfoPanel.fillForm(pm);
        otherInfoPanel.fillForm(pm);
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        addedMethodsPanel = new javax.swing.JPanel();
        addedMethodsScrollPane = new javax.swing.JScrollPane();
        addedMethodsList = new javax.swing.JList();
        jLabel2 = new javax.swing.JLabel();
        methodPanel = new javax.swing.JPanel();
        buttonPanel = new javax.swing.JPanel();
        eastButtonPanel = new javax.swing.JPanel();
        clearButton = new javax.swing.JButton();
        deleteButton = new javax.swing.JButton();
        addModifyButton = new javax.swing.JButton();

        setLayout(new java.awt.BorderLayout());

        setBorder(javax.swing.BorderFactory.createTitledBorder("Phenotype Methods: enter details of how the Phenotype Entities were determined"));
        addedMethodsPanel.setLayout(new java.awt.GridBagLayout());

        addedMethodsPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Added Phenotype Methods"));
        addedMethodsScrollPane.setPreferredSize(new java.awt.Dimension(810, 80));
        addedMethodsList.setBackground(new java.awt.Color(255, 255, 204));
        addedMethodsList.addListSelectionListener(new javax.swing.event.ListSelectionListener() {
            public void valueChanged(javax.swing.event.ListSelectionEvent evt) {
                addedMethodsListValueChanged(evt);
            }
        });

        addedMethodsScrollPane.setViewportView(addedMethodsList);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        addedMethodsPanel.add(addedMethodsScrollPane, gridBagConstraints);

        jLabel2.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel2.setForeground(new java.awt.Color(255, 51, 51));
        jLabel2.setText("Phenotype Methods already entered (click entries to view and edit)");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        addedMethodsPanel.add(jLabel2, gridBagConstraints);

        add(addedMethodsPanel, java.awt.BorderLayout.NORTH);

        methodPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Phenotype Method Details"));
        add(methodPanel, java.awt.BorderLayout.CENTER);

        buttonPanel.setLayout(new java.awt.BorderLayout());

        clearButton.setText("New Phenotype Method");
        clearButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                clearButtonActionPerformed(evt);
            }
        });

        eastButtonPanel.add(clearButton);

        deleteButton.setText("Delete Phenotype Method");
        deleteButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteButtonActionPerformed(evt);
            }
        });

        eastButtonPanel.add(deleteButton);

        addModifyButton.setText("Save Phenotype Method");
        addModifyButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addModifyButtonActionPerformed(evt);
            }
        });

        eastButtonPanel.add(addModifyButton);

        buttonPanel.add(eastButtonPanel, java.awt.BorderLayout.EAST);

        add(buttonPanel, java.awt.BorderLayout.SOUTH);

    }// </editor-fold>//GEN-END:initComponents

    private void deleteButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteButtonActionPerformed
        deletePhenotypeMethod();
    }//GEN-LAST:event_deleteButtonActionPerformed

    private void addedMethodsListValueChanged(javax.swing.event.ListSelectionEvent evt) {//GEN-FIRST:event_addedMethodsListValueChanged
        PhenotypeMethod pm = (PhenotypeMethod)addedMethodsList.getSelectedValue();
        if(pm != null) {
            fillForm(pm);
        }
    }//GEN-LAST:event_addedMethodsListValueChanged

    private void addModifyButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addModifyButtonActionPerformed
        PhenotypeMethod pm = new PhenotypeMethod();
        pm.setMethodName(generalInfoPanel.getMethodName());
        pm.setPhenotypeName(generalInfoPanel.getPhenotypeName());
        pm.setResultType(generalInfoPanel.getResultType());
        pm.setSampleType(generalInfoPanel.getSampleType());
        pm.setCircumstance(generalInfoPanel.getCircumstance());
        pm.setDetails(generalInfoPanel.getDetails());
        try {
            if(!otherInfoPanel.getTimeInstant().equals("")) {
                pm.setTimeInstant(otherInfoPanel.getTimeInstant());
            }
            else if(!otherInfoPanel.getTimePeriod().equals("")) {
                pm.setTimePeriod(otherInfoPanel.getTimePeriod());
            }
        }
        catch(PhenotypeMethodException pme) {
            System.out.println("Time instant/period error");
        }
        String[] keywords = otherInfoPanel.getAddedKeywords();
        for(int i = 0; i < keywords.length; i++) {
            pm.addKeyword(keywords[i]);
        }
        Citation[] citations = otherInfoPanel.getAddedCitations();
        for(int i = 0; i < citations.length; i++) {
            pm.addCitation(citations[i]);
        }
        if(addedMethodsList.getSelectedValue() == null) {
            mainFrame.getCurrentStudy().addPhenotypeMethod(pm);
            clearForm();
        }
        else {
            int answer = JOptionPane.showConfirmDialog(this,
                    "Do you wish to update the selected phenotype method?",
                    "Warning",
                    JOptionPane.WARNING_MESSAGE,
                    JOptionPane.YES_NO_OPTION);
            if(answer == JOptionPane.YES_OPTION) {
                PhenotypeMethod selectedPhenotypeMethod = (PhenotypeMethod)addedMethodsList.getSelectedValue();
                int id = selectedPhenotypeMethod.getID();
                mainFrame.getCurrentStudy().updatePhenotypeMethod(pm, id);
                clearForm(); 
            }
        }
    }//GEN-LAST:event_addModifyButtonActionPerformed

    private void clearButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_clearButtonActionPerformed
        clearForm();
    }//GEN-LAST:event_clearButtonActionPerformed
    
    private void deletePhenotypeMethod() {
        PhenotypeMethod pm = (PhenotypeMethod)addedMethodsList.getSelectedValue();
        if(pm == null) {
            JOptionPane.showMessageDialog(this,
                "You have to select a method to be able to delete it.",
                "Error",
                JOptionPane.ERROR_MESSAGE);
        } else {
            int answer = JOptionPane.showConfirmDialog(this,
                    "Do you wish to permanently delete the selected method from the submission?",
                    "Warning",
                    JOptionPane.WARNING_MESSAGE,
                    JOptionPane.YES_NO_OPTION);
            if(answer == JOptionPane.YES_OPTION) {
                mainFrame.getCurrentStudy().deletePhenotypeMethod(pm.getID());
                clearForm();    
            }
        }
    }
    
    private HGVbaseSubmissionTool mainFrame;
    private PhenotypeMethod_GeneralInformationPanel generalInfoPanel;
    private PhenotypeMethod_OtherInformationPanel otherInfoPanel;
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton addModifyButton;
    private javax.swing.JList addedMethodsList;
    private javax.swing.JPanel addedMethodsPanel;
    private javax.swing.JScrollPane addedMethodsScrollPane;
    private javax.swing.JPanel buttonPanel;
    private javax.swing.JButton clearButton;
    private javax.swing.JButton deleteButton;
    private javax.swing.JPanel eastButtonPanel;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JPanel methodPanel;
    // End of variables declaration//GEN-END:variables
    
}
