/*
 * ResearcherPanel.java
 *
 * Created on den 21 september 2005, 14:14
 */

package phenobase.gui;

import phenobase.data.*;
import javax.swing.*;
import javax.swing.event.*;
import java.awt.*;
import java.awt.event.*;
import phenobase.handling.*;
import javax.xml.parsers.*;
import java.io.*;
import java.util.*;
import java.util.regex.*;
import org.w3c.dom.*;
import org.xml.sax.*;

/**
 * This panel is used to display, alter and add researcher data. 
 * Like every panel displaying data this panel is a <code>Observer</code> that listens 
 * to the <code>Observable</code> model represented by the <code>Study</code> object. 
 * This means that the data in the panel will be automatically updated as soon as 
 * the current study data is updated. For more information on this, please refer
 * to the MVC (ModelViewController) design pattern. 
 *
 * @author  Fredrik Sjholm
 */
public class ResearcherPanel extends javax.swing.JPanel implements Observer {
    
    /** 
     * Creates a new instance of <code>ResearcherPanel</code>.
     *
     * @param t     The <code>HGVbaseSubmissionTool</code> that this panel
     *              belong to. 
     */
    public ResearcherPanel(HGVbaseSubmissionTool t) {
        mainFrame = t;
        mainFrame.getCurrentStudy().addObserver(this);
        initComponents();
    }
    
    /**
     * This method is invoked when the observed <code>Study</code> changes. For more
     * information, refer to the MVC (ModelViewController) design pattern and the
     * <code>Observer</code> class in the java standard library. 
     */
    public void update(Observable o, Object arg) {
        Study s = (Study)o;
        addedResearchersList.setListData(s.getResearcherArray());
        validate();
        repaint();
    }
    
    //Clears all the fields in the form
    private void clearForm() {
        addedResearchersList.clearSelection();
        firstNameField.setText("");
        lastNameField.setText("");
        otherNamesField.setText("");
        departmentField.setText("");
        institutionField.setText("");
        addressField.setText("");
        phoneField.setText("");
        faxField.setText("");
        emailField.setText("");
        homepageField.setText("");
        authorCheckBox.setSelected(false);
        submitterCheckBox.setSelected(false);
    }
    
    //Fills the form with the data from a given reasearcher
    private void fillForm(Researcher r) {
        firstNameField.setText(r.getFirstName());
        lastNameField.setText(r.getLastName());
        otherNamesField.setText(r.getOtherNames());
        departmentField.setText(r.getDepartment());
        institutionField.setText(r.getInstitution());
        addressField.setText(r.getAddress());
        phoneField.setText(r.getPhone());
        faxField.setText(r.getFax());
        emailField.setText(r.getEmail());
        homepageField.setText(r.getWWW());
        authorCheckBox.setSelected(r.getIsAuthor());
        submitterCheckBox.setSelected(r.getIsCorrespondingAuthor());
        validate();
        repaint();
    }
       
    //Deletes the reasearcher selected in the list from the current study
    private void deleteResearcher() {
        Researcher r = (Researcher)addedResearchersList.getSelectedValue();
        if(r == null) {
            JOptionPane.showMessageDialog(this,
                "You have to select a Researcher to be able to delete him/her.",
                "Error",
                JOptionPane.ERROR_MESSAGE);
        } else {
            int answer = JOptionPane.showConfirmDialog(this,
                    "Do you wish to permanently delete the selected Researcher from the study?",
                    "Warning",
                    JOptionPane.WARNING_MESSAGE,
                    JOptionPane.YES_NO_OPTION);
            if(answer == JOptionPane.YES_OPTION) {
                mainFrame.getCurrentStudy().deleteResearcher(r.getID());
                clearForm();    
            }
        }
    }
    
    /** 
     * This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        addedResearchersPanel = new javax.swing.JPanel();
        addedResearchersScrollPane = new javax.swing.JScrollPane();
        addedResearchersList = new javax.swing.JList();
        jLabel1 = new javax.swing.JLabel();
        researcherPanel = new javax.swing.JPanel();
        jLabel5 = new javax.swing.JLabel();
        jLabel9 = new javax.swing.JLabel();
        jLabel7 = new javax.swing.JLabel();
        lastNameField = new javax.swing.JTextField();
        otherNamesField = new javax.swing.JTextField();
        firstNameField = new javax.swing.JTextField();
        jLabel6 = new javax.swing.JLabel();
        jLabel10 = new javax.swing.JLabel();
        jLabel8 = new javax.swing.JLabel();
        jLabel11 = new javax.swing.JLabel();
        jLabel13 = new javax.swing.JLabel();
        departmentField = new javax.swing.JTextField();
        institutionField = new javax.swing.JTextField();
        jLabel14 = new javax.swing.JLabel();
        jLabel12 = new javax.swing.JLabel();
        jLabel15 = new javax.swing.JLabel();
        addressField = new javax.swing.JTextField();
        jLabel16 = new javax.swing.JLabel();
        jLabel17 = new javax.swing.JLabel();
        jLabel19 = new javax.swing.JLabel();
        jLabel21 = new javax.swing.JLabel();
        emailField = new javax.swing.JTextField();
        faxField = new javax.swing.JTextField();
        phoneField = new javax.swing.JTextField();
        jLabel18 = new javax.swing.JLabel();
        jLabel20 = new javax.swing.JLabel();
        jLabel22 = new javax.swing.JLabel();
        jLabel23 = new javax.swing.JLabel();
        homepageField = new javax.swing.JTextField();
        jLabel24 = new javax.swing.JLabel();
        jLabel3 = new javax.swing.JLabel();
        jLabel25 = new javax.swing.JLabel();
        jPanel1 = new javax.swing.JPanel();
        authorCheckBox = new javax.swing.JCheckBox();
        submitterCheckBox = new javax.swing.JCheckBox();
        buttonPanel = new javax.swing.JPanel();
        buttons = new javax.swing.JPanel();
        newButton = new javax.swing.JButton();
        deleteButton = new javax.swing.JButton();
        saveButton = new javax.swing.JButton();

        setLayout(new java.awt.BorderLayout());

        setBorder(javax.swing.BorderFactory.createTitledBorder("Researchers: enter all the scientists to be named as authors on this submission"));
        addedResearchersPanel.setLayout(new java.awt.GridBagLayout());

        addedResearchersPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Added Researchers"));
        addedResearchersScrollPane.setPreferredSize(new java.awt.Dimension(810, 80));
        addedResearchersList.setBackground(new java.awt.Color(255, 255, 204));
        addedResearchersList.addKeyListener(new java.awt.event.KeyAdapter() {
            public void keyPressed(java.awt.event.KeyEvent evt) {
                addedResearchersListKeyPressed(evt);
            }
        });
        addedResearchersList.addListSelectionListener(new javax.swing.event.ListSelectionListener() {
            public void valueChanged(javax.swing.event.ListSelectionEvent evt) {
                addedResearchersListValueChanged(evt);
            }
        });

        addedResearchersScrollPane.setViewportView(addedResearchersList);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        addedResearchersPanel.add(addedResearchersScrollPane, gridBagConstraints);

        jLabel1.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel1.setForeground(new java.awt.Color(255, 51, 51));
        jLabel1.setText("Researchers already entered (click entries to view and edit)");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        addedResearchersPanel.add(jLabel1, gridBagConstraints);

        add(addedResearchersPanel, java.awt.BorderLayout.NORTH);

        researcherPanel.setLayout(new java.awt.GridBagLayout());

        researcherPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Researcher Details"));
        jLabel5.setForeground(java.awt.SystemColor.textHighlight);
        jLabel5.setText("First name");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        researcherPanel.add(jLabel5, gridBagConstraints);

        jLabel9.setForeground(java.awt.SystemColor.textHighlight);
        jLabel9.setText("Other name(s)");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        researcherPanel.add(jLabel9, gridBagConstraints);

        jLabel7.setForeground(java.awt.SystemColor.textHighlight);
        jLabel7.setText("Last name");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        researcherPanel.add(jLabel7, gridBagConstraints);

        lastNameField.setBorder(javax.swing.BorderFactory.createLineBorder(java.awt.Color.blue, 2));
        lastNameField.setPreferredSize(new java.awt.Dimension(250, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        researcherPanel.add(lastNameField, gridBagConstraints);

        otherNamesField.setPreferredSize(new java.awt.Dimension(250, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        researcherPanel.add(otherNamesField, gridBagConstraints);

        firstNameField.setBorder(javax.swing.BorderFactory.createLineBorder(java.awt.Color.blue, 2));
        firstNameField.setPreferredSize(new java.awt.Dimension(250, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        researcherPanel.add(firstNameField, gridBagConstraints);

        jLabel6.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel6.setForeground(new java.awt.Color(255, 51, 51));
        jLabel6.setText("First name of the researcher");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        researcherPanel.add(jLabel6, gridBagConstraints);

        jLabel10.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel10.setForeground(new java.awt.Color(255, 51, 51));
        jLabel10.setText("Other name(s) of the researcher");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        researcherPanel.add(jLabel10, gridBagConstraints);

        jLabel8.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel8.setForeground(new java.awt.Color(255, 51, 51));
        jLabel8.setText("Last name of the researcher");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        researcherPanel.add(jLabel8, gridBagConstraints);

        jLabel11.setForeground(java.awt.SystemColor.textHighlight);
        jLabel11.setText("Department");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 9;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        researcherPanel.add(jLabel11, gridBagConstraints);

        jLabel13.setForeground(java.awt.SystemColor.textHighlight);
        jLabel13.setText("Institution");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 9;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        researcherPanel.add(jLabel13, gridBagConstraints);

        departmentField.setPreferredSize(new java.awt.Dimension(390, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 10;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        researcherPanel.add(departmentField, gridBagConstraints);

        institutionField.setBorder(javax.swing.BorderFactory.createLineBorder(java.awt.Color.blue, 2));
        institutionField.setPreferredSize(new java.awt.Dimension(390, 19));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 10;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        researcherPanel.add(institutionField, gridBagConstraints);

        jLabel14.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel14.setForeground(new java.awt.Color(255, 51, 51));
        jLabel14.setText("Institution of the researcher");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 11;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        researcherPanel.add(jLabel14, gridBagConstraints);

        jLabel12.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel12.setForeground(new java.awt.Color(255, 51, 51));
        jLabel12.setText("Department of the researcher");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 11;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        researcherPanel.add(jLabel12, gridBagConstraints);

        jLabel15.setForeground(java.awt.SystemColor.textHighlight);
        jLabel15.setText("Address");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 12;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        researcherPanel.add(jLabel15, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 13;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        researcherPanel.add(addressField, gridBagConstraints);

        jLabel16.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel16.setForeground(new java.awt.Color(255, 51, 51));
        jLabel16.setText("Street address of the researcher");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 14;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        researcherPanel.add(jLabel16, gridBagConstraints);

        jLabel17.setForeground(java.awt.SystemColor.textHighlight);
        jLabel17.setText("Phone");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 15;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        researcherPanel.add(jLabel17, gridBagConstraints);

        jLabel19.setForeground(java.awt.SystemColor.textHighlight);
        jLabel19.setText("Fax");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 15;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        researcherPanel.add(jLabel19, gridBagConstraints);

        jLabel21.setForeground(java.awt.SystemColor.textHighlight);
        jLabel21.setText("Email");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 18;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        researcherPanel.add(jLabel21, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 19;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        researcherPanel.add(emailField, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 16;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        researcherPanel.add(faxField, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 16;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        researcherPanel.add(phoneField, gridBagConstraints);

        jLabel18.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel18.setForeground(new java.awt.Color(255, 51, 51));
        jLabel18.setText("Phone number of the researcher");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 17;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        researcherPanel.add(jLabel18, gridBagConstraints);

        jLabel20.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel20.setForeground(new java.awt.Color(255, 51, 51));
        jLabel20.setText("Fax number of the researcher");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 17;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        researcherPanel.add(jLabel20, gridBagConstraints);

        jLabel22.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel22.setForeground(new java.awt.Color(255, 51, 51));
        jLabel22.setText("Email address of the researcher");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 20;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        researcherPanel.add(jLabel22, gridBagConstraints);

        jLabel23.setForeground(java.awt.SystemColor.textHighlight);
        jLabel23.setText("Homepage");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 18;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        researcherPanel.add(jLabel23, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 19;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        researcherPanel.add(homepageField, gridBagConstraints);

        jLabel24.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel24.setForeground(new java.awt.Color(255, 51, 51));
        jLabel24.setText("The homepage or WWW address of the sresearcher");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 20;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        researcherPanel.add(jLabel24, gridBagConstraints);

        jLabel3.setForeground(java.awt.SystemColor.textHighlight);
        jLabel3.setText("Role");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        researcherPanel.add(jLabel3, gridBagConstraints);

        jLabel25.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel25.setForeground(new java.awt.Color(255, 51, 51));
        jLabel25.setText("The role of the researcher in this submission");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 8;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        researcherPanel.add(jLabel25, gridBagConstraints);

        jPanel1.setBorder(javax.swing.BorderFactory.createLineBorder(java.awt.Color.blue, 2));
        authorCheckBox.setSelected(true);
        authorCheckBox.setText("Author");
        authorCheckBox.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                authorCheckBoxActionPerformed(evt);
            }
        });

        jPanel1.add(authorCheckBox);

        submitterCheckBox.setText("Corresponding Author");
        jPanel1.add(submitterCheckBox);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        researcherPanel.add(jPanel1, gridBagConstraints);

        add(researcherPanel, java.awt.BorderLayout.CENTER);

        buttonPanel.setLayout(new java.awt.BorderLayout());

        newButton.setText("New Researcher");
        newButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                newButtonActionPerformed(evt);
            }
        });

        buttons.add(newButton);

        deleteButton.setText("Delete Researcher");
        deleteButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteButtonActionPerformed(evt);
            }
        });

        buttons.add(deleteButton);

        saveButton.setText("Save Researcher");
        saveButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                saveButtonActionPerformed(evt);
            }
        });

        buttons.add(saveButton);

        buttonPanel.add(buttons, java.awt.BorderLayout.EAST);

        add(buttonPanel, java.awt.BorderLayout.SOUTH);

    }// </editor-fold>//GEN-END:initComponents

    //Invoked when the author checkboz is clicked. WILL THIS BE USED???
    private void authorCheckBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_authorCheckBoxActionPerformed
        // TODO add your handling code here:
    }//GEN-LAST:event_authorCheckBoxActionPerformed

    //Invoked when the clear button is clicked
    private void newButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_newButtonActionPerformed
        clearForm();
    }//GEN-LAST:event_newButtonActionPerformed

    //Invoked if the reseacher list is selected and a key is pressed, used to
    //enable users to use the delete key when deleting researchers.
    private void addedResearchersListKeyPressed(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_addedResearchersListKeyPressed
        if(evt.getKeyCode() == java.awt.event.KeyEvent.VK_DELETE) {
            deleteResearcher();
        }
    }//GEN-LAST:event_addedResearchersListKeyPressed

    //Invoked when the delete button is clicked
    private void deleteButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteButtonActionPerformed
        deleteResearcher();
    }//GEN-LAST:event_deleteButtonActionPerformed

    //Invoked whenever the selection in the researcher list changes.
    private void addedResearchersListValueChanged(javax.swing.event.ListSelectionEvent evt) {//GEN-FIRST:event_addedResearchersListValueChanged
        Researcher r = (Researcher)addedResearchersList.getSelectedValue();
        if(r != null) {
            fillForm(r);
        }
    }//GEN-LAST:event_addedResearchersListValueChanged

    //Invoked when the add/modify button is clicked
    private void saveButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_saveButtonActionPerformed
        boolean incomplete = false;
        Researcher r = new Researcher();
        if(firstNameField.getText().equals("")) {
            incomplete = true;
        }
        else {
            r.setFirstName(firstNameField.getText());
        }
        if(lastNameField.getText().equals("")) {
            incomplete = true;
        }
        else {
            r.setLastName(lastNameField.getText());
        }
        r.setOtherNames(otherNamesField.getText());
        r.setDepartment(departmentField.getText());
        if(institutionField.getText().equals("")) {
            incomplete = true;
        }
        else {
            r.setInstitution(institutionField.getText());
        }
        r.setAddress(addressField.getText());
        r.setPhone(phoneField.getText());
        r.setFax(faxField.getText());
        boolean correctEmail = true;
        if(!emailField.getText().equals("")) {
            Pattern p = Pattern.compile("\\w+[\\w.]*@[\\w.]*\\w+");
            Matcher m = p.matcher(emailField.getText());
            if(!m.matches()) {
                correctEmail = false;
            }
        }
        r.setEmail(emailField.getText());
        r.setWWW(homepageField.getText());
        if(!authorCheckBox.isSelected() && !submitterCheckBox.isSelected()) {
            incomplete = true;
        }
        else {
            r.setIsAuthor(authorCheckBox.isSelected());
            r.setIsCorrespondingAuthor(submitterCheckBox.isSelected());
        }
        if(incomplete) {
            JOptionPane.showMessageDialog(this,
                "All of the required information has not been entered",
                "Error",
                JOptionPane.ERROR_MESSAGE);
        }
        else if(!correctEmail) {
            JOptionPane.showMessageDialog(this,
                "The email adress given did not have a proper format",
                "Error",
                JOptionPane.ERROR_MESSAGE);
        }
        else {
            if(addedResearchersList.getSelectedValue() == null) {
                mainFrame.getCurrentStudy().addResearcher(r);
                clearForm();
            }
            else {
                int answer = JOptionPane.showConfirmDialog(this,
                        "Do you wish to update the selected Researcher?",
                        "Warning",
                        JOptionPane.WARNING_MESSAGE,
                        JOptionPane.YES_NO_OPTION);
                if(answer == JOptionPane.YES_OPTION) {
                    Researcher selectedResearcher = (Researcher)addedResearchersList.getSelectedValue();
                    int id = selectedResearcher.getID();
                    mainFrame.getCurrentStudy().updateResearcher(r, id);
                    clearForm();
                }
            }
        }
    }//GEN-LAST:event_saveButtonActionPerformed
    
    private HGVbaseSubmissionTool mainFrame;
    private javax.swing.plaf.basic.BasicBorders.FieldBorder oldFieldBorder;
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JList addedResearchersList;
    private javax.swing.JPanel addedResearchersPanel;
    private javax.swing.JScrollPane addedResearchersScrollPane;
    private javax.swing.JTextField addressField;
    private javax.swing.JCheckBox authorCheckBox;
    private javax.swing.JPanel buttonPanel;
    private javax.swing.JPanel buttons;
    private javax.swing.JButton deleteButton;
    private javax.swing.JTextField departmentField;
    private javax.swing.JTextField emailField;
    private javax.swing.JTextField faxField;
    private javax.swing.JTextField firstNameField;
    private javax.swing.JTextField homepageField;
    private javax.swing.JTextField institutionField;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel10;
    private javax.swing.JLabel jLabel11;
    private javax.swing.JLabel jLabel12;
    private javax.swing.JLabel jLabel13;
    private javax.swing.JLabel jLabel14;
    private javax.swing.JLabel jLabel15;
    private javax.swing.JLabel jLabel16;
    private javax.swing.JLabel jLabel17;
    private javax.swing.JLabel jLabel18;
    private javax.swing.JLabel jLabel19;
    private javax.swing.JLabel jLabel20;
    private javax.swing.JLabel jLabel21;
    private javax.swing.JLabel jLabel22;
    private javax.swing.JLabel jLabel23;
    private javax.swing.JLabel jLabel24;
    private javax.swing.JLabel jLabel25;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JLabel jLabel7;
    private javax.swing.JLabel jLabel8;
    private javax.swing.JLabel jLabel9;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JTextField lastNameField;
    private javax.swing.JButton newButton;
    private javax.swing.JTextField otherNamesField;
    private javax.swing.JTextField phoneField;
    private javax.swing.JPanel researcherPanel;
    private javax.swing.JButton saveButton;
    private javax.swing.JCheckBox submitterCheckBox;
    // End of variables declaration//GEN-END:variables
}
