/*
 * SamplesetPanel.java
 *
 * Created on den 23 december 2005, 15:34
 */

package phenobase.gui;

import phenobase.data.*;
import javax.swing.*;
import javax.swing.event.*;
import java.util.*;
import java.awt.*;

/**
 *
 * @author  fresjo
 */
public class SamplepanelPanel extends javax.swing.JPanel implements Observer {
    
    public static final int GENERAL = 0;
    
    public static final int POPULATION = 1;
    
    public static final int OTHER = 2;
    
    public static final int OVERLAP = 3;
    
    public static final int PHENOTYPE_VALUES = 4;
    
    /** Creates new form SamplesetPanel */
    public SamplepanelPanel(HGVbaseSubmissionTool mf) {
        mainFrame = mf;
        mainFrame.getCurrentStudy().addObserver(this);
        initComponents();
        generalInfoPanel = new Samplepanel_GeneralInformationPanel(this);
        popInfoPanel = new Samplepanel_PopulationInformationPanel(this);
        otherInfoPanel = new Samplepanel_OtherInformationPanel(this);
        overlapPanel = new Samplepanel_OverlapPanel(this);
        phenotypeValuePanel = new Samplepanel_NumberWithPhenotypePanel(this);
        contentPanel.add(generalInfoPanel, BorderLayout.NORTH);
        validate();
        repaint();
    }
    
    public Study getCurrentSubmission() {
        return mainFrame.getCurrentStudy();
    }
    
    public void update(Observable o, Object arg) {
        Study s = (Study)o;
        addedSamplepanelsList.setListData(s.getSamplepanelArray());
        Object[] samplepanels = s.getSamplepanelArray();
        Object[] phenotypeValues = s.getPhenotypeValueArray();
        String[] labIDs = new String[samplepanels.length];
        for(int i = 0; i < samplepanels.length; i++) {
            labIDs[i] = ((Samplepanel)samplepanels[i]).getLabID();
        }
        String[] values = new String[phenotypeValues.length];
        for(int i = 0; i < phenotypeValues.length; i++) {
            values[i] = ((PhenotypeValue)phenotypeValues[i]).getPhenotypeValue();
        }
        overlapPanel.setSamplepanels(labIDs);
        phenotypeValuePanel.setPhenotypeValues(values);
        validate();
        repaint();
    }
    
    public void clearForm() {
        addedSamplepanelsList.clearSelection();
        generalInfoPanel.clearForm();
        popInfoPanel.clearForm();
        otherInfoPanel.clearForm();
        overlapPanel.clearEntireForm();
    }
    
    public void fillForm(Samplepanel s) {
        generalInfoPanel.fillForm(s);
        popInfoPanel.fillForm(s);
        otherInfoPanel.fillForm(s);
        overlapPanel.fillForm(s);
    }
    
    public void switchPanel(int panel) {
        contentPanel.removeAll();
        if(panel == GENERAL) {
            contentPanel.add(generalInfoPanel, BorderLayout.NORTH);
        }
        else if(panel == POPULATION) {
            contentPanel.add(popInfoPanel, BorderLayout.NORTH);
        }
        else if(panel == OTHER) {
            contentPanel.add(otherInfoPanel, BorderLayout.NORTH);
        }
        else if(panel == OVERLAP) {
            contentPanel.add(overlapPanel, BorderLayout.NORTH);
        }
        else if(panel == PHENOTYPE_VALUES) {
            contentPanel.add(phenotypeValuePanel, BorderLayout.NORTH);
        }
        validate();
        repaint();
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        contentPanel = new javax.swing.JPanel();
        buttonPanel = new javax.swing.JPanel();
        eastPanel = new javax.swing.JPanel();
        clearButton = new javax.swing.JButton();
        deleteButton = new javax.swing.JButton();
        addModifyButton = new javax.swing.JButton();
        addedSamplepanelsPanel = new javax.swing.JPanel();
        jLabel2 = new javax.swing.JLabel();
        addedSamplepanelsScrollPane = new javax.swing.JScrollPane();
        addedSamplepanelsList = new javax.swing.JList();

        setLayout(new java.awt.BorderLayout());

        setBorder(javax.swing.BorderFactory.createTitledBorder("Sample-Panels: enter details of each main group of samples (called Sample-Panels) employed in this study"));
        contentPanel.setLayout(new java.awt.BorderLayout());

        contentPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Sample-Panel Details"));
        add(contentPanel, java.awt.BorderLayout.CENTER);

        buttonPanel.setLayout(new java.awt.BorderLayout());

        clearButton.setText("New Sample-Panel");
        clearButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                clearButtonActionPerformed(evt);
            }
        });

        eastPanel.add(clearButton);

        deleteButton.setText("Delete Sample-Panel");
        deleteButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteButtonActionPerformed(evt);
            }
        });

        eastPanel.add(deleteButton);

        addModifyButton.setText("Save Sample-Panel");
        addModifyButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addModifyButtonActionPerformed(evt);
            }
        });

        eastPanel.add(addModifyButton);

        buttonPanel.add(eastPanel, java.awt.BorderLayout.EAST);

        add(buttonPanel, java.awt.BorderLayout.SOUTH);

        addedSamplepanelsPanel.setLayout(new java.awt.GridBagLayout());

        addedSamplepanelsPanel.setBorder(javax.swing.BorderFactory.createTitledBorder("Added Sample-Panels"));
        jLabel2.setFont(new java.awt.Font("Microsoft Sans Serif", 0, 9));
        jLabel2.setForeground(new java.awt.Color(255, 51, 51));
        jLabel2.setText("Sample-Panels already entered (click entries to view and edit)");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTHWEST;
        gridBagConstraints.insets = new java.awt.Insets(1, 3, 3, 3);
        addedSamplepanelsPanel.add(jLabel2, gridBagConstraints);

        addedSamplepanelsScrollPane.setPreferredSize(new java.awt.Dimension(810, 80));
        addedSamplepanelsList.setBackground(new java.awt.Color(255, 255, 204));
        addedSamplepanelsList.addKeyListener(new java.awt.event.KeyAdapter() {
            public void keyPressed(java.awt.event.KeyEvent evt) {
                addedSamplepanelsListKeyPressed(evt);
            }
        });
        addedSamplepanelsList.addListSelectionListener(new javax.swing.event.ListSelectionListener() {
            public void valueChanged(javax.swing.event.ListSelectionEvent evt) {
                addedSamplepanelsListValueChanged(evt);
            }
        });

        addedSamplepanelsScrollPane.setViewportView(addedSamplepanelsList);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 1, 3);
        addedSamplepanelsPanel.add(addedSamplepanelsScrollPane, gridBagConstraints);

        add(addedSamplepanelsPanel, java.awt.BorderLayout.NORTH);

    }// </editor-fold>//GEN-END:initComponents

    private void addedSamplepanelsListKeyPressed(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_addedSamplepanelsListKeyPressed
        if(evt.getKeyCode() == java.awt.event.KeyEvent.VK_DELETE) {
            deleteSamplepanel();
        }
    }//GEN-LAST:event_addedSamplepanelsListKeyPressed

    private void deleteButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteButtonActionPerformed
        deleteSamplepanel();
    }//GEN-LAST:event_deleteButtonActionPerformed

    private void clearButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_clearButtonActionPerformed
        clearForm();
    }//GEN-LAST:event_clearButtonActionPerformed

    private void addedSamplepanelsListValueChanged(javax.swing.event.ListSelectionEvent evt) {//GEN-FIRST:event_addedSamplepanelsListValueChanged
        Samplepanel s = (Samplepanel)addedSamplepanelsList.getSelectedValue();
        if(s != null) {
            fillForm(s);
        }
    }//GEN-LAST:event_addedSamplepanelsListValueChanged

    private void addModifyButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addModifyButtonActionPerformed
        Samplepanel s = new Samplepanel();
        //Assayedpanel a = new Assayedpanel();  //The complete subset of this sampleset
        try {
            s.setLabID(generalInfoPanel.getLabID());
            //a.setLabname(generalInfoPanel.getLabID());
            //a.setSampleset(generalInfoPanel.getLabID());
            //a.setPhenotypeCriteria("Complete subset");
            s.setComposition(generalInfoPanel.getComposition());
            //a.setComposition(generalInfoPanel.getComposition());
            s.setSourceOfDNA(generalInfoPanel.getSourceOfDNA());
            s.setDnasArePooled(generalInfoPanel.getDNAIsPooled());
            s.setDnasAreWGA(generalInfoPanel.getDNAIsWGA());
            s.setNrOfIndividuals(generalInfoPanel.getNrOfIndividuals());
            //a.setNrOfIndividuals(generalInfoPanel.getNrOfIndividuals());
            s.setNrOfMales(generalInfoPanel.getNrOfMales());
            //a.setNrOfMales(generalInfoPanel.getNrOfMales());
            s.setNrOfFemales(generalInfoPanel.getNrOfFemales());
            //a.setNrOfFemales(generalInfoPanel.getNrOfFemales());
            s.setNrOfProbands(generalInfoPanel.getNrOfProbands());
            //a.setNrOfProbands(generalInfoPanel.getNrOfProbands());
            s.setNrOfParents(generalInfoPanel.getNrOfParents());
            //a.setNrOfParents(generalInfoPanel.getNrOfParents());
            s.setSummaryDescription(generalInfoPanel.getSummaryDescription());
            //a.setDescription(generalInfoPanel.getSummaryDescription());
            s.setPopulationInfo(popInfoPanel.getPopulationInformation());
            s.setGeographicRegionInfo(popInfoPanel.getGeographicRegionInformation());
            s.setEthnicityInfo(popInfoPanel.getEthnicityInformation());
            s.setBirthplaceInfo(popInfoPanel.getBirthplaceInformation());
            s.setAdmixtureInfo(popInfoPanel.getAdmixtureInformation());
            s.setEnvironmentInfo(popInfoPanel.getEnvironmentInformation());
            //a.setEnvironmentCriteria(popInfoPanel.getEnvironmentInformation());
            s.setModeOfRecruitment(otherInfoPanel.getModeOfRecruitment());
            s.setDiagnosisAgeRange(otherInfoPanel.getDiagnosisAgeRange());
            //a.setAgeInfo(otherInfoPanel.getDiagnosisAgeRange());
            s.setDiagnosisPeriod(otherInfoPanel.getDiagnosisPeriod());
            s.setSamplingAgeRange(otherInfoPanel.getSamplingAgeRange());
            s.setSamplingPeriod(otherInfoPanel.getSamplingPeriod());
            SamplepanelOverlap[] overlaps = overlapPanel.getSamplesetOverlaps();
            for(int i = 0; i < overlaps.length; i++) {
                s.addOverlap(overlaps[i]);
            }
            if(addedSamplepanelsList.getSelectedValue() == null) {
                mainFrame.getCurrentStudy().addSamplepanel(s);
                //mainFrame.getCurrentStudy().addAssayset(a);
                clearForm();
            }
            else {
                int answer = JOptionPane.showConfirmDialog(this,
                        "Do you wish to update the selected samplepanel?",
                        "Warning",
                        JOptionPane.WARNING_MESSAGE,
                        JOptionPane.YES_NO_OPTION);
                if(answer == JOptionPane.YES_OPTION) {
                    Samplepanel selectedSamplepanel = (Samplepanel)addedSamplepanelsList.getSelectedValue();
                    int id = selectedSamplepanel.getID();
                    mainFrame.getCurrentStudy().updateSamplepanel(s, id);
                    clearForm(); 
                }
            }
        }
        catch(FormatingException fe) {
            JOptionPane.showMessageDialog(this,
                fe.getMessage(),
                "Error",
                JOptionPane.ERROR_MESSAGE);
        }
    }//GEN-LAST:event_addModifyButtonActionPerformed
    
    private void deleteSamplepanel() {
        Samplepanel s = (Samplepanel)addedSamplepanelsList.getSelectedValue();
        if(s == null) {
            JOptionPane.showMessageDialog(this,
                "You have to select a samplepanel to be able to delete it.",
                "Error",
                JOptionPane.ERROR_MESSAGE);
        } else {
            int answer = JOptionPane.showConfirmDialog(this,
                    "Do you wish to permanently delete the selected samplepanel from the submission?",
                    "Warning",
                    JOptionPane.WARNING_MESSAGE,
                    JOptionPane.YES_NO_OPTION);
            if(answer == JOptionPane.YES_OPTION) {
                mainFrame.getCurrentStudy().deleteSamplepanel(s.getID());
                clearForm();    
            }
        }
    }
    
    private HGVbaseSubmissionTool mainFrame;
    private Samplepanel_GeneralInformationPanel generalInfoPanel;
    private Samplepanel_PopulationInformationPanel popInfoPanel;
    private Samplepanel_OtherInformationPanel otherInfoPanel;
    private Samplepanel_OverlapPanel overlapPanel;
    private Samplepanel_NumberWithPhenotypePanel phenotypeValuePanel;
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton addModifyButton;
    private javax.swing.JList addedSamplepanelsList;
    private javax.swing.JPanel addedSamplepanelsPanel;
    private javax.swing.JScrollPane addedSamplepanelsScrollPane;
    private javax.swing.JPanel buttonPanel;
    private javax.swing.JButton clearButton;
    private javax.swing.JPanel contentPanel;
    private javax.swing.JButton deleteButton;
    private javax.swing.JPanel eastPanel;
    private javax.swing.JLabel jLabel2;
    // End of variables declaration//GEN-END:variables
    
}
