/*
 * DbSNPAdapter.java
 *
 * Created on den 18 september 2006, 12:02
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package phenobase.handling;

import phenobase.data.*;
import phenobase.data.dbsnp.*;
import java.net.*;
import java.io.*;
import java.util.*;
import java.util.regex.*;
import javax.xml.parsers.*;
import org.w3c.dom.*;
import org.xml.sax.*;
import java.awt.*;
import javax.swing.*;

/**
 *
 * @author fredrik
 */
public class DBSNPAdapter {
    
    /** Creates a new instance of DbSNPAdapter */
    public DBSNPAdapter(JPanel panel) {
    }
    
    public Marker getMarker(String rsID, JPanel panel) throws MarkerException {
        Marker res = new Marker();
        res.setRsID(rsID);
        String id = rsID.substring(2);
        try {
            String address = "http://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi?db=snp&id=" + id + "&retmode=xml";
            URL url = new URL(address);
            URLConnection urlC = url.openConnection();
            InputStream is = url.openStream();
            BufferedReader reader = new BufferedReader(new InputStreamReader(is));
            StudyDOMParser parser = new StudyDOMParser();
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            DocumentBuilder builder = factory.newDocumentBuilder();
            Document doc = builder.parse(is);
            DBSNPMarker marker = parser.unmarshallDBSNPMarker(doc.getDocumentElement());
            if(marker.getID() == -1) {
                throw new MarkerException("Input Data Error: rsID did not exist");
            }
            String validation = "";
            if(marker.getByHapMap()) {
                validation = "HapMap";
                if(marker.getBy2Hit2()) {
                    validation = validation + ", double hit";
                }
                if(marker.getByOtherPop()) {
                    validation = validation + ", submitter";
                }
                if(marker.getByFreq()) {
                    validation = validation + ", freq";
                }
                if(marker.getByCluster()) {
                    validation = validation + ", cluster";
                }
            }
            else if(marker.getBy2Hit2()) {
                validation = "By double hit";
                if(marker.getByOtherPop()) {
                    validation = validation + ", submitter";
                }
                if(marker.getByFreq()) {
                    validation = validation + ", freq";
                }
                if(marker.getByCluster()) {
                    validation = validation + ", cluster";
                }
            }
            else if(marker.getByOtherPop()) {
                validation = "By submitter";
                if(marker.getByFreq()) {
                    validation = validation + ", freq";
                }
                if(marker.getByCluster()) {
                    validation = validation + ", cluster";
                }
            }
            else if(marker.getByFreq()) {
                validation = "By freq";
                if(marker.getByCluster()) {
                    validation = validation + ", cluster";
                }
            }
            else if(marker.getByCluster()) {
                validation = "By cluster";
            }
            else {
                validation = "No validation";
            }
            res.setValidation(validation);
            res.setSequenceType(marker.getType());
            String seq5 = marker.getSeq5();
            String up30bp = "";
            if(seq5.length() > 30) {
                up30bp = seq5.substring(seq5.length() - 30);
            }
            else {
                up30bp = seq5;
            }
            String seq3 = marker.getSeq3();
            String down30bp = "";
            if(seq3.length() > 30) {
                down30bp = seq3.substring(0, 30);
            }
            else {
                down30bp = seq3;
            }
            String alleles = marker.getAlleles();
            StringTokenizer strTok = new StringTokenizer(alleles, "//");
            Pattern p = Pattern.compile("^(\\(\\w+\\))\\d+.*");
            Matcher m = p.matcher(alleles);
            if(m.matches()) {
                Pattern p2 = Pattern.compile("\\(\\w+\\)(\\d+)");
                Pattern p3 = Pattern.compile("\\d+");
                while(strTok.hasMoreTokens()) {
                    String tmpAllele = strTok.nextToken();
                    String allele = "";
                    Matcher m2 = p2.matcher(tmpAllele);
                    Matcher m3 = p3.matcher(tmpAllele);
                    if(m2.matches()) {
                        allele = "" + m.group(1) + m2.group(1);
                    }
                    else if(m3.matches()) {
                        allele = "" + m.group(1) + tmpAllele;
                    }
                    else {
                        throw new MarkerException("Unknown allele sequence in Marker");
                    }
                    Allele a = new Allele();
                    a.setAlleleSequence(allele);
                    a.setUpstream30bp(up30bp);
                    a.setDownstream30bp(down30bp);
                    res.addAllele(a);
                }
            }
            else {
                while(strTok.hasMoreTokens()) {
                    Allele a = new Allele();
                    a.setAlleleSequence(strTok.nextToken());
                    a.setUpstream30bp(up30bp);
                    a.setDownstream30bp(down30bp);
                    res.addAllele(a);
                }
            }
        }
        catch(NullPointerException npe) {
            res = new Marker();
        }
        catch(InputDataException ide) {
            throw new MarkerException("Input Data Error: " + ide.getMessage());
        }
        catch(XMLException xmle) {
            throw new MarkerException("XML Error: " + xmle.getMessage());
        }
        catch(MalformedURLException urle) {
            throw new MarkerException("URL Error: " + urle.getMessage());
        }
        catch(IOException ioe) {
            throw new MarkerException("IO Error: " + ioe.getMessage());
        }
        catch(ParserConfigurationException pce) {
            throw new MarkerException("Parser Configuration Error: " + pce.getMessage());
        }
        catch(SAXException saxe) {
            throw new MarkerException("SAX Error: " + saxe.getMessage());
        }        
        return res;
    }
    
}
