/*
 * DOMParserPhenobaseHandler.java
 *
 * Created on den 1 april 2005, 14:02
 */

package phenobase.handling;

import org.w3c.dom.*;
import phenobase.data.*;
import phenobase.storage.*;
import phenobase.data.pubmed.*;
import phenobase.data.dbsnp.*;
import java.util.*;

/**
 *
 * @author fresjo
 */
public class StudyDOMParser {
    
    /** Creates a new instance of DOMParserPhenobaseHandler */
    public StudyDOMParser() {
        s = new Study();
    }

    public Study unmarshallStudy(Node rootNode) throws XMLException {
        Node n;
	NodeList nodes = rootNode.getChildNodes();	
        for(int i=0; i<nodes.getLength(); i++) {
	    n = nodes.item(i);
	    if(n.getNodeType() == Node.ELEMENT_NODE) {
		if(n.getNodeName().equals("researcher")) {
                    try {
                        Researcher r = unmarshallResearcher(n);
                        s.addResearcher(r);
                    }
                    catch(XMLException exception) {
                        throw exception;
                    }
                } 
                else if(n.getNodeName().equals("citation")) {
                    try {
                        Citation c = unmarshallCitation(n);
                        s.addCitation(c);
                    }
                    catch(XMLException exception) {
                        throw exception;
                    }
                } 
                else if(n.getNodeName().equals("samplepanel")) {
                    try {
                        Samplepanel sp = unmarshallSamplepanel(n);
                        s.addSamplepanel(sp);
                    }
                    catch(XMLException exception) {
                        throw exception;
                    }
                }
                else if(n.getNodeName().equals("assayedpanel")) {
                    try {
                        Assayedpanel a = unmarshallAssayedpanel(n);
                        s.addAssayedpanel(a);
                    }
                    catch(XMLException exception) {
                        throw exception;
                    }
                }
                else if(n.getNodeName().equals("phenotypeProperty")) {
                    try {
                        PhenotypeProperty pp = unmarshallPhenotypeProperty(n);
                        s.addPhenotypeProperty(pp);
                    }
                    catch(XMLException exception) {
                        throw exception;
                    }
                }
                else if(n.getNodeName().equals("phenotypeMethod")) {
                    try {
                        PhenotypeMethod pm = unmarshallPhenotypeMethod(n);
                        s.addPhenotypeMethod(pm);
                    }
                    catch(XMLException exception) {
                        throw exception;
                    }
                }
                else if(n.getNodeName().equals("phenotypeValue")) {
                    try {
                        PhenotypeValue pv = unmarshallPhenotypeValue(n);
                        s.addPhenotypeValue(pv);
                    }
                    catch(XMLException exception) {
                        throw exception;
                    }
                }
                else if(n.getNodeName().equals("marker")) {
                    try {
                        Marker m = unmarshallMarker(n);
                        s.addMarker(m);
                    }
                    catch(XMLException exception) {
                        throw exception;
                    }
                }
                else if(n.getNodeName().equals("oligo")) {
                    try {
                        Oligo o = unmarshallOligo(n);
                        s.addOligo(o);
                    }
                    catch(XMLException exception) {
                        throw exception;
                    }
                }
                else if(n.getNodeName().equals("assay")) {
                    try {
                        Assay a = unmarshallAssay(n);
                        s.addAssay(a);
                    }
                    catch(XMLException exception) {
                        throw exception;
                    }
                }
                else {
		    // unexpected element in Phenobase
		}
	    } else {
		// unexpected node-type in Catalog
	    }
	}
        return s;
    }
     
    public Researcher unmarshallResearcher(Node researcherNode) throws XMLException {
        Researcher r = new Researcher();
        Node n;
        NodeList nodes = researcherNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i);
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("firstName")) {
                    r.setFirstName(unmarshallText(n));
                }
                else if(n.getNodeName().equals("otherNames")) {
                    r.setOtherNames(unmarshallText(n));
                }    
                else if(n.getNodeName().equals("lastName")) {
                    r.setLastName(unmarshallText(n));
                }  
                else if(n.getNodeName().equals("department")) {
                    r.setDepartment(unmarshallText(n));
                }  
                else if(n.getNodeName().equals("institution")) {
                    r.setInstitution(unmarshallText(n));
                }  
                else if(n.getNodeName().equals("address")) {
                    r.setAddress(unmarshallText(n));
                }  
                else if(n.getNodeName().equals("phone")) {
                    r.setPhone(unmarshallText(n));
                }
                else if(n.getNodeName().equals("fax")) {
                    r.setFax(unmarshallText(n));
                }  
                else if(n.getNodeName().equals("email")) {
                    r.setEmail(unmarshallText(n));
                }
                else if(n.getNodeName().equals("www")) {
                    r.setWWW(unmarshallText(n));
                }
                else if(n.getNodeName().equals("isAuthor")) {
                    if(unmarshallText(n).equals("true")) {
                        r.setIsAuthor(true);
                    }
                }
                else if(n.getNodeName().equals("isCorrespondingAuthor")) {
                    if(unmarshallText(n).equals("true")) {
                        r.setIsCorrespondingAuthor(true);
                    }
                }
            }
            else {
                // unexpected node-type in Citation
            }
        }
        return r;
    }
        
    public PubMedCitation unmarshallPubmedCitaion(Node pubMedNode) throws XMLException {
        PubMedCitation c = new PubMedCitation();
        Node n;
        NodeList nodes = pubMedNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i);
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("PubmedArticle")) {
                    c = unmarshallPubmedArticle(n);
                }
            }
            else {
                // unexpected node-type in Citation
            }
        }
        return c;
    }
    
    public DBSNPMarker unmarshallDBSNPMarker(Node dbSNPNode) throws XMLException {
        DBSNPMarker m = new DBSNPMarker();
        Node n;
        NodeList nodes = dbSNPNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i);
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("Rs")) {
                    m = unmarshallRs(n);
                }
            }
            else {
                // unexpected node-type in Citation
            }
        }
        return m;
    }
    
    private DBSNPMarker unmarshallRs(Node rsNode) throws XMLException {
        DBSNPMarker m = new DBSNPMarker();
        Node n;
        NodeList nodes = rsNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i);
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("Rs_rsId")) {
                    m.setID(Integer.parseInt(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("Rs_molType")) {
                    m.setType(unmarshallAttribute(n, "value", ""));
                }
                else if(n.getNodeName().equals("Rs_validation")) {
                    unmarshallValidation(n, m);
                }
                else if(n.getNodeName().equals("Rs_sequence")) {
                    unmarshallRsSequence(n, m);
                }
            }
            else {
                // unexpected node-type in Citation
            }
        }
        return m;
    }
    
    private void unmarshallValidation(Node validationNode, DBSNPMarker marker) throws XMLException {
        Node n;
        NodeList nodes = validationNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i);
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("Rs_validation_byCluster")) {
                    if(unmarshallAttribute(n, "value", "").equals("true")) {
                        marker.setByCluster(true);
                    }
                }
                else if(n.getNodeName().equals("Rs_validation_byFrequency")) {
                    if(unmarshallAttribute(n, "value", "").equals("true")) {
                        marker.setByFreq(true);
                    }
                }
                else if(n.getNodeName().equals("Rs_validation_byHapMap")) {
                    if(unmarshallAttribute(n, "value", "").equals("true")) {
                        marker.setByHapMap(true);
                    }
                }
                else if(n.getNodeName().equals("Rs_validation_byOtherPop")) {
                    if(unmarshallAttribute(n, "value", "").equals("true")) {
                        marker.setByOtherPop(true);
                    }
                }
                else if(n.getNodeName().equals("Rs_validation_by2Hit2Allele")) {
                    if(unmarshallAttribute(n, "value", "").equals("true")) {
                        marker.setBy2Hit2(true);
                    }
                }
            }
            else {
                // unexpected node-type in Citation
            }
        }
    }
    
    private void unmarshallRsSequence(Node validationNode, DBSNPMarker marker) throws XMLException {
        Node n;
        NodeList nodes = validationNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i);
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("Rs_sequence_seq5")) {
                    marker.setSeq5(unmarshallText(n));
                }
                else if(n.getNodeName().equals("Rs_sequence_seq3")) {
                    marker.setSeq3(unmarshallText(n));
                }
                else if(n.getNodeName().equals("Rs_sequence_observed")) {
                    marker.setAlleles(unmarshallText(n));
                }
            }
            else {
                // unexpected node-type in Citation
            }
        }
    }
    
    private Citation unmarshallCitation(Node citationNode) throws XMLException {
        Citation c = new Citation();
        Node n;
        NodeList nodes = citationNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("citationID")) {
                    c.setID(Integer.parseInt(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("pubMedID")) {
                    c.setPubMedID(Integer.parseInt(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("citationDetail")) {
                    c.setCitationDetail(unmarshallText(n));
                }
                else if(n.getNodeName().equals("title")) {
                    c.setTitle(unmarshallText(n));
                }
                else if(n.getNodeName().equals("author")) {
                    c.addAuthor(unmarshallText(n));
                }
                else if(n.getNodeName().equals("meshTerm")) {
                    c.addMeshTerm(unmarshallText(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return c;
    }
    
    private Samplepanel unmarshallSamplepanel(Node samplepanelNode) throws XMLException {
        Samplepanel s = new Samplepanel();
        Node n;
        NodeList nodes = samplepanelNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("labID4Samplepanel")) {
                    s.setLabID(unmarshallText(n));
                }
                else if(n.getNodeName().equals("composition")) {
                    s.setComposition(unmarshallText(n));
                }
                else if(n.getNodeName().equals("nrOfIndividuals")) {
                    if(!unmarshallText(n).equals("")) {
                        s.setNrOfIndividuals(Integer.parseInt(unmarshallText(n)));
                    }
                    else {
                        s.setNrOfIndividuals(-1);
                    }
                }
                else if(n.getNodeName().equals("nrOfMales")) {
                    if(!unmarshallText(n).equals("")) {
                        s.setNrOfMales(Integer.parseInt(unmarshallText(n)));
                    }
                    else {
                        s.setNrOfMales(-1);
                    }
                }
                else if(n.getNodeName().equals("nrOfFemales")) {
                    if(!unmarshallText(n).equals("")) {
                        s.setNrOfFemales(Integer.parseInt(unmarshallText(n)));
                    }
                    else {
                        s.setNrOfFemales(-1);
                    }
                }
                else if(n.getNodeName().equals("nrOfProbands")) {
                    if(!unmarshallText(n).equals("")) {
                        s.setNrOfProbands(Integer.parseInt(unmarshallText(n)));
                    }
                    else {
                        s.setNrOfProbands(-1);
                    }
                }
                else if(n.getNodeName().equals("nrOfParents")) {
                    if(!unmarshallText(n).equals("")) {
                        s.setNrOfParents(Integer.parseInt(unmarshallText(n)));
                    }
                    else {
                        s.setNrOfParents(-1);
                    }
                }
                else if(n.getNodeName().equals("modeOfRecruitment")) {
                    s.setModeOfRecruitment(unmarshallText(n));
                }
                else if(n.getNodeName().equals("diagnosisAgeRange")) {
                    s.setDiagnosisAgeRange(unmarshallText(n));
                }
                else if(n.getNodeName().equals("diagnosisPeriod")) {
                    s.setDiagnosisPeriod(unmarshallText(n));
                }
                else if(n.getNodeName().equals("samplingAgeRange")) {
                    s.setSamplingAgeRange(unmarshallText(n));
                }
                else if(n.getNodeName().equals("samplingPeriod")) {
                    s.setSamplingPeriod(unmarshallText(n));
                }
                else if(n.getNodeName().equals("populationInfo")) {
                    s.setPopulationInfo(unmarshallText(n));
                }
                else if(n.getNodeName().equals("geographicRegionInfo")) {
                    s.setGeographicRegionInfo(unmarshallText(n));
                }
                else if(n.getNodeName().equals("ethnicityInfo")) {
                    s.setEthnicityInfo(unmarshallText(n));
                }
                else if(n.getNodeName().equals("birthplaceInfo")) {
                    s.setBirthplaceInfo(unmarshallText(n));
                }
                else if(n.getNodeName().equals("admixtureInfo")) {
                    s.setAdmixtureInfo(unmarshallText(n));
                }
                else if(n.getNodeName().equals("environmentInfo")) {
                    s.setEnvironmentInfo(unmarshallText(n));
                }
                else if(n.getNodeName().equals("summaryDescription")) {
                    s.setSummaryDescription(unmarshallText(n));
                }
                else if(n.getNodeName().equals("dnasArePooled")) {
                    s.setDnasArePooled(unmarshallText(n));
                }
                else if(n.getNodeName().equals("dnasAreWGA")) {
                    s.setDnasAreWGA(unmarshallText(n));
                }
                else if(n.getNodeName().equals("samplepanelOverlap")) {
                    s.addOverlap(unmarshallSamplepanelOverlap(n));
                }
                else if(n.getNodeName().equals("numberWithPhenotype")) {
                    s.addNumberWithPhenotype(unmarshallNumberWithPhenotype(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return s;
    }
    
   public SamplepanelOverlap unmarshallSamplepanelOverlap(Node samplepanelOverlapNode) throws XMLException {
       SamplepanelOverlap so = new SamplepanelOverlap();
       Node n;
       NodeList nodes = samplepanelOverlapNode.getChildNodes();
       for(int i = 0; i < nodes.getLength(); i++) {
           n = nodes.item(i);
           if(n.getNodeType() == Node.ELEMENT_NODE) {
               if(n.getNodeName().equals("labID4Samplepanel")) {
                   so.setLabID(unmarshallText(n));
               }
               else if(n.getNodeName().equals("overlapDetails")) {
                   so.setOverlapDetails(unmarshallText(n));
               }
           }
           else {
               //Unexpected node type in samplesetOverlap 
           }
       }
       return so;
   }
   
   public NumberWithPhenotype unmarshallNumberWithPhenotype(Node nrWithPhenotypeNode) throws XMLException {
       NumberWithPhenotype np = new NumberWithPhenotype();
       Node n;
       NodeList nodes = nrWithPhenotypeNode.getChildNodes();
       for(int i = 0; i < nodes.getLength(); i++) {
           n = nodes.item(i);
           if(n.getNodeType() == Node.ELEMENT_NODE) {
               if(n.getNodeName().equals("phenotypeValue")) {
                   np.setPhenotypeValue(unmarshallText(n));
               }
               else if(n.getNodeName().equals("nrOfIndividuals")) {
                   np.setNrOfIndividuals(Integer.parseInt(unmarshallText(n)));
               }
           }
           else {
               //Unexpected node type in samplesetOverlap 
           }
       }
       return np;
   }
 
    public PhenotypeProperty unmarshallPhenotypeProperty(Node phenotypeGeneralNode) throws XMLException {
        PhenotypeProperty pg = new PhenotypeProperty();
        Node n;
        NodeList nodes = phenotypeGeneralNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i);
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("propertyName")) {
                    pg.setPropertyName(unmarshallText(n));
                }
                else if(n.getNodeName().equals("comment")) {
                    pg.setComment(unmarshallText(n));
                }    
                else if(n.getNodeName().equals("keyword")) {
                    pg.addKeyword(unmarshallText(n));
                }  
                else if(n.getNodeName().equals("diseaseArea")) {
                    pg.addDiseaseArea(unmarshallText(n));
                }
                else if(n.getNodeName().equals("anatomicScale")) {
                    pg.addAnatomicScale(unmarshallText(n));
                }
                else if(n.getNodeName().equals("subphenotype")) {
                    pg.addSubphenotype(unmarshallText(n));
                }
                else if(n.getNodeName().equals("citation")) {
                    pg.addCitation(s.getCitationWithID(Integer.parseInt(unmarshallText(n))));
                }
            }
            else {
                // unexpected node-type in Citation
            }
        }
        return pg;
    }

    public PhenotypeMethod unmarshallPhenotypeMethod(Node phenotypeMethodNode) throws XMLException {
        PhenotypeMethod pm = new PhenotypeMethod();
        try {
            Node n;
            NodeList nodes = phenotypeMethodNode.getChildNodes();
            for(int i = 0; i < nodes.getLength(); i++) {
                n = nodes.item(i);
                if(n.getNodeType() == Node.ELEMENT_NODE) {
                    if(n.getNodeName().equals("methodName")) {
                        pm.setMethodName(unmarshallText(n));
                    }
                    else if(n.getNodeName().equals("phenotype")) {
                        pm.setPhenotypeName(unmarshallText(n));
                    }    
                    else if(n.getNodeName().equals("sampleType")) {
                        pm.setSampleType(unmarshallText(n));
                    }    
                    else if(n.getNodeName().equals("resultType")) {
                        pm.setResultType(unmarshallText(n));
                    }
                    else if(n.getNodeName().equals("circumstance")) {
                        pm.setCircumstance(unmarshallText(n));
                    }
                    else if(n.getNodeName().equals("details")) {
                        pm.setDetails(unmarshallText(n));
                    }
                    else if(n.getNodeName().equals("timeInstant")) {
                        pm.setTimeInstant(unmarshallText(n));
                    }
                    else if(n.getNodeName().equals("timePeriod")) {
                        pm.setTimePeriod(unmarshallText(n));
                    }
                    else if(n.getNodeName().equals("keyword")) {
                        pm.addKeyword(unmarshallText(n));
                    }  
                    else if(n.getNodeName().equals("citation")) {
                        pm.addCitation(s.getCitationWithID(Integer.parseInt(unmarshallText(n))));
                    }
                }
                else {
                    // unexpected node-type in Citation
                }
            }
        }
        catch(PhenotypeMethodException pme) {
            System.out.println("XML contains values for both timeInstant and timePeriod");
        }
        return pm;
    }
    
    private Assayedpanel unmarshallAssayedpanel(Node assayedpanelNode) throws XMLException {
        Assayedpanel a = new Assayedpanel();
        Node n;
        NodeList nodes = assayedpanelNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("labID4Assayedpanel")) {
                    a.setLabID(unmarshallText(n));
                }
                else if(n.getNodeName().equals("nrOfIndividuals")) {
                    a.setNrOfIndividuals(Integer.parseInt(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("nrOfMales")) {
                    a.setNrOfMales(Integer.parseInt(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("nrOfFemales")) {
                    a.setNrOfFemales(Integer.parseInt(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("nrOfProbands")) {
                    a.setNrOfProbands(Integer.parseInt(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("nrOfParents")) {
                    a.setNrOfParents(Integer.parseInt(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("description")) {
                    a.setDescription(unmarshallText(n));
                }
                else if(n.getNodeName().equals("selectionCriteria")) {
                    a.addSelectionCriteria(unmarshallSelectionCriteria(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return a;
    }
    
    private SelectionCriteria unmarshallSelectionCriteria(Node selectionCriteriaNode) throws XMLException {
        SelectionCriteria s = new SelectionCriteria();
        Node n;
        NodeList nodes = selectionCriteriaNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("samplepanel")) {
                    s.setSamplepanelID(unmarshallText(n));
                }
                else if(n.getNodeName().equals("phenotypeCriteria")) {
                    s.setPhenotypeCriteria(unmarshallText(n));
                }
                else if(n.getNodeName().equals("environmentCriteria")) {
                    s.setEnvironmentCriteria(unmarshallText(n));
                }
                else if(n.getNodeName().equals("numberOfIndividuals")) {
                    s.setNrOfIndividuals(Integer.parseInt(unmarshallText(n)));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return s;
    }
    
    private PhenotypeValue unmarshallPhenotypeValue(Node phenotypeValueNode) throws XMLException {
        PhenotypeValue pv = new PhenotypeValue();
        Node n;
        NodeList nodes = phenotypeValueNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("phenotypeMethod")) {
                    pv.setPhenotypeMethod(unmarshallText(n));
                }
                else if(n.getNodeName().equals("value")) {
                    pv.setPhenotypeValue(unmarshallText(n));
                }
                else if(n.getNodeName().equals("phenotypeValueDetail")) {
                    pv.addPhenotypeValueDetail(unmarshallPhenotypeValueDetail(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return pv;
    }
    
    private PhenotypeValueDetail unmarshallPhenotypeValueDetail(Node phenotypeValueDetailNode) throws XMLException {
        PhenotypeValueDetail pvd = new PhenotypeValueDetail();
        Node n;
        NodeList nodes = phenotypeValueDetailNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("attribute")) {
                    pvd.setAttribute(unmarshallText(n));
                }
                else if(n.getNodeName().equals("value")) {
                    pvd.setPhenotypeValueDetail(unmarshallText(n));
                }
                else if(n.getNodeName().equals("qualifier")) {
                    pvd.setQualifier(unmarshallText(n));
                }
                else if(n.getNodeName().equals("unitOfMeasurement")) {
                    pvd.setUnitOfMeasurement(unmarshallText(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return pvd;
    }
    
    private Marker unmarshallMarker(Node markerNode) throws XMLException {
        Marker m = new Marker();
        Node n;
        NodeList nodes = markerNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("rsID")) {
                    m.setRsID(unmarshallText(n));
                }
                else if(n.getNodeName().equals("markerID")) {
                    m.setMarkerID(unmarshallText(n));
                }
                else if(n.getNodeName().equals("validation")) {
                    m.setValidation(unmarshallText(n));
                }
                else if(n.getNodeName().equals("sequenceType")) {
                    m.setSequenceType(unmarshallText(n));
                }
                else if(n.getNodeName().equals("allele")) {
                    m.addAllele(unmarshallAllele(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return m;
    }
    
    private Allele unmarshallAllele(Node alleleNode) throws XMLException {
        Allele a = new Allele();
        Node n;
        NodeList nodes = alleleNode.getChildNodes();
        try {
            for(int i = 0; i < nodes.getLength(); i++) {
                n = nodes.item(i); 
                if(n.getNodeType() == Node.ELEMENT_NODE) {
                    if(n.getNodeName().equals("alleleID")) {
                        a.setAlleleID(unmarshallText(n));
                    }
                    else if(n.getNodeName().equals("alleleSequence")) {
                        a.setAlleleSequence(unmarshallText(n));
                    }
                    else if(n.getNodeName().equals("sequenceType")) {
                        a.setSequenceType(unmarshallText(n));
                    }
                    else if(n.getNodeName().equals("downstream30bp")) {
                        a.setDownstream30bp(unmarshallText(n));
                    }
                    else if(n.getNodeName().equals("upstream30bp")) {
                        a.setUpstream30bp(unmarshallText(n));
                    }
                }
                else {
                    //Unexpected node type in sampleset
                }
            }
        }
        catch(InputDataException ide) {
            
        }
        return a;
    }   
    
    private GenotypeSignificance unmarshallGenotypeSignificance(Node genotypeSignificanceNode) throws XMLException {
        GenotypeSignificance g = new GenotypeSignificance();
        Node n;
        NodeList nodes = genotypeSignificanceNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("genotypeFrequencyClusterID1")) {
                    GenotypeFrequencyCluster gfc = s.getGenotypeFrequencyClusterWithID(Integer.parseInt(unmarshallText(n)));
                    g.setCluster1(gfc);
                }
                else if(n.getNodeName().equals("genotypeFrequencyClusterID2")) {
                    GenotypeFrequencyCluster gfc = s.getGenotypeFrequencyClusterWithID(Integer.parseInt(unmarshallText(n)));
                    g.setCluster2(gfc);
                }
                else if(n.getNodeName().equals("oddsRatioStatement")) {
                    String s = unmarshallText(n);
                    g.setOddsRatioStatement(s);
                }
                else if(n.getNodeName().equals("attributableRiskStatement")) {
                    String s = unmarshallText(n);
                    g.setAttributableRiskStatement(s);
                }
                else if(n.getNodeName().equals("statisticalMethod")) {
                    String s = unmarshallText(n);
                    g.setStatisticalMethod(s);
                }
                else if(n.getNodeName().equals("pValue")) {
                    g.setPValue(Float.parseFloat(unmarshallText(n)));
                }
            }
            else {
                    //Unexpected node type in sampleset
            }
        }
        return g;
    }
    
    private GenotypeFrequencyCluster unmarshallGenotypeFrequencyCluster(Node genotypeFrequencyClusterNode) throws XMLException {
        GenotypeFrequencyCluster g = new GenotypeFrequencyCluster();
        Node n;
        NodeList nodes = genotypeFrequencyClusterNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("assayedpanelID")) {
                    Assayedpanel a = s.getAssayedpanelWithID(Integer.parseInt(unmarshallText(n)));
                    g.setAssayedpanel(a);
                }
                else if(n.getNodeName().equals("marker")) {
                    Marker m = s.getMarkerWithID(Integer.parseInt(unmarshallText(n)));
                    g.setMarker(m);
                }
                else if(n.getNodeName().equals("nrGenotypedSamples")) {
                    g.setNrGenotypedSamples(Integer.parseInt(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("pValueHWE")) {
                    g.setPValueHWE(Float.parseFloat(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("genotypeFrequency")) {
                    g.addGenotypeFrequency(unmarshallGenotypeFrequency(n));
                }
            }
            else {
                    //Unexpected node type in sampleset
            }
        }
        return g;
    }
    
    private GenotypeFrequency unmarshallGenotypeFrequency(Node genotypeFrequencyNode) throws XMLException {
        GenotypeFrequency g = new GenotypeFrequency();
        Node n;
        NodeList nodes = genotypeFrequencyNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("genotypeCombo")) {
                    g.setGenotypeCombo(unmarshallText(n));
                }
                else if(n.getNodeName().equals("frequency")) {
                    g.setFrequency(Float.parseFloat(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("numberSamplesWithGenotype")) {
                    g.setNrSamples(Integer.parseInt(unmarshallText(n)));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return g;
    }    
    
    private AlleleSignificance unmarshallAlleleSignificance(Node alleleSignificanceNode) throws XMLException {
        AlleleSignificance a = new AlleleSignificance();
        Node n;
        NodeList nodes = alleleSignificanceNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("genotypeFrequencyClusterID1")) {
                    AlleleFrequencyCluster afc = s.getAlleleFrequencyClusterWithID(Integer.parseInt(unmarshallText(n)));
                    a.setCluster1(afc);
                }
                else if(n.getNodeName().equals("genotypeFrequencyClusterID2")) {
                    AlleleFrequencyCluster afc = s.getAlleleFrequencyClusterWithID(Integer.parseInt(unmarshallText(n)));
                    a.setCluster2(afc);
                }
                else if(n.getNodeName().equals("oddsRatioStatement")) {
                    String s = unmarshallText(n);
                    a.setOddsRatioStatement(s);
                }
                else if(n.getNodeName().equals("attributableRiskStatement")) {
                    String s = unmarshallText(n);
                    a.setAttributableRiskStatement(s);
                }
                else if(n.getNodeName().equals("statisticalMethod")) {
                    String s = unmarshallText(n);
                    a.setStatisticalMethod(s);
                }
                else if(n.getNodeName().equals("pValue")) {
                    a.setPValue(Float.parseFloat(unmarshallText(n)));
                }
            }
            else {
                    //Unexpected node type in sampleset
            }
        }
        return a;
    }
    
    private AlleleFrequencyCluster unmarshallAlleleFrequencyCluster(Node alleleFrequencyClusterNode) throws XMLException {
        AlleleFrequencyCluster afc = new AlleleFrequencyCluster();
        Node n;
        NodeList nodes = alleleFrequencyClusterNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("assayedpanelID")) {
                    Assayedpanel a = s.getAssayedpanelWithID(Integer.parseInt(unmarshallText(n)));
                    afc.setAssayedpanel(a);
                }
                else if(n.getNodeName().equals("marker")) {
                    Marker m = s.getMarkerWithID(Integer.parseInt(unmarshallText(n)));
                    afc.setMarker(m);
                }
                else if(n.getNodeName().equals("nrGenotypedSamples")) {
                    afc.setNrGenotypedSamples(Integer.parseInt(unmarshallText(n)));
                }
                else if(n.getNodeName().equals("alleleFrequency")) {
                    afc.addAlleleFrequency(unmarshallAlleleFrequency(n));
                }
            }
            else {
                    //Unexpected node type in sampleset
            }
        }
        return afc;
    }
    
    private AlleleFrequency unmarshallAlleleFrequency(Node alleleFrequencyNode) throws XMLException {
        AlleleFrequency af = new AlleleFrequency();
        Node n;
        NodeList nodes = alleleFrequencyNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("alleleCombo")) {
                    af.setAlleleCombo(unmarshallText(n));
                }
                else if(n.getNodeName().equals("frequency")) {
                    af.setFrequency(Float.parseFloat(unmarshallText(n)));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return af;
    }    
    
    private Oligo unmarshallOligo(Node oligoNode) throws XMLException {
        Oligo o = new Oligo();
        Node n;
        NodeList nodes = oligoNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("name")) {
                    o.setName(unmarshallText(n));
                }
                else if(n.getNodeName().equals("role")) {
                    o.setRole(unmarshallText(n));
                }
                else if(n.getNodeName().equals("sequence")) {
                    o.setSequence(unmarshallText(n));
                }
                else if(n.getNodeName().equals("modifications")) {
                    o.setModifications(unmarshallText(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return o;
    }
    
    private Assay unmarshallAssay(Node assayNode) throws XMLException {
        Assay a = new Assay();
        Node n;
        NodeList nodes = assayNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("name")) {
                    a.setName(unmarshallText(n));
                }
                else if(n.getNodeName().equals("type")) {
                    a.setMethodType(unmarshallText(n));
                }
                else if(n.getNodeName().equals("method")) {
                    a.setMethod(unmarshallText(n));
                }
                else if(n.getNodeName().equals("conditions")) {
                    a.setConditions(unmarshallText(n));
                }
                else if(n.getNodeName().equals("markerID")) {
                    Marker m = s.getMarkerWithID(Integer.parseInt(unmarshallText(n)));
                    a.addMarker(m);
                }
                else if(n.getNodeName().equals("oligoID")) {
                    Oligo o = s.getOligoWithID(Integer.parseInt(unmarshallText(n)));
                    a.addOligo(o);
                }
                else if(n.getNodeName().equals("citationID")) {
                    Citation c = s.getCitationWithID(Integer.parseInt(unmarshallText(n)));
                    a.addCitation(c);
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return a;
    }

    private PubMedCitation unmarshallPubmedArticle(Node pubmedArticleNode) throws XMLException {
        PubMedCitation c = new PubMedCitation();
        Node n;
        NodeList nodes = pubmedArticleNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("MedlineCitation")) {
                    c = unmarshallMedlineCitation(n);
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return c;
    }

   private PubMedCitation unmarshallMedlineCitation(Node medlineCitationNode) throws XMLException {
        PubMedCitation c = new PubMedCitation();
        Node n;
        NodeList nodes = medlineCitationNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("Article")) {
                    c.setArticle(unmarshallArticle(n));
                }
                else if(n.getNodeName().equals("MeshHeadingList")) {
                    c.setMeshTerms(unmarshallMeshHeadingList(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return c;
    } 

   private DataArray unmarshallMeshHeadingList(Node meshHeadingListNode) throws XMLException {
        DataArray a = new DataArray();
        Node n;
        NodeList nodes = meshHeadingListNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("MeshHeading")) {
                    a.add(unmarshallMeshHeading(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return a;
    } 
   
   private String unmarshallMeshHeading(Node meshHeadingNode) throws XMLException {
        String s = "";
        Node n;
        NodeList nodes = meshHeadingNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("DescriptorName")) {
                    s = unmarshallText(n);
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return s;
    } 
   
   private PubMedArticle unmarshallArticle(Node articleNode) throws XMLException {
        PubMedArticle a = new PubMedArticle();
        Node n;
        NodeList nodes = articleNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("Journal")) {
                    a.setJournal(unmarshallJournal(n));
                }
                else if(n.getNodeName().equals("AuthorList")) {
                    a.setAuthors(unmarshallAuthorList(n));
                }
                else if(n.getNodeName().equals("ArticleTitle")) {
                    a.setTitle(unmarshallText(n));
                }                
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return a;
    } 
   
   private PubMedJournal unmarshallJournal(Node journalNode) throws XMLException {
        PubMedJournal j = new PubMedJournal();
        Node n;
        NodeList nodes = journalNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("ISSN")) {
                    j.setISSN(unmarshallText(n));
                }
                else if(n.getNodeName().equals("JournalIssue")) {
                    j.setIssue(unmarshallIssue(n));
                }
                else if(n.getNodeName().equals("Title")) {
                    j.setTitle(unmarshallText(n));
                }
                else if(n.getNodeName().equals("ISOAbbreviation")) {
                    j.setAbbreviation(unmarshallText(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return j;
    } 
   
   private PubMedIssue unmarshallIssue(Node issueNode) throws XMLException {
        PubMedIssue i = new PubMedIssue();
        Node n;
        NodeList nodes = issueNode.getChildNodes();
        for(int j = 0; j < nodes.getLength(); j++) {
            n = nodes.item(j); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("Volume")) {
                    i.setVolume(unmarshallText(n));
                }
                else if(n.getNodeName().equals("Issue")) {
                    i.setIssue(unmarshallText(n));
                }
                else if(n.getNodeName().equals("PubDate")) {
                    i.setDate(unmarshallDate(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return i;
    } 
   
   private PubMedDate unmarshallDate(Node dateNode) throws XMLException {
        PubMedDate d = new PubMedDate();
        Node n;
        NodeList nodes = dateNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("Year")) {
                    d.setYear(unmarshallText(n));
                }
                else if(n.getNodeName().equals("Month")) {
                    d.setMonth(unmarshallText(n));
                }
                else if(n.getNodeName().equals("Day")) {
                    d.setDay(unmarshallText(n));
                }
                else if(n.getNodeName().equals("MedlineDate")) {
                    d.setMedlineDate(unmarshallText(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return d;
    } 
    
   private DataArray unmarshallAuthorList(Node authorListNode) throws XMLException {
        DataArray d = new DataArray();
        Node n;
        NodeList nodes = authorListNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("Author")) {
                    d.add(unmarshallAuthor(n));
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return d;
    }
   
   private String unmarshallAuthor(Node dateNode) throws XMLException {
        String s = "";
        Node n;
        NodeList nodes = dateNode.getChildNodes();
        for(int i = 0; i < nodes.getLength(); i++) {
            n = nodes.item(i); 
            if(n.getNodeType() == Node.ELEMENT_NODE) {
                if(n.getNodeName().equals("LastName")) {
                    s = s + unmarshallText(n);
                }
                else if(n.getNodeName().equals("Initials")) {
                    s = s + " " + unmarshallText(n);
                }
            }
            else {
                //Unexpected node type in sampleset
            }
        }
        return s;
    } 
   
    private String unmarshallText( Node textNode ) {
	StringBuffer buf = new StringBuffer();

	Node n;
	NodeList nodes = textNode.getChildNodes();

	for( int i=0; i<nodes.getLength(); i++ ){
	    n = nodes.item( i );

	    if( n.getNodeType() == Node.TEXT_NODE ) {
		buf.append( n.getNodeValue() );
	    }else{
		// expected a text-only node!
	    }
	}
	return buf.toString();
    }

    // -----

    private String unmarshallAttribute( Node node, 
    	String name, String defaultValue ){
	Node n = node.getAttributes().getNamedItem( name );
	return (n!=null)?(n.getNodeValue()):(defaultValue);
    }
    
    private Study s;
}
