#!perl

# $Id: Marker.pm 772 2008-06-23 17:37:28Z rcf8 $

=head1 NAME

HGVbaseG2Pmart::Test::Marker - Test module for marker data.


=head1 SYNOPSIS

=head1 DESCRIPTION

This module is run by the Test::Harness and used as a base class by a number of other test modules eg. StudyMarker,
PhenotypeMarker. When run on its own, it tests data retrieval from the Marker dataset.
When used as a base class, the 'before_test' method should be overridden so that the initial 
BioMart::Query object links to other datasets.

For example HGVbaseG2Pmart::Test::StudyMarker initialises the query object so it will filter on a specific study 
for each test. When control passes to the methods in HGVbaseG2Pmart::Test::Marker, $self->get_query will
get this predefined query.

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2Pmart::Test::Marker;
use strict;
use warnings;

use base qw(HGVbaseG2Pmart::Test);
use Test::More;
use Test::Exception;
use Data::Dumper qw(Dumper);

#overrides Marker method to set up query and description
sub before_test : Test(setup) {
	my $self = shift;
	my $query = $self->create_query;
	
	$query->setDataset("marker");
	$self->set_query($query);
	$self->add_attribute_page("marker","marker");
	$self->set_description("markers");
}

#sub _01_get_all_markers : Test(1) {
#	my $self = shift;
#	my $query = $self->get_query;
#		
#	$query->setDataset("marker");
#	
#	throws_ok { $self->execute_query } qr/No filters selected/, 'Prevents markers with no filter '.$self->get_description;
#}
#
#sub _02_check_specific_marker_by_non_hgvbase_id : Test(2) {
#	my $self = shift;
#	$self->filter_count_test('nonhgvmarkerid','nonhgvbaseid','check_specific_marker_by_non_hgvbaseid');
#	$self->before_test;
#	$self->filter_count_test('nonhgvmarkerid','multi_nonhgvbaseid','check_specific_marker_by_multi_non_hgvbaseid');
#}
#
#sub _03_check_specific_marker_by_hgvbase_id : Test(2) {
#	my $self = shift;
#	$self->filter_count_test('hgvmarkerid','hgvbaseid','check_specific_marker_by_non_hgvbaseid');
#	$self->before_test;
#	$self->filter_count_test('hgvmarkerid','multi_hgvbaseid','check_specific_marker_by_multi_non_hgvbaseid');
#}
#
#sub _04_check_markers_for_sourcedb : Test(2) {
#	my $self = shift;
#
#	$self->filter_count_test('marker_source','sourcedb1','check_markers_for_sourcedb');
#	$self->before_test;
#	$self->filter_count_test('marker_source','sourcedb2','check_markers_for_sourcedb');
#}
#
#sub _05_check_markers_for_variationtype : Test(3) {
#	my $self = shift;
#
#	$self->filter_count_test('variationtype','variationtype1','check_markers_for_variationtype');
#	$self->before_test;
#	$self->filter_count_test('variationtype','variationtype2','check_markers_for_variationtype');
#	$self->before_test;
#	$self->filter_count_test('variationtype','variationtype3','check_markers_for_variationtype');
#}

sub _06_check_markers_within_genes : Test(2) {
	my $self = shift;
	$self->filter_count_test('gene_stable_id','ensembl_gene_id','check_markers_within_genes_with_ensembl_id');
	$self->before_test;
	$self->filter_count_test('display_id','hgnc_gene_id','check_markers_within_genes_with_hgnc_id');
}

#sub _07_get_markers_for_gene_transcripts: Test(1) {
#	my $self = shift;
#	$self->filter_count_test('transcript_count','transcriptcount','get markers for gene transcripts >=');
#}
#
#sub _08_get_markers_for_5UTR: Test(2) {
#	my $self = shift;
#	$self->filter_count_test('with_5utr','with_5utr','get markers for genes with 5UTR');
#	$self->before_test;
#	$self->filter_count_test('with_5utr','without_5utr','get markers for genes with 5UTR');
#}
#
#sub _09_check_markers_for3UTR : Test(2) {
#	my $self = shift;
#	$self->filter_count_test('with_3utr','with_3utr','get markers for genes with 3UTR');
#	$self->before_test;
#	$self->filter_count_test('with_3utr','without_3utr','get markers for genes with 3UTR');
#}
#
#sub _10_check_markers_within_genetype : Test(1) {
#	my $self = shift;
#
#	$self->filter_count_test('biotype','genetype','get markers for genes of type');
#}
#
#sub _11_check_markers_in_chromosome : Test(1) {
#	my $self = shift;
#	$self->filter_count_test('chromosome_name','chromosome','check_markers_for_chromosome');
#}
#
#sub _12_check_markers_between_start_and_end : Test(1) {
#	my $self = shift;
#	$self->multi_filter_count_test(
#		['start','end'],
#		['range_start','range_end'],
#		'check_markers_between_start_and_end'
#	);
#}
#
#sub _13_check_markers_between_chr_bands : Test(1) {
#	my $self = shift;
#	$self->multi_filter_count_test(
#		['band_start','band_end'],
#		['bandstart','bandend'],
#		'check_markers_between_chr_band_start_and_end'
#	);
#}
#
#sub _14_check_markers_for_encode_region : Test(1) {
#	my $self = shift;
#	$self->filter_count_test('encode_region','encode_region','check_markers_with_encode_region');
#}
#
#sub _15_check_markers_for_encode_type : Test(1) {
#	my $self = shift;
#	$self->filter_count_test('type','encode_type','check_markers_with_encode_type');
#}

1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>

=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: Marker.pm 772 2008-06-23 17:37:28Z rcf8 $

=cut


