#!perl

# $Id: Phenotype.pm 268 2008-01-09 16:01:16Z rcf8 $

=head1 NAME

HGVbaseG2Pmart::Test::Phenotype - Test module for phenotype data


=head1 SYNOPSIS

=head1 DESCRIPTION

This module is run by the Test harness. It tests queries on phenotype data

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2Pmart::Test::Phenotype;
use strict;
use warnings;

use base qw(HGVbaseG2Pmart::Test);
use Test::More;

#overrides Marker method to set up query and description
sub check_phenotype_data : Test(5) {
	my $self = shift;
	my %testdata = $self->get_data;
	my $query = $self->create_query;
	
	$query->setDataset("phenotype");

	$query->addAttribute("methodname");
	$query->addAttribute("propertyname");
	$query->addAttribute("entityterm");
	$query->addAttribute("entity");
	$query->addAttribute("unitterm");
	$query->addAttribute("unit");
	$query->addAttribute("quality");
	$query->addAttribute("timeinstant");
	$query->addAttribute("qualityterm");
	$query->addAttribute("variabletype");
	$query->addAttribute("details");
	my $count = $self->get_executed_count;
	cmp_ok($count,'>=',1,"get all phenotypes ($count)");
	
	$query = $self->create_query;
	$query->setDataset("phenotype");
	$query->addAttribute("methodname");
	$query->addAttribute("propertyname");
	$query->addAttribute("variabletype");
	$query->addAttribute("details");
	$query->addFilter("methodname",[$testdata{phenotype1}]);		
	$count = $self->get_executed_count;
	cmp_ok($count,'>=',1,"get phenotypes with a non-wildcard specific method ($count)");
	
	SKIP: {
		skip "Change mart config so method name qualifier is Like",1;

		$query = $self->create_query;
		$query->setDataset("phenotype");
		$query->addAttribute("methodname");
		$query->addAttribute("propertyname");
		$query->addAttribute("variabletype");
		$query->addAttribute("details");	
		$query->addFilter("methodname",[$testdata{phenotype2}]);		
		$count = $self->get_executed_count;
		cmp_ok($count,'>=',1,"get phenotypes with a wild-card specific method $testdata{phenotype2} ($count)");
	}
	
	$query = $self->create_query;
	$query->setDataset("phenotype");
	$query->addAttribute("methodname");
	$query->addAttribute("propertyname");
	$query->addAttribute("variabletype");
	$query->addAttribute("details");
	$query->addFilter("propertyname",[$testdata{phenotypeprop1}]);		
	$count = $self->get_executed_count;
	cmp_ok($count,'>=',1,"get phenotypes with a non-wildcard specific property ($count)");
	
	SKIP: {
		skip "Change mart config so property name qualifier is Like",1;
		$query = $self->create_query;
		$query->setDataset("phenotype");
		$query->addAttribute("methodname");
		$query->addAttribute("propertyname");
		$query->addAttribute("variabletype");
		$query->addAttribute("details");	
		$query->addFilter("propertyname",[$testdata{phenotypeprop2}]);		
		$count = $self->get_executed_count;
		cmp_ok($count,'>=',1,"get phenotypes with a wild-card specific property ($count)");
	}
}
1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>

=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: Phenotype.pm 268 2008-01-09 16:01:16Z rcf8 $

=cut
