#!perl

# $Id: Samplepanel.pm 268 2008-01-09 16:01:16Z rcf8 $

=head1 NAME

HGVbaseG2Pmart::Test::Samplepanel - Test module for sample panel data

=head1 SYNOPSIS

=head1 DESCRIPTION

This module is run by the Test harness. It tests queries on Sample panel data

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2Pmart::Test::Samplepanel;
use strict;
use warnings;

use base qw(HGVbaseG2Pmart::Test);
use Test::More;

sub check_samplepanel_data : Test(7) {
	my $self = shift;
	my %testdata = $self->get_data;
	my $query = $self->create_query;
	
	$query->setDataset("samplepanel");

	$query->addAttribute("geographicregioninfo");
	$query->addAttribute("localid");
	$query->addAttribute("ethnicityinfo");
	$query->addAttribute("numberofsexmale");
	$query->addAttribute("numberofsexfemale");
	$query->addAttribute("totalnumberofindividuals");
	$query->addAttribute("composition");
	
	my $count = $self->get_executed_count;
	
	cmp_ok($count,'>=',1,"get all samplepanels ($count)");
	
	$query = $self->create_query;
	$query->setDataset("samplepanel");
	$query->addFilter("geographicregioninfo",[$testdata{geographicinfo}]);
	$query->addAttribute("geographicregioninfo");
	$query->addAttribute("localid");
	$query->addAttribute("ethnicityinfo");

	$count = $self->get_executed_count;
	
	cmp_ok($count,'>=',1,"get samplepanels for specific geographic region ($count)");
	
	$query = $self->create_query;
	$query->setDataset("samplepanel");
	$query->addFilter("ethnicityinfo",[$testdata{ethnicityinfo}]);
	$query->addAttribute("geographicregioninfo");
	$query->addAttribute("localid");
	$query->addAttribute("ethnicityinfo");

	$count = $self->get_executed_count;
	
	cmp_ok($count,'>=',1,"get samplepanels for specific ethnicity type ($count)");
	
	$query = $self->create_query;
	$query->setDataset("samplepanel");
	$query->addFilter("localid",[$testdata{panelid}]);
	$query->addAttribute("geographicregioninfo");
	$query->addAttribute("localid");
	$query->addAttribute("ethnicityinfo");

	$count = $self->get_executed_count;
	
	cmp_ok($count,'>=',1,"get specific panel ID ($count)");
	
	$query = $self->create_query;
	$query->setDataset("samplepanel");
	$query->addFilter("numberofsexmale_from",[$testdata{malesfrom}]);
	$query->addFilter("numberofsexmale_to",[$testdata{malesto}]);
	$query->addAttribute("geographicregioninfo");
	$query->addAttribute("localid");
	$query->addAttribute("ethnicityinfo");

	$count = $self->get_executed_count;
	cmp_ok($count,'>=',1,"get samplepanels for number of males ($count)");
	
	$query = $self->create_query;
	$query->setDataset("samplepanel");
	$query->addFilter("numberofsexfemale_from",[$testdata{femalesfrom}]);
	$query->addFilter("numberofsexfemale_to",[$testdata{femalesto}]);
	$query->addAttribute("geographicregioninfo");
	$query->addAttribute("localid");
	$query->addAttribute("ethnicityinfo");

	$count = $self->get_executed_count;
	
	cmp_ok($count,'>=',1,"get samplepanels for number of females ($count)");
	
	$query = $self->create_query;
	$query->setDataset("samplepanel");
	$query->addFilter("composition",[$testdata{composition}]);
	$query->addAttribute("geographicregioninfo");
	$query->addAttribute("localid");
	$query->addAttribute("ethnicityinfo");

	$count = $self->get_executed_count;$query->setDataset("samplepanel");
	cmp_ok($count,'>=',1,"get samplepanels for ".$testdata{composition}." composition ($count)");
}

sub check_study_data : Test(1) {
	my $self = shift;
	my %testdata = $self->get_data;
	my $query = $self->create_query;
	
	$query->setDataset("samplepanel");
	$query->addAttribute("geographicregioninfo");
	$query->addFilter("title",[$testdata{studytitle1}]);
	
	my $count = $self->get_executed_count;
	
	cmp_ok($count,'>=',1,"get samplepanel for specific study ($count)");
}
1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>

=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: Samplepanel.pm 268 2008-01-09 16:01:16Z rcf8 $

=cut
