#!perl

# $Id: SamplepanelMarker.pm 268 2008-01-09 16:01:16Z rcf8 $

=head1 NAME

HGVbaseG2Pmart::Test::SamplepanelMarker - Test module for link between samplepanel and marker data


=head1 SYNOPSIS

The module uses HGVbaseG2Pmart::Test::Marker as a base class but overrides
the before_test method. This means the tests running from the base class return 
markers for a specific sample panel.

There are also test methods unique to the module which do not do this. 

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2Pmart::Test::SamplepanelMarker;
use strict;
use warnings;

use base qw(HGVbaseG2Pmart::Test::Marker);
use Test::More;

#overrides method in HGVbaseG2Pmart::Test::Marker method to set up query and description
sub before_test : Test(setup) {
	my $self = shift;
	my %testdata = $self->get_data;
	my $query = $self->create_query;
	
	$query->setDataset("samplepanel");
	$query->addFilter("geographicregioninfo",[$testdata{geographicinfo}]);
	$query->addAttribute("geographicregioninfo");
	$query->addAttribute("localid");
	$query->addAttribute("ethnicityinfo");

	$self->set_query($query);
	$self->set_description("samplepanels with geography");
}

sub get_markers_for_all_samplepanels : Test(1) {
	my $self = shift;
	my %testdata = $self->get_data;
	my $query = $self->create_query;
	
	$query->setDataset("samplepanel");
	$query->addAttribute("geographicregioninfo");
	$query->addAttribute("localid");
	
	$query->setDataset("marker");
	$query->addAttribute("localid");
	
	my $count = $self->get_executed_count;
	
	cmp_ok($count,'>=',1,"get markers for all samplepanels ($count)");
}
1;