#!perl

# $Id: Study.pm 772 2008-06-23 17:37:28Z rcf8 $

=head1 NAME

HGVbaseG2Pmart::Test::Study - Test module for study data


=head1 SYNOPSIS

=head1 DESCRIPTION

This module is run by the Test harness. It tests queries on Study data

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2Pmart::Test::Study;
use strict;
use warnings;

use base qw(HGVbaseG2Pmart::Test);
use Test::More;
use Test::Exception;

#overrides Marker method to set up query and description
sub before_test : Test(setup) {
	my $self = shift;
	my $query = $self->create_query;
	
	$query->setDataset("study");
	$self->set_query($query);
	$self->add_attribute_page("study","study");
	$self->set_description("studies");
}

sub _01_check_all_studies : Test {
	my $self = shift;
	my $query = $self->get_query;
		
	$query->setDataset("study");
	
	throws_ok { $self->execute_query } qr/No filters selected/, "Prevents studies with no filter (attr page:".$self->get_description.")";
	
}

sub _02_check_study_id_filters : Tests(4) {
	my $self = shift;
	
	$self->filter_count_test('studyid','studyid','check_study_id_filter');
	$self->before_test;
	$self->filter_count_test('studyid','multistudyid','check_multi_study_id_filter');
	$self->before_test;
	$self->filter_count_test('StudyID','studyid','check_study_list_filter');
	$self->before_test;
	$self->filter_count_test('StudyID','multistudyid','check_multi_study_list_filter');
	
}

sub _03_check_submission_date_filter : Test {
	my $self = shift;
	$self->multi_filter_count_test(
		['submissiondate_month_from','submissiondate_month_to'],
		['datefrom','dateto'],
		"check_submission_date_filter"
	);
}

sub _04_check_author_name_filter : Test {
	my $self = shift;
	my $query = $self->get_query;
	$self->filter_count_test('shortname','shortname',"check_author_name_filter")
}

sub _05_check_al_significance_filters : Tests(3) {
    my $self = shift;
	$self->filter_count_test('aa_more_significant','aa_moresignificant','check_more_al_significant_than');
	$self->before_test;	
	$self->filter_count_test('aa_less_significant','aa_lesssignificant','check_less_al_significant_than');
	$self->before_test;
	$self->multi_filter_count_test(
		['aa_more_significant','aa_less_significant'],
		['aa_both_moresignificant','aa_both_lesssignificant'],
		'check_both_al_significant'
	);
}

sub _06_check_gt_significance_filters : Tests(3) {
    my $self = shift;
	$self->filter_count_test('ga_more_significant','ga_moresignificant','check_more_gt_significant_than');
	$self->before_test;
	$self->filter_count_test('ga_less_significant','ga_lesssignificant','check_less_gt_significant_than');
	$self->before_test;
	$self->multi_filter_count_test(
		['ga_more_significant','ga_less_significant'],
		['ga_both_moresignificant','ga_both_lesssignificant'],
		'check_both_gt_significant'
	);
}

1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>

=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: Study.pm 772 2008-06-23 17:37:28Z rcf8 $

=cut

