# $Id: DataElement.pm 1243 2009-07-15 11:48:35Z rob $

=head1 NAME

HGVbaseG2P::DataImport::DataElement - Class which stores various data for a single 'line' in a file


=head1 SYNOPSIS
	...
	my $element = HGVbaseG2P::DataElement->new;
	my ($marker,$status) = $rmarker->get_validated_marker('rs699');
	$element->marker($marker);
	$element->line($line);
	$element->status($status);


=head1 DESCRIPTION

A container class representing a single line in a file.
Contains accessors for marker (Bio::SeqFeature), line (arrayref of values), status (hashref), line_no (scalar), flip (0/1 flag)


=head1 SUBROUTINES/METHODS

=cut

package HGVbaseG2P::DataImport::DataElement;
{

	use strict;
	use warnings;

	# Use OIO inside-out object framework for our OO hierarachy
	use Object::InsideOut;
	use Object::InsideOut::Metadata;

	use English qw( -no_match_vars );

	# Private variables & constants
	my @marker : Field : All(marker); #marker data as BioSeqFeature
	my @line : Field : All(line); #arrayref of line data
	my @line_no : Field : All(line_no); #line number in file
	my @status : Field : All(status);  #contains RetrieveMarker object
	my @flip : Field : All(flip); #carry out strand-flip (1) or not (0/undef)

	sub _init :Init {
		my ($self)=@_;
		$self->status({});
	}
}
1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>


=head1 LICENCE AND COPYRIGHT

Copyright (c) <2009> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

=head1 SVNINFO

$Id: DataElement.pm 1243 2009-07-15 11:48:35Z rob $

=cut
