# $Id: Export.pm 1245 2009-07-15 11:50:03Z rob $

=head1 NAME

HGVbaseG2P::DataImport::Export - Base class for DataImport Export


=head1 SYNOPSIS

	use base qw(HGVbaseG2P::DataImport::Export);

	#overrides base export method
	sub output {
		my ($self, $lines);
		my @lines = @{$lines};
		... deal with batch of lines
	}


=head1 DESCRIPTION

Base class providing interface for Export modules. Generally the 'output' module must be overridden to deal with lines of data.
Other methods may be optionally overridden.


=head1 SUBROUTINES/METHODS

=cut

package HGVbaseG2P::DataImport::Export;
{

	use strict;
	use warnings;

	# Use OIO inside-out object framework for our OO hierarachy
	use Object::InsideOut qw(HGVbaseG2P::DataImport);
	use Object::InsideOut::Metadata;

	use English qw( -no_match_vars );
	use Data::Dumper;

	my @settings : Field : All(settings);
	my @panelnames : Field : All(panelnames);
	my @frequencies : Field : All(frequencies);
	my @associations : Field : All(associations);
	my @resultset_lookup : Field : All(resultset_lookup);
	my @resultset_field : Field : All(resultset_field);
	my @resultsets : Field : All(resultsets);
	my @template : Field : All(template);

	sub has_config { 0; }

	sub _init :Init {
		my ($self)=@_;
		$self->settings({});
		$self->panelnames([]);
	}

=head2 before

Run before all Exports have run (could be used to connect to a DB for instance)

=cut

	sub before {
	}

=head2 output

Outputs data to chosen data source (Database is the only option at the moment)

=cut

	sub output {
		my ($self,$lines)=@_;
		die "'output' method in Export ".ref($self)." not defined";
	}

=head2 rollback

Used by Database based export to rollback changes to the database

=cut

	sub rollback {
	}

=head2 commit

Used by Database based export to commit changes to the database

=cut

	sub commit {
	}

=head2 after

Run after all Exports have run (could be used to disconnect for instance)

=cut

	sub after {
	}
}
1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>


=head1 LICENCE AND COPYRIGHT

Copyright (c) <2009> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

=head1 SVNINFO

$Id: Export.pm 1245 2009-07-15 11:50:03Z rob $

=cut
