# $Id: Plugin.pm 1248 2009-07-15 11:55:06Z rob $

=head1 NAME

HGVbaseG2P::DataImport::Plugin - Base class for DataImport Plugin


=head1 SYNOPSIS

	use base qw(HGVbaseG2P::DataImport::Plugin);

	#overrides base process_before_marker method
	sub process_before_marker {
		my ($self,$element);
		my $line = $element->line;
		... do stuff with line
	}


=head1 DESCRIPTION

Plugins provide ways of adding additional DataImport to the DataImport pipeline.
They are added to the template as a space separated list:
e.g.
to load plugins named HGVbaseG2P::DataImport::Plugin::DoSomething and HGVbaseG2P::DataImport::Plugin::DoSomethingElse specify:

plugins = DoSomething DoSomethingElse

Plugins allow you to process row data at four key points using four methods. This module provides an interface for these methods.
Any can be overloaded as required.

before - usually used to set up something eg. a database connection, or a list from a file

process_before_marker - run before RetrieveMarker is called (for example this could be used to lookup rs IDs which are then added to the line)

process_after_marker - run after RetrieveMarker is called, but before the rules are called

after - usually used to deinitialise something eg. a disconnect from a database, close a file handle

=head1 SUBROUTINES/METHODS

=cut

package HGVbaseG2P::DataImport::Plugin;
{

	use strict;
	use warnings;

	# Use OIO inside-out object framework for our OO hierarachy
	use Object::InsideOut qw(HGVbaseG2P::DataImport);
	use Object::InsideOut::Metadata;

	use English qw( -no_match_vars );
	use Data::Dumper;

	sub has_config { 0; }

	sub before {

	}

	sub process_before_marker {

	}

	sub process_after_marker {

	}

	sub after {

	}
}
1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>


=head1 LICENCE AND COPYRIGHT

Copyright (c) <2009> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

=head1 SVNINFO

$Id: Plugin.pm 1248 2009-07-15 11:55:06Z rob $

=cut