# $Id: PopulateGenotypesFromAlleles.pm 1248 2009-07-15 11:55:06Z rob $

=head1 NAME

HGVbaseG2P::DataImport::PopulateGenotypesFromAlleles - Rule to determine genotypes using alleles


=head1 SYNOPSIS
	
	my $rule = $lmaker->import_rule('PopulateGenotypesFromAlleles');
	

=head1 DESCRIPTION

Uses provided alleles fields to build genotypes (e.g. A and T become (A), (A)+(T) and (T).

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2P::DataImport::Rule::PopulateGenotypesFromAlleles;
{

	use strict;
	use warnings;

	# Use OIO inside-out object framework for our OO hierarachy
	use Object::InsideOut qw(HGVbaseG2P::DataImport::Rule);
	use Object::InsideOut::Metadata;
	use Data::Dumper qw(Dumper);
	
	sub run {
		my($self, $element)=@_;
		my $line = $element->line;
		
		my $allele1 = $line->{"allele1"};
		my $allele2 = $line->{"allele2"};
		
		$line->{genotype11}="($allele1)";
		$line->{genotype12}="($allele1)+($allele2)";
		$line->{genotype22}="($allele2)";
	}
}
1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>


=head1 LICENCE AND COPYRIGHT

Copyright (c) <2009> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 SVNINFO

$Id: PopulateGenotypesFromAlleles.pm 1248 2009-07-15 11:55:06Z rob $ 

=cut