# $Id: StrandFlip.pm 1248 2009-07-15 11:55:06Z rob $

=head1 NAME

HGVbaseG2P::DataImport::Rule::StrandFlip - Base class for DataImport Strandflip Rule


=head1 SYNOPSIS

	use base qw(HGVbaseG2P::DataImport::Rule::StrandFlip);

	#overrides base Rule method
	sub run {
		my ($self,$element);
		my $line = $element->line;
		... determine whether to flip.. and
		$self->strand_flip($line);
	}


=head1 DESCRIPTION

Provides a common strand_flip method which is used to flip alleles in 'allele1' and 'allele2'. Various child modules based on this class provide differnet
functionalities. The StrandFlip child module used is determined by the LogicMaker module.

=head1 SUBROUTINES/METHODS

=cut

package HGVbaseG2P::DataImport::Rule::StrandFlip;
{

	use strict;
	use warnings;

	# Use OIO inside-out object framework for our OO hierarachy
	use Object::InsideOut qw(HGVbaseG2P::DataImport::Rule);
	use Object::InsideOut::Metadata;
	use List::Compare;

	use Data::Dumper qw(Dumper);

=head2 strand_flip

  Usage      : $self->strand_flip($line);
  Purpose    : Flips alleles in DataElement line
  Returns    : Nowt
  Arguments  : DataElement line
  Throws     :
  Status     :
  Comments   :

=cut

	sub strand_flip {
		my ($self, $line) = @_;

		my $allele1 = $line->{allele1};
		my $allele2 = $line->{allele2};
		$self->log->debug("before REVCOM:$allele1=>$allele2");
		print Dumper("before REVCOM:$allele1=>$allele2")
		my $a1_revcom = $self->revcom($allele1);
		my $a2_revcom = $self->revcom($allele2);
		$allele1 = $a1_revcom;
		$allele2 = $a2_revcom;
		$self->log->debug( "after REVCOM:" . "$allele1,$allele2" );
		print Dumper("After REVCOM:$allele1=>$allele2");
		$line->{allele1}=$a1_revcom;
		$line->{allele2}=$a2_revcom;
	}

=head2 revcom

  Usage      : my $allele_revcom = $self->revcom($a1);
  Purpose    : To reverse complement a sequence
  Returns    : a scalar string
  Arguments  : a string of DNA
  Throws     :
  Status     :
  Comments   : * To Do, add the UPAC codes *

=cut

	sub revcom {
		## Reverse compliment a DNA sequence.
		my ( $self, $str ) = @_;
		$str =~ tr/acgtnACGTN/tgcanTGCAN/;
		$str = reverse $str;
		return ($str);
	}

	sub get_ref_strand {

		my ( $strand_info ) = @_;
		my $strand;

		if ( $strand_info ) {
			if ( $strand_info eq "+" ) {
				$strand = "1";
			}
			elsif ( $strand_info eq "-" ) {
				$strand = "-1";
			}
		}

		return $strand;

	}

}
1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>


=head1 LICENCE AND COPYRIGHT

Copyright (c) <2009> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

=head1 SVNINFO

$Id: StrandFlip.pm 1248 2009-07-15 11:55:06Z rob $

=cut