# $Id: Custom.pm 1248 2009-07-15 11:55:06Z rob $

=head1 NAME

HGVbaseG2P::DataImport::Rule::StrandFlip::Custom - Strand flipping depending on 'flip' flag in element


=head1 SYNOPSIS
	
	my $rule = $lmaker->import_rule('StrandFlip::Custom');
	

=head1 DESCRIPTION

Flips the alleles if the 'flip' flag is set to 1 in the DataElement.

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2P::DataImport::Rule::StrandFlip::Custom;
{

	use strict;
	use warnings;

	# Use OIO inside-out object framework for our OO hierarachy
	use Object::InsideOut qw(HGVbaseG2P::DataImport::Rule::StrandFlip);
	use Object::InsideOut::Metadata;
	use List::Compare;
	
	use Data::Dumper qw(Dumper);
	
	sub run {
		my ($self, $element) = @_;

		#do strand flip if element status set to flip
		if ($element->flip) {
			$self->strand_flip($element->line);
		}
	}
}
1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>


=head1 LICENCE AND COPYRIGHT

Copyright (c) <2009> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 SVNINFO

$Id: Custom.pm 1248 2009-07-15 11:55:06Z rob $ 

=cut