#$Id: Browser.pm 1258 2009-08-03 11:13:08Z rcf8 $

=head1 NAME

HGVbaseG2P::Database::Browser - Query Significance data for Browser/DAS


=head1 SYNOPSIS

more to be written


=head1 DESCRIPTION

more to be written

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2P::Database::Browser; {
    
use strict;
use warnings;


# Use OIO inside-out object framework for our OO hierarachy
use Object::InsideOut qw( HGVbaseG2P::Database );
use Object::InsideOut::Metadata;

use FindBin;
use lib "$FindBin::Bin/../../";

use English qw( -no_match_vars );
use Data::Dumper;
use DBI;
sub init_data_source {
        my ($self, $args)=@_;
        my $config = $self->config->{HGVBrowser};
        return DBI->connect($config->{dsn} || $args->{dsn},$config->{dbuser} || $args->{dbuser},$config->{dbpassw} || $args->{dbpassw},
        {
                                   PrintError => 1, # warn() on errors
                                   RaiseError => 1, # do die on error
                                   AutoCommit => 0, # does not commit immediately

                               }
                  
        
        );
    }

sub get_marker_data_by_resultset {
    my ($self, $attrs) = @_;
    my $sql = "SELECT Marker_Identifier, Marker_Accession, Chr, Start, Stop, NegLogPValue, Strand, SignificanceID FROM marker_data WHERE ResultsetID=?";
    
    my @pars=();
    my $results = $self->dbi_select(
        $sql,
        [
            $attrs->{resultsetid},
        ],
        $attrs);    
        return $results;
}

sub get_marker_data_by_range_and_resultset {
    my ($self, $attrs) = @_;
    my $sql = "SELECT Marker_Identifier, Marker_Accession, Chr, Start, Stop, NegLogPValue, Strand, SignificanceID FROM marker_data WHERE ResultsetID=? and Chr=? and Start>=? and Stop=<?";
    
    my @pars=();
    my $results = $self->dbi_select(
        $sql,
        [
            $attrs->{resultsetid},
            $attrs->{chr},
            $attrs->{start},
            $attrs->{stop},
        ],
        $attrs);    
        return $results;
}

sub get_marker_data_by_range_and_resultsets {
    my ($self, $attrs) = @_;
    my @resultsets = @{$attrs->{resultsetid}};
    
    my $sql = "SELECT Marker_Identifier, Marker_Accession, Chr, Start, Stop, NegLogPValue, Strand, SignificanceID, ResultsetID FROM marker_data_chr" . $attrs->{chr}. " WHERE ResultsetID=? and Start>? and Stop<?";
    
    my $sth = $self->data_source->prepare($sql);
    
    my @data=();
    
    my $counter=0;
    foreach my $rs(@resultsets) {
    	$sth->execute($rs,$attrs->{start},$attrs->{stop});
    	while(my $row = $sth->fetchrow_hashref) {
    		push @data,$row;	
    	}
    	$counter++;
    }
    $sth->finish;
    
    return \@data;
}

sub get_markers_by_identifier {
	my ($self,$attrs) = @_;
	
    my $sql = "SELECT Marker_Identifier, Marker_Accession, Chr, Start, Stop, NegLogPValue, Strand, SignificanceID FROM marker_data_chr".$attrs->{chr}." WHERE Marker_Identifier=? AND NegLogPValue>=?";
    
    my $resultsetid = $attrs->{resultsetid};
    if ($resultsetid and scalar(@{$resultsetid})>0) {
		$sql.=" AND ResultsetID IN (".join(',',@{$resultsetid}).")";
	}
    my @pars=();
    my $results = $self->dbi_select(
        $sql,
        [
            $attrs->{identifier},
            ($attrs->{threshold} eq 'ZERO' ? '0' : $attrs->{threshold}),
        ],
        $attrs);    
        return $results;
}

sub get_marker_data_by_resultsets {
    my ($self, $attrs) = @_;
    my @resultsets = @{$attrs->{resultsetid}};
    
    my $sql = "SELECT Marker_Identifier, Marker_Accession, Chr, Start, Stop, NegLogPValue, Strand, SignificanceID, ResultsetID FROM marker_data WHERE ResultsetID=?";
    
    my $sth = $self->data_source->prepare($sql);
    
    my %data=();
    
    my $counter=0;
    foreach my $rs(@resultsets) {
    	$sth->execute($rs);
    	while(my $row = $sth->fetchrow_hashref) {
#    		!$data{$row->{'Start'}} and $data{$row->{'Start'}}=[];
    		push @{$data{$row->{'Chr'}}},$row;	
    	}
    	$counter++;
    }
    $sth->finish;
    
    return \%data;
}

sub get_marker_data_by_chr_and_resultsets {
    my ($self, $attrs) = @_;
    my @resultsets = @{$attrs->{resultsetid}};
    
    my $sql = "SELECT Marker_Identifier, Marker_Accession, Chr, Start, Stop, NegLogPValue, Strand, SignificanceID, ResultsetID FROM marker_data_chr" . $attrs->{chr}. " WHERE ResultsetID=?";
    
    my $sth = $self->data_source->prepare($sql);
    
    my @data=();
    
    my $counter=0;
    foreach my $rs(@resultsets) {
    	$sth->execute($rs);
    	while(my $row = $sth->fetchrow_hashref) {
    		push @data,$row;	
    	}
    	$counter++;
    }
    $sth->finish;
    
    return \@data;
}

sub get_marker_data_by_threshold_range_and_resultsets {
    my ($self, $attrs) = @_;
    my @resultsets = split(',',$attrs->{resultsetid});
    
    my $sql = "SELECT Marker_Identifier, Marker_Accession, Chr, Start, Stop, FORMAT(NegLogPValue,2) AS NegLogPValue, Strand, SignificanceID, ResultsetID FROM marker_data WHERE NegLogPValue>? and ResultsetID=? and Chr=? and Start>? and Stop<?";
    my $sth = $self->data_source->prepare($sql);
    
    my %data=();
    
    my $counter=0;
    foreach my $rs(@resultsets) {
    	$sth->execute($attrs->{threshold},$rs,$attrs->{chr},$attrs->{start},$attrs->{stop});
    	while(my $row = $sth->fetchrow_hashref) {
    		!$data{$row->{'Start'}} and $data{$row->{'Start'}}=[];
    		$data{$row->{'Start'}}->[$counter]=$row;	
    	}
    	$counter++;
    }
    $sth->finish;
    
    return \%data;
}

sub get_marker_data_by_threshold_chr_and_resultsets {
    my ($self, $attrs) = @_;
    my @resultsets = split(',',$attrs->{resultsetid});
    
    my $sql = "SELECT Marker_Identifier, Marker_Accession, Chr, Start, Stop, FORMAT(NegLogPValue,2) AS NegLogPValue, Strand, SignificanceID, ResultsetID FROM marker_data WHERE NegLogPValue>? and ResultsetID=? and Chr=?";
    my $sth = $self->data_source->prepare($sql);
    
    my %data=();
    
    my $counter=0;
    foreach my $rs(@resultsets) {
    	$sth->execute($attrs->{threshold},$rs,$attrs->{chr});
    	while(my $row = $sth->fetchrow_hashref) {
    		!$data{$row->{'Start'}} and $data{$row->{'Start'}}=[];
    		$data{$row->{'Start'}}->[$counter]=$row;	
    	}
    	$counter++;
    }
    $sth->finish;
    
    return \%data;
}

sub get_marker_binned_counts_for_resultsets_and_threshold {
	my ($self, $attrs) = @_;
	my $resultsetid=$attrs->{resultsetid};
	
	my $sql = "SELECT Reference, Start, Stop, COUNT(Start) AS Score FROM marker_binned".
	" WHERE Threshold=? and Score>0 and BinSize=?";
	if ($resultsetid and scalar(@{$resultsetid})>0) {
		$sql.=" and ResultsetID IN (".join(',',@{$resultsetid}).")";
	}
	$sql.=" GROUP BY Reference, Start";
	
	my @pars=();
    my $results = $self->dbi_select(
        $sql,
        [
            $attrs->{threshold},
            $attrs->{binsize}
        ],
        $attrs);    

        return $results;
}

sub get_marker_binned_counts_for_resultsets_chr_and_threshold {
	my ($self, $attrs) = @_;
	my $resultsetid=$attrs->{resultsetid};
		
	my $sql = "SELECT Reference, Start, Stop, COUNT(Start) AS Score FROM marker_binned".
	" WHERE Threshold=? and Score>0 and BinSize=? and Reference=?";
	if ($resultsetid and scalar(@{$resultsetid})>0) {
		$sql.=" and ResultsetID IN (".join(',',@{$resultsetid}).")";
	}
	$sql.=" GROUP BY Reference, Start";
	
	my @pars=();
    my $results = $self->dbi_select(
        $sql,
        [
            $attrs->{threshold},
            $attrs->{bin_size},
            $attrs->{chr},
        ],
        $attrs);    

        return $results;
}

sub get_marker_binned_by_resultsets_and_threshold {
	my ($self, $attrs) = @_;
	my $resultsetid=$attrs->{resultsetid};
		
	my $sql = "SELECT Reference,Start as bin_start,Stop as bin_stop,GROUP_CONCAT(Score ORDER BY ResultsetID ASC SEPARATOR '|') as bin_counts".
	"  FROM marker_binned_" . $attrs->{bin_size}."mb WHERE Threshold=?";
	if ($resultsetid and scalar(@{$resultsetid})>0) {
		$sql.=" and ResultsetID IN (".join(',',@{$resultsetid}).")";
	}
	$sql.=" GROUP BY Reference, Start";
	
	my @pars=();
    my $results = $self->dbi_select(
        $sql,
        [
            $attrs->{threshold},
        ],
        $attrs);    

        return $results;
}

sub get_marker_binned_by_resultsets_chr_and_threshold {
	my ($self, $attrs) = @_;
	my $resultsetid=$attrs->{resultsetid};
	my $chrs =  $attrs->{chr};
	$chrs =~ s/\s/','/g;
	
	my $sql = "SELECT Reference,Start as bin_start,Stop as bin_stop,GROUP_CONCAT(Score ORDER BY ResultsetID ASC SEPARATOR '|') as bin_counts".
	"  FROM marker_binned_" . $attrs->{bin_size}."mb WHERE Threshold=? and Reference IN ('$chrs') ";
	if ($resultsetid and scalar(@{$resultsetid})>0) {
		$sql.=" and ResultsetID IN (".join(',',@{$resultsetid}).")";
	}
	$sql.=" GROUP BY Reference, Start";
	
	my @pars=();
    my $results = $self->dbi_select(
        $sql,
        [
            $attrs->{threshold},
        ],
        $attrs);    

        return $results;
}

sub get_marker_binned_by_resultsets_range_and_threshold {
	my ($self, $attrs) = @_;
	my $resultsetid=$attrs->{resultsetid};
	
	my $sql = "SELECT Reference,Start as bin_start,Stop as bin_stop,GROUP_CONCAT(Score ORDER BY ResultsetID ASC SEPARATOR '|') as bin_counts".
	"  FROM marker_binned_" . $attrs->{bin_size}."mb WHERE Threshold=? and Reference=? and Start>=? and Stop<=?";
	if ($resultsetid and scalar(@{$resultsetid})>0) {
		$sql.=" and ResultsetID IN (".join(',',@{$resultsetid}).")";
	}
	$sql.=" GROUP BY Reference, Start";
	
	my @pars=();
    my $results = $self->dbi_select(
        $sql,
        [
            $attrs->{threshold},
            $attrs->{chr},
            $attrs->{start},
            $attrs->{stop},
        ],
        $attrs);    

        return $results;
}

sub get_markers_in_region_for_resultsets_above_threshold {
	my ($self, $attrs) = @_;
	my $resultsetid=$attrs->{resultsetid};
	
	my $sql = "SELECT Marker_Accession, Start, Stop, COUNT(Marker_Identifier) AS Score, GROUP_CONCAT(SignificanceID SEPARATOR \",\") AS SigIDs FROM marker_data".
	" WHERE NegLogPValue>? and Chr=? and Start>=? and Stop<=?";
	if ($resultsetid and scalar(@{$resultsetid})>0) {
		$sql.=" and ResultsetID IN (".join(',',@{$resultsetid}).")";
	}
	$sql.=" GROUP BY Marker_Identifier";
	
	my @pars=();
    my $results = $self->dbi_select(
        $sql,
        [
            $attrs->{threshold},
            $attrs->{chr},
            $attrs->{start},
            $attrs->{stop}
        ],
        $attrs);    

        return $results;
}

sub get_resultsets_in_study {
	    my ($self, $attrs) = @_;
		if ($attrs->{studyid}) {
			my $sql = "SELECT ResultsetID,Study_Identifier,Resultset_Label FROM resultset_data WHERE Study_Identifier=?";
		    return $self->dbi_select(
		        $sql,
		        [
		            $attrs->{studyid},
		        ],
		        $attrs
		    );
		}
		else {
			my $sql = "SELECT ResultsetID,Study_Identifier,Resultset_Label FROM resultset_data";
		    return $self->dbi_select(
		        $sql,
		        undef,
		        $attrs
		    );
		}
	}

sub get_resultset_details {
	    my ($self, $attrs) = @_;
		my $sql = "SELECT Resultset_Identifier, ResultsetID, Resultset_Name, Study_Identifier,FullLabel, Study_Name, IsDisplayed FROM resultset_data WHERE ResultsetID=?";
	    my $resultset =  $self->dbi_select(
	        $sql,
	        [
	            $attrs->{resultsetid},
	        ],
	        $attrs
	    );
	    if ($resultset->[0]=={}) {
	    	return undef;
	    }
	    else {
	    	return $resultset->[0];
	    }
	}

sub delete_marker_binned_by_resultset {
    my ($self, $attrs) = @_;
    my $sql = "DELETE FROM marker_binned WHERE ResultsetID=? and BinSize=?";
    
    my @pars=();
    $self->dbi_delete(
	        $sql,
	        [
	            $attrs->{resultsetid},
	            $attrs->{binsize}
	        ],
	        $attrs
	 );
}

sub delete_marker_data_by_resultset_and_chr {
    my ($self, $attrs) = @_;
    my $sql = "DELETE FROM marker_data_chr".$attrs->{chr}." WHERE ResultsetID=?";
    
    my @pars=();
    $self->dbi_delete(
	        $sql,
	        [
	            $attrs->{resultsetid},
	        ],
	        $attrs
	 );
}

sub delete_resultset_data_by_resultset {
    my ($self, $attrs) = @_;
    my $sql = "DELETE FROM resultset_data WHERE ResultsetID=?";
    
    my @pars=();
    $self->dbi_delete(
	        $sql,
	        [
	            $attrs->{resultsetid},
	        ],
	        $attrs
	 );
}

sub create_marker_data_table {
	my ($self, $attrs) = @_;
	my $sql = "
	CREATE TABLE IF NOT EXISTS `marker_data_chr".$attrs->{chr}."` (
  `ResultsetID` int(10) unsigned NOT NULL default '0',
  `ExperimentID` int(10) unsigned NOT NULL,
  `AnalysisMethodID` int(10) unsigned default NULL,
  `StudyID` mediumint(8) unsigned,
  `Identifier_Study` varchar(15) default NULL,
  `SignificanceID` int(12) unsigned default '0',
  `UsedmarkersetID` int(12) unsigned,
  `UnadjustedPValue` float unsigned default NULL,
  `NegLogPValue` double default NULL,
  `MarkerID` int(10) unsigned,
  `Marker_Identifier` varchar(15) default NULL,
  `Marker_Accession` varchar(15) default NULL,
  `DataSourceID` int(4) unsigned default NULL,
  `VariationType` varchar(30) COMMENT 'SO term for the type of the marker feature',
  `Chr` varchar(20) COMMENT 'Chromosome that marker maps to. ''MT'' for mitochondrial genome, ''Un'' if unplaced on chromosome',
  `Start` int(10) unsigned default NULL,
  `Stop` int(10) unsigned default NULL,
  `Strand` smallint(1) default '0' COMMENT 'Strand orientation relative to the reference sequence: +1 for forward strand, -1 for reverse strand and 0 if not applicable or unknown',
  KEY `Region` (`Chr`,`Start`,`Stop`),
  KEY `ResultsetID` (`ResultsetID`),
  KEY `ExperimentID` (`ExperimentID`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 ROW_FORMAT=DYNAMIC;";

	$self->dbh->do($sql);
}

sub get_markers_in_resultsets {
	my ($self, $attrs) = @_;
	my $threshold = $attrs->{threshold};
	my $chr = $attrs->{chr};
	my $start = $attrs->{start};
	my $stop = $attrs->{stop};
	$threshold eq 'ZERO' and $threshold='0';
	my $sql = "select Marker_Identifier, Marker_Accession, Start, Stop, ResultsetList$threshold from marker_resultsets_chr".$chr." where Start>? and Start<?";
	my $sth = $self->dbh->prepare($sql);
	$sth->execute($start,$stop);
	my %marker_resultsets;
	 
	while (my $row = $sth->fetchrow_arrayref) {
		my $mid = $row->[0];
		my @resultsets = split(";",$row->[4]);
		$marker_resultsets{$mid}={
			accession=>$row->[1],
			start=>$row->[2],
			stop=>$row->[3],
		};
		my $total=0;
		foreach my $rs(@resultsets) {
			$marker_resultsets{$mid}->{resultsets}->{$rs}=1;
			$total++;
		}
		$marker_resultsets{$mid}->{total}=$total;
	}
	$self->log->info("mar_rs:".Dumper(\%marker_resultsets));
	return \%marker_resultsets;
}

sub optimise_marker_data_table {
	my ($self, $attrs) = @_;
	my $sql = "OPTIMIZE TABLE `marker_data_chr".$attrs->{chr}."`;";
	$self->dbh->do($sql);
}

sub create_resultset_data_table {
	my ($self, $attrs) = @_;
	my $sql = "
	CREATE TABLE IF NOT EXISTS `resultset_data` (
  `StudyID` mediumint(8) unsigned NOT NULL default '0',
  `Study_Identifier` varchar(15) default NULL,
  `Study_Name` varchar(100) default NULL,
  `Study_Label` varchar(10) default NULL,
  `IsDisplayed` char(5) default NULL,
  `ExperimentID` int(10) unsigned default '0',
  `Experiment_Identifier` varchar(15) default NULL,
  `Experiment_Label` varchar(10) default NULL,
  `ResultsetID` int(10) unsigned default '0',
  `Resultset_Identifier` varchar(15) default NULL,
  `Resultset_Label` varchar(10) default NULL,
  `Resultset_Name` varchar(100) default NULL,
  `FullLabel` varchar(32) default NULL
) ENGINE=MyISAM DEFAULT CHARSET=latin1;";

	
	$self->dbh->do($sql);
}

sub optimise_resultset_data_table {
	my ($self, $attrs) = @_;
	my $sql = "
	OPTIMIZE TABLE `resultset_data`;";
	$self->dbh->do($sql);
}

sub create_marker_binned_table {
	my ($self, $attrs) = @_;
	my $sql = "
CREATE TABLE IF NOT EXISTS `marker_binned` (
  `Reference` varchar(10) NOT NULL,
  `Source` varchar(20) NOT NULL,
  `Type` varchar(20) NOT NULL,
  `Name` varchar(30) NOT NULL,
  `Start` bigint(20) NOT NULL,
  `Stop` bigint(20) NOT NULL,
  `Score` double NOT NULL,
  `ResultSetID` int(11) NOT NULL,
  `Url` text,
  `Threshold` int(11) default NULL,
  `BinSize` int(11) default NULL,
  KEY `ResultsetID` (`ResultSetID`),
  KEY `Reference` (`Reference`,`Start`,`Stop`),
  KEY `Threshold` (`Threshold`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;";

	
	$self->dbh->do($sql);
}

sub optimise_marker_binned_table {
	my ($self, $attrs) = @_;
	my $sql = "
OPTIMIZE TABLE `marker_binned`";
	$self->dbh->do($sql);
}
}
1;

=head1 SEE ALSO

L<HGVbaseG2P::FileParser>, L<HGVbaseG2P::Database> and related classes

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>

=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: Browser.pm 1258 2009-08-03 11:13:08Z rcf8 $ 

=cut

