# $Id: Feature.pm 1272 2009-08-21 15:08:35Z rcf8 $

=head1 NAME

HGVbaseG2P::Database::Feature - Query Main HGVbaseG2P DB using DBStag


=head1 SYNOPSIS

more to be written


=head1 DESCRIPTION

more to be written

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2P::Database::Feature; {
    
	use strict;
	use warnings;
	
	# Use OIO inside-out object framework for our OO hierarachy
	use Object::InsideOut qw( HGVbaseG2P::Database );
	use Object::InsideOut::Metadata;
	
	use English qw( -no_match_vars );
	use Data::Dumper;
	use FindBin;
	use Carp qw(croak cluck);
	use Bio::DB::SeqFeature::Store;
	
    sub init_data_source {
        my ($self, $args)=@_;
        my %config = %{$self->config};
        
        # Connect to database using either info from config OR parameters provided as
	    # arguments to the constructor-call. Arguments will override configfile
	    my $dsn = $args->{dsn} || $config{FeatureDB}->{dsn} ||
		$self->log->logcroak("No database DSN provided with the dsn parameter or configfile");
	    my $dbuser = $args->{user} || $config{FeatureDB}->{dbuser} || getlogin();
	    $self->log->info("Connecting to Bio::DB::SeqFeature database $dsn as user $dbuser");
	    my $dbpassw = $args->{pass} || $config{FeatureDB}->{dbpassw};	
	    my $dbh = Bio::DB::SeqFeature::Store->new(-adaptor => 'DBI::mysql',
						      -dsn     => $dsn,
						      -user    => $dbuser,
						      -pass    => $dbpassw) or die $@;
	    return $dbh;
	}

    sub search_attributes {
	    my ($self, $qstring, $tags, $page,$page_size) = @_;
	
	    my @results = $self->dbh->search_attributes($qstring,$tags);
	    #my @feats = $self->dbh->
	    @results == 0 and return undef;
	    warn "total_entries=",scalar(@results), ", entries_per_page=$page_size, current_page=$page";
	    my $pager = Data::Pageset->new({total_entries    => scalar(@results),
					    entries_per_page => $page_size,
					    current_page     => $page});
	    # Get a slice of the results-list corresponding to pager parameters
	    $self->log->info(Dumper(\@results));
	    my $i = $page_size * ($page-1);
	    $self->log->info("getting slice [",$i," .. ",$i+$page_size,"] from results-array");
	    @results = @results[$i .. $i+$page_size-1];

	    return ( $pager,\@results );
	}
}
1;

=head1 SEE ALSO

L<HGVbaseG2P::FileParser>, L<HGVbaseG2P::Database> and related classes

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Mummi <gthorisson@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>

=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: Feature.pm 1272 2009-08-21 15:08:35Z rcf8 $ 

=cut

