# $Id: Schema.pm 1192 2009-06-18 11:26:43Z rcf8 $

=head1 NAME

HGVbaseG2P::Database::Main - Query Main HGVbaseG2P DB using DBStag


=head1 SYNOPSIS

more to be written


=head1 DESCRIPTION

more to be written

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2P::Database::Schema; {
    
	use strict;
	use warnings;
	
	# Use OIO inside-out object framework for our OO hierarachy
	use Object::InsideOut qw( HGVbaseG2P::Database );
	use Object::InsideOut::Metadata;
	
	use English qw( -no_match_vars );
	use Data::Dumper;
	use FindBin;
	use Carp qw(croak cluck);
	use HGVbaseG2P::Schema;
	
    sub init_data_source {
        my ($self, $args)=@_;
        my %config = %{$self->config};
        
        # Connect to database using either info from config OR parameters provided as
	    # arguments to the constructor-call. Arguments will override configfile
	    my $dsn = $args->{dsn} || $config{dsn} ||
		$self->log->logcroak("No database DSN provided with the dsn parameter or configfile");
	    my $dbuser = $args->{user} || $config{dbuser} || getlogin();
	    $self->log->info("Connecting to database $dsn as user $dbuser");
	    my $dbpassw = $args->{pass} || $config{dbpassw};
	    	my $dbh = HGVbaseG2P::Schema->connect($dsn,
                               $dbuser,
                               $dbpassw,   
                               {
                                   PrintError => 1, # warn() on errors
                                   RaiseError => 1, # do die on error
                                  # AutoCommit => 0, # does not commit immediately
                               }) or OIO->throw("Could not initialize db-connection. DBI::errstr=".$DBI::errstr);
    		$self->log->info("got database handle ".$dbh);
		
	    
	    return $dbh;
    }
    
	sub get_marker_by_accession_and_source {
		my ($self, $accession, $datasource) = @_;
		return $self->dbh->resultset('Marker')->search('accession' => $accession)->single;
	}
	
	sub get_study_by_identifier {
		my ($self, $studyid)=@_;
		my $study = $self->dbh->resultset("Study")->search({ Identifier => $studyid })->first;
		return $study;
	}
	
	sub get_experiment_by_identifier {
		my ($self, $experimentid)=@_;
		my $exp = $self->dbh->resultset("Experiment")->search({ Identifier => $experimentid })->first;
		return $exp;
	}
	
	sub get_resultset_by_identifier {
		my ($self, $resultsetid)=@_;
		my $exp = $self->dbh->resultset("Resultset")->search({ Identifier => $resultsetid })->first;
		return $exp;
	}
	
	sub get_resultset_by_identifier_and_experiment {
		my ($self, $resultsetid)=@_;
		my $exp = $self->dbh->resultset("Resultset")->search({ Identifier => $resultsetid })->first;
		return $exp;
	}
	
	sub get_resultset_by_name_and_experiment {
		my ($self, $resultsetid, $experimentid)=@_;
		my $exp = $self->dbh->resultset("Resultset")->search({ Name => $resultsetid, 'Experimentid' => $experimentid })->first;
		return $exp;
	}
	
	sub get_datasource {
		my ($self, $name)=@_;
		my $ds = $self->dbh->resultset("Datasource")->search({ Name => $name })->first;
		return $ds;
	}
	
	sub get_panel_by_name_and_study {
		my ($self, $name, $studyid)=@_;
		my $apanels = $self->dbh->resultset("Assayedpanel")->search({ 'Name' => $name, 'Studyid' => $studyid })->first;
		
		return $apanels;
	}
	
	sub disconnect {
		my ($self) = @_;
		#$self->dbh->disconnect;
	}
}
1;

=head1 SEE ALSO

L<HGVbaseG2P::FileParser>, L<HGVbaseG2P::Database> and related classes

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Mummi <gthorisson@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>

=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: Schema.pm 1192 2009-06-18 11:26:43Z rcf8 $ 

=cut

