=head1 NAME

HGVbaseG2P::PreProcess - Common functionality for preprocessing frequency and association files

=head1 SYNOPSIS

    use HGVbaseG2P::PreProcess;
    my $preprocess = HGVbaseG2P::PreProcess->new(log4perl_conf => 'log4perl.conf');
    

=head1 DESCRIPTION

  This class implements functions common to our pre-proecess for summary-level genotype data 
  (i.e. allele, genotype and haplotype frequencies) and there associations. 

  Derived classes such as HGVbaseG2P::PreProcess::LiftOver implement logic specific to Preprocess required.

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2P::PreProcess;
{

	use strict;
	use warnings;

	# Use OIO inside-out object framework for our OO hierarachy
	use Object::InsideOut;
	use Object::InsideOut::Metadata;
use Carp qw(cluck confess);
	use Data::Dumper;

	use HGVbaseG2P::Util qw(load_config init_logger open_outfile);

	use POSIX qw(strftime);
	use File::Basename;

	# Private variables & constants
	my $logger;    # Reference to master logger
	my %config;    # Master configuration settings from config-file



	
	my @error_stats : Field :All(stats);
	
	# Initialization arguments
	my %init_args : InitArgs = (
		'conf_file'     => '',
		'log4perl_conf' => '',
	);

	# Initialization method (see OIO docs for details)
	sub _init : Init
	{
		my ( $self, $args ) = @_;

		# Load master config IF config file is provided
		$args->{conf_file} and %config = load_config( $args->{conf_file} );

		# Initialize logger
		my $log4perl_conf = $args->{log4perl_conf} || $config{log4perl_conf};

		$logger = init_logger( $log4perl_conf, __PACKAGE__ );
	    $self->stats({});
	}



    sub increment_stat : Public {
        my ($self,$stat, $value) = @_;
        $self->stats->{$stat}++;
        return $value;
    }
    
    sub get_stat : Public {
        my ($self,$stat) = @_;
        return $self->stats->{$stat};
    }
	
			
		
}    #package
1;

=head1 SEE ALSO



=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Mummi <gthorisson@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Robert Hastings <rkh7@le.ac.uk>


=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: PreProcess.pm 1094 2008-11-26 11:22:33Z rcf8 $ 

=cut