#!/usr/bin/perl

# $Id: Affymetrix.pm 1098 2008-12-05 13:27:01Z rcf8 $

=head1 NAME

HGVbaseG2P::PreProcess::Affymetrix - PreProccessing Affeymetrix lookups

=head1 SYNOPSIS

    
=head1 DESCRIPTION

  

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2P::PreProcess::Affymetrix;
{
	use strict;
	use warnings;

	use FindBin;
	use lib "$FindBin::Bin/../../";

	# Use OIO inside-out object framework for our OO hierarachy
	use Object::InsideOut qw(HGVbaseG2P::PreProcess);
	use Object::InsideOut::Metadata;

	use English qw( -no_match_vars );
	use Carp qw(cluck croak confess);
	use Data::Dumper;
    use HGVbaseG2P::FileParser;
	use HGVbaseG2P::Util qw(load_config init_logger);

	# Private variables & constants
	my $logger;        # Reference to master logger
	my %config;        # Master configuration settings from config-file
	my %apanels_done;  # Keep track of which assayedpanels have been seen so far
	my %affyid;
	my %snpstrands;

	
	
	# Initialization method (see OIO docs for details)
	sub _init : Init
	{
		my ( $self, $args ) = @_;

		# Load master config IF config file is provided
		$args->{conf_file} and %config = load_config( $args->{conf_file} );

		# Initialize logger
		my $log4perl_conf = $args->{log4perl_conf} || $config{log4perl_conf};
	
		$logger = init_logger( $log4perl_conf, __PACKAGE__ );
	}
	

	sub filetype { return 'delimited'; }


sub preprocess_file {
		my ($self, $annot_files,$handler) = @_;

      my $fileparser = HGVbaseG2P::FileParser->new();
		foreach my $file ( @{$annot_files} ) {
			$fileparser->parse_file(
				filename => $file,
				filetype => 'delimited',
				handler  => sub { $self->$handler(@_) },
			);
			$logger->info("Preprocessed $file for rsids");
			
		}

	}


sub _get_rsid_from_affy {
		my ( $self, $line ) = @_;
		return if $line->[0] =~ /^Probe/;
		return if $line->[0] =~ /^#/;

		$affyid{ $line->[0] } =  $line->[1];
		#print Dumper($line->[1]);
	#print Dumper (%affyid);
	#exit;
	}



	sub get_rsid {
		my ( $self, $affymetrix_id ) = @_;    
		my $rsid_array = $affyid{$affymetrix_id};

		if ( !$rsid_array ) {
			$logger->error("no rsid for $affymetrix_id");
			$self->increment_stat('affymetrix_errors');
			return;
		}
		return $rsid_array;
	}
	
	
	
	sub _get_rsid_snpstrand {
        my ( $self, $line ) = @_;
        return if $line->[0] =~ /^Probe/;
        return if $line->[0] =~ /^#/;
        
        
        chomp ($line->[1]);
        chomp ($line->[4]);
        
        $snpstrands{ $line->[0] } = "$line->[1]\t$line->[4]";
       
       
    }

    sub get_rsid_snpstrand {
        my ( $self,$affy_id) = @_;    
        my $array_strand = $snpstrands{$affy_id};

        if ( !$array_strand ) {
            $logger->error("Strand info not found for SNP with rsid:$affy_id");
            $self->increment_stat('strand_errors');
            return;
        }
        
        #my ($rsid,$strand) = split (/\t/,$array_strand);
        #print Dumper ("rsid:$rsid");
        #print Dumper ("stand:$strand");
        #return ($rsid,$strand);
        return ($array_strand);
    }
	
	
	
	

}#package 

1;	
=head1 SEE ALSO



=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Mummi <gthorisson@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Robert Hastings <rkh7@le.ac.uk>


=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: Affymetrix.pm 1098 2008-12-05 13:27:01Z rcf8 $ 

=cut