#!/usr/bin/perl
# $Id: Broad.pm 1098 2008-12-05 13:27:01Z rcf8 $

=head1 NAME

HGVbaseG2P::PreProcess::LiftOver::Broad - PreProccessing the liftover for broad

=head1 SYNOPSIS

    
=head1 DESCRIPTION

  

=head1 SUBROUTINES/METHODS 

=cut
package HGVbaseG2P::PreProcess::LiftOver::Broad;
{
	use strict;
	use warnings;

	#ToDo
	use FindBin;
	use lib "$FindBin::Bin/../";

	# Use OIO inside-out object framework for our OO hierarachy
	use Object::InsideOut qw(HGVbaseG2P::PreProcess::LiftOver);
	use Object::InsideOut::Metadata;
	use Carp qw(cluck croak confess);
	use Data::Dumper;
	use HGVbaseG2P::Util qw(load_config init_logger);

	# Private variables & constants
	my $logger;    # Reference to master logger
	my %config;    # Master configuration settings from config-file
	my %data;
	my @res;

	# Initialization method (see OIO docs for details)
	sub _init : Init
	{
		my ( $self, $args ) = @_;

		# Initialize logger
		my $log4perl_conf = $args->{log4perl_conf} || $config{log4perl_conf};
		$logger = init_logger( $log4perl_conf, __PACKAGE__ );
	}

	# some text here
	sub filetype        { return 'delimited'; }
	sub field_separator { return ' '; }

	sub process_line
	{

		#set up some counters for processing
		my ( $self, $line ) = @_;

		# Don't want the header lineif /^CHR/;
		my (
			 $chr,      $pos,      $rsid,    $z_pval,  $z_score,
			 $or_cmh,   $l95,      $u95,     $a1,      $a2,
			 $maf,      $f_a,      $f_u,     $geno,    $geno_a,
			 $geno_u,   $p_hwd,    $p_hwd_a, $p_hwd_u, $f_miss,
			 $f_miss_a, $f_miss_u, $p_miss,  $gene_list
		) = @$line;
		return if $chr =~ /^CHR/;

		#construct the liftover line
		#start stop for the lift over
		my $start = $pos;
		my $stop  = $pos + 1;

		#$liftover line);
		my $liftover_line = "chr$chr\t$start\t$stop\t$rsid\n";
		my $fh            = $self->print_liftover_outfile;
		print $fh $liftover_line;
	}

	sub reprocess_line
	{

		#set up some counters for processing
		my ( $self, $line ) = @_;

		# Don't want the header lineif /^CHR/;
		my (
			 $chr,      $pos,      $rsid,    $z_pval,  $z_score,
			 $or_cmh,   $l95,      $u95,     $a1,      $a2,
			 $maf,      $f_a,      $f_u,     $geno,    $geno_a,
			 $geno_u,   $p_hwd,    $p_hwd_a, $p_hwd_u, $f_miss,
			 $f_miss_a, $f_miss_u, $p_miss,  $gene_list
		) = @$line;
		chomp($gene_list);
		if ($chr=~/^CHR/){
			#mapped
			my $fh = $self->print_source_liftover_outfile;
			print $fh "CHR POS SNP Z_PVAL ZSCORE OR_CMH L95 U95 A1 A2 MAF F_A F_U GENO GENO_A GENO_U P_HWD P_HWD_A P_HWD_U F_MISS F_MISS_A F_MISS_U P_MISS GENE_LIST\n";
		#unmapped
		my $unmappedfh = $self->print_unmapped_liftover_outfile;
		print $unmappedfh "CHR POS SNP Z_PVAL ZSCORE OR_CMH L95 U95 A1 A2 MAF F_A F_U GENO GENO_A GENO_U P_HWD P_HWD_A P_HWD_U F_MISS F_MISS_A F_MISS_U P_MISS GENE_LIST\n";
	
		}
		return if $chr =~ /^CHR/;
		$logger->info("finding new genome build co-ordinate for $rsid");
		my $new_pos = $self->get_liftover_start_pos($rsid);
		
		

		if ( !$new_pos )
		{
			my $new_pos = $self->get_liftover_unmapped_pos($rsid);
			$logger->warn(
				 "$rsid id has not been mapped to a new genome build $new_pos");
	
		my $unmapped_line= "$chr $pos $rsid $z_pval $z_score $or_cmh $l95 $u95 $a1 $a2 $maf $f_a $f_u $geno $geno_a $geno_u $p_hwd $p_hwd_a $p_hwd_u $f_miss $f_miss_a $f_miss_u $p_miss $gene_list";
		my $unmappedfh = $self->print_unmapped_liftover_outfile;
		print $unmappedfh "$unmapped_line\n";
		$self->increment_stat("chr".$chr."_unmapped");
		} else
		{
			
			chomp($new_pos);
			my $new_liftover_line =
"$chr $new_pos $rsid $z_pval $z_score $or_cmh $l95 $u95 $a1 $a2 $maf $f_a $f_u $geno $geno_a $geno_u $p_hwd $p_hwd_a $p_hwd_u $f_miss $f_miss_a $f_miss_u $p_miss $gene_list";
			
			my $fh = $self->print_source_liftover_outfile;
			
			print $fh "$new_liftover_line\n";
			
			$self->increment_stat("chr".$chr."_mapped_ok");
			
			
		}
	}
}    #package
1;

=head1 SEE ALSO



=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Mummi <gthorisson@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Robert Hastings <rkh7@le.ac.uk>


=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: Broad.pm 1098 2008-12-05 13:27:01Z rcf8 $ 

=cut
