package HGVbaseG2P::Schema::Analysismethod;

use strict;
use warnings;

use base 'DBIx::Class';

__PACKAGE__->load_components("Core");
__PACKAGE__->table("AnalysisMethod");
__PACKAGE__->add_columns(
  "analysismethodid",
  { data_type => "INT", default_value => undef, is_nullable => 0, size => 10 },
  "submittedinstudyid",
  {
    data_type => "MEDIUMINT",
    default_value => undef,
    is_nullable => 1,
    size => 8,
  },
  "identifier",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 0,
    size => 15,
  },
  "name",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 100,
  },
  "label",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 10,
  },
  "accession",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 15,
  },
  "accessionversion",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 10,
  },
  "description",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "protocolparameters",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
);
__PACKAGE__->set_primary_key("analysismethodid");
__PACKAGE__->add_unique_constraint("Identifier", ["identifier"]);
__PACKAGE__->add_unique_constraint("Label", ["label", "submittedinstudyid"]);
__PACKAGE__->add_unique_constraint("Name", ["name", "submittedinstudyid"]);
__PACKAGE__->belongs_to(
  "submittedinstudyid",
  "HGVbaseG2P::Schema::Study",
  { studyid => "submittedinstudyid" },
);
__PACKAGE__->has_many(
  "resultsets",
  "HGVbaseG2P::Schema::Resultset",
  { "foreign.analysismethodid" => "self.analysismethodid" },
);
__PACKAGE__->has_many(
  "studyanalysismethods",
  "HGVbaseG2P::Schema::Studyanalysismethod",
  { "foreign.analysismethodid" => "self.analysismethodid" },
);


# Created by DBIx::Class::Schema::Loader v0.04005 @ 2008-12-29 14:15:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:ZEEOoDGhL/7apz2pkEy9nQ


# You can replace this text with custom content, and it will be preserved on regeneration

*submittedinstudy = \&submittedinstudyid;
__PACKAGE__->many_to_many(usedinstudies => 'studyanalysismethods', 'studyid' );

sub to_jsonhash {
    my $self = shift;
    return { 
	'type'  => 'analysismethod',
	'label' => $self->name,
	'id'    => $self->identifier,
	#'submittedinstudy' => $self->submittedinstudy->identifier,
	'description'     => $self->description || '',
    };
}

1;
