package HGVbaseG2P::Schema::Experiment;

use strict;
use warnings;

use base 'DBIx::Class';

__PACKAGE__->load_components("Core");
__PACKAGE__->table("Experiment");
__PACKAGE__->add_columns(
  "experimentid",
  { data_type => "INT", default_value => undef, is_nullable => 0, size => 10 },
  "studyid",
  {
    data_type => "MEDIUMINT",
    default_value => undef,
    is_nullable => 0,
    size => 8,
  },
  "phenotypemethodid",
  { data_type => "INT", default_value => undef, is_nullable => 1, size => 10 },
  "identifier",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 15,
  },
  "name",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 100,
  },
  "label",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 10,
  },
  "accession",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 15,
  },
  "accessionversion",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 10,
  },
  "description",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "type",
  { data_type => "VARCHAR", default_value => "", is_nullable => 0, size => 100 },
  "hotlinkid",
  { data_type => "INT", default_value => undef, is_nullable => 1, size => 10 },
  "totalmarkerstested",
  { data_type => "INT", default_value => undef, is_nullable => 1, size => 6 },
  "totalmarkersimported",
  { data_type => "INT", default_value => undef, is_nullable => 1, size => 6 },
  "objective",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 0,
    size => 65535,
  },
  "outcome",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 0,
    size => 65535,
  },
  "comments",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "individualdatastatement",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "frequencysummary",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "significancesummary",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "timecreated",
  {
    data_type => "TIMESTAMP",
    default_value => "CURRENT_TIMESTAMP",
    is_nullable => 0,
    size => 14,
  },
  "genotypedbundle",
  { data_type => "VARCHAR", default_value => "", is_nullable => 0, size => 100 },
);
__PACKAGE__->set_primary_key("experimentid");
__PACKAGE__->add_unique_constraint("Identifier", ["identifier"]);
__PACKAGE__->add_unique_constraint("Name", ["name", "studyid"]);
__PACKAGE__->belongs_to(
  "phenotypemethodid",
  "HGVbaseG2P::Schema::Phenotypemethod",
  { phenotypemethodid => "phenotypemethodid" },
);
__PACKAGE__->belongs_to(
  "hotlinkid",
  "HGVbaseG2P::Schema::Hotlink",
  { hotlinkid => "hotlinkid" },
);
__PACKAGE__->belongs_to(
  "studyid",
  "HGVbaseG2P::Schema::Study",
  { studyid => "studyid" },
);
__PACKAGE__->has_many(
  "experimentassayedpanels",
  "HGVbaseG2P::Schema::Experimentassayedpanel",
  { "foreign.experimentid" => "self.experimentid" },
);
__PACKAGE__->has_many(
  "genotypedbundles",
  "HGVbaseG2P::Schema::Genotypedbundle",
  { "foreign.experimentid" => "self.experimentid" },
);
__PACKAGE__->has_many(
  "genotypingdetails",
  "HGVbaseG2P::Schema::Genotypingdetails",
  { "foreign.experimentid" => "self.experimentid" },
);
__PACKAGE__->has_many(
  "resultsets",
  "HGVbaseG2P::Schema::Resultset",
  { "foreign.experimentid" => "self.experimentid" },
);
__PACKAGE__->has_many(
  "usedmarkersets",
  "HGVbaseG2P::Schema::Usedmarkerset",
  { "foreign.experimentid" => "self.experimentid" },
);


# Created by DBIx::Class::Schema::Loader v0.04005 @ 2008-12-29 14:15:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:X6V5YVYJAwb8JupdIKqzTg


# You can replace this text with custom content, and it will be preserved on regeneration

__PACKAGE__->many_to_many(usedassayedpanels => 'experimentassayedpanels', 'assayedpanelid' );

*phenotypemethod = \&phenotypemethodid;
*study = \&studyid;

sub design {
	my ($self)=@_;
	return 'GWAS';
}

sub to_jsonhash {
    my $self = shift;
    
#    my $count = $self->usedmarkersets->count;
#    my $logcount = int($count/10);
#    
#    my $markers_present;
#   
#    if ($count>=10000) {
#    	$markers_present = '1E'.$count . "-1E".($count+1);
#    }
#    elsif ($count>=1000 and $count<10000) {
#    	$markers_present='1000-10000';
#    }
#    elsif ($count>=100 and $count<1000) {
#    	$markers_present='100-1000';
#    }
#    elsif ($count>=10 and $count<100) {
#    	$markers_present='10-100';
#    }
#    elsif ($count>=1 and $count<10) {
#    	$markers_present='1-10';
#    }
     
    return {
	'type'  => 'experiment',
	'name' => $self->name,
	'label'    => $self->identifier,
	'study' => $self->study->identifier,
	'description'     => $self->description || '',
	'design' => $self->design,
	#'markerspresent' => $markers_present,
	#'logpresent'=>$log_markers
	#'phenotypemethod' => $self->phenotypemethod->methodname,
	#'assayedpanels'   => join('|', @apanel_names),
    };
}

sub poslog {
		my ( $value, $base ) = @_;
		!$base and $base = 10;
		$value == 0 and return '0.00';
		my $logged = log($value) / log($base);
		return $logged;
	}
	
1;
