package HGVbaseG2P::Schema::Marker;

use strict;
use warnings;

use base 'DBIx::Class';

__PACKAGE__->load_components("Core");
__PACKAGE__->table("Marker");
__PACKAGE__->add_columns(
  "markerid",
  { data_type => "INT", default_value => undef, is_nullable => 0, size => 10 },
  "identifier",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 15,
  },
  "accession",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 15,
  },
  "accessionversion",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 10,
  },
  "datasourceid",
  { data_type => "INT", default_value => undef, is_nullable => 1, size => 4 },
  "status",
  {
    data_type => "VARCHAR",
    default_value => "active",
    is_nullable => 0,
    size => 20,
  },
  "variationtype",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 0,
    size => 30,
  },
  "hotlinkid",
  { data_type => "INT", default_value => undef, is_nullable => 1, size => 10 },
  "upstream30bp",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 0,
    size => 30,
  },
  "alleleseqs",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "downstream30bp",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 0,
    size => 30,
  },
  "validationcode",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "addedfromsourcebuild",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 10,
  },
  "timelasttouched",
  {
    data_type => "TIMESTAMP",
    default_value => "CURRENT_TIMESTAMP",
    is_nullable => 0,
    size => 14,
  },
);
__PACKAGE__->set_primary_key("markerid");
__PACKAGE__->add_unique_constraint("Identifier", ["identifier"]);
__PACKAGE__->add_unique_constraint("Accession", ["accession", "datasourceid"]);
__PACKAGE__->has_many(
  "alleles",
  "HGVbaseG2P::Schema::Allele",
  { "foreign.markerid" => "self.markerid" },
);
__PACKAGE__->has_many(
  "assaymarkers",
  "HGVbaseG2P::Schema::Assaymarker",
  { "foreign.markerid" => "self.markerid" },
);
__PACKAGE__->has_many(
  "genotypes",
  "HGVbaseG2P::Schema::Genotype",
  { "foreign.markerid" => "self.markerid" },
);
__PACKAGE__->belongs_to(
  "datasourceid",
  "HGVbaseG2P::Schema::Datasource",
  { datasourceid => "datasourceid" },
);
__PACKAGE__->belongs_to(
  "hotlinkid",
  "HGVbaseG2P::Schema::Hotlink",
  { hotlinkid => "hotlinkid" },
);
__PACKAGE__->has_many(
  "markeralias",
  "HGVbaseG2P::Schema::Markeralias",
  { "foreign.markerid" => "self.markerid" },
);
__PACKAGE__->has_many(
  "markercoords",
  "HGVbaseG2P::Schema::Markercoord",
  { "foreign.markerid" => "self.markerid" },
);
__PACKAGE__->has_many(
  "markercrossrefs",
  "HGVbaseG2P::Schema::Markercrossref",
  { "foreign.markerid" => "self.markerid" },
);
__PACKAGE__->has_many(
  "markerrevision_markerids",
  "HGVbaseG2P::Schema::Markerrevision",
  { "foreign.markerid" => "self.markerid" },
);
__PACKAGE__->has_many(
  "markerrevision_replacedbymarkerids",
  "HGVbaseG2P::Schema::Markerrevision",
  { "foreign.replacedbymarkerid" => "self.markerid" },
);
__PACKAGE__->has_many(
  "markersetmarkers",
  "HGVbaseG2P::Schema::Markersetmarker",
  { "foreign.markerid" => "self.markerid" },
);


# Created by DBIx::Class::Schema::Loader v0.04005 @ 2008-12-29 14:15:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:Sr/y0WtDXbkR/YeSdfSMTg


# You can replace this text with custom content, and it will be preserved on regeneration
*datasource = \&datasourceid;
*hotlink = \&hotlinkid;
*revisions = \*markerrevision_markerids;
__PACKAGE__->many_to_many(crossrefs => 'markercrossrefs', 'crossrefid' );
__PACKAGE__->many_to_many(usedmarkersets => 'markersetmarkers', 'usedmarkersetid' );

1;
