package HGVbaseG2P::Schema::Phenotypemethod;

use strict;
use warnings;

use base 'DBIx::Class';

__PACKAGE__->load_components("Core");
__PACKAGE__->table("PhenotypeMethod");
__PACKAGE__->add_columns(
  "phenotypemethodid",
  { data_type => "INT", default_value => undef, is_nullable => 0, size => 10 },
  "studyid",
  {
    data_type => "MEDIUMINT",
    default_value => undef,
    is_nullable => 0,
    size => 8,
  },
  "phenotypepropertyid",
  { data_type => "INT", default_value => undef, is_nullable => 0, size => 10 },
  "identifier",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 15,
  },
  "name",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 100,
  },
  "description",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "sample",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 100,
  },
  "measuredattribute",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 100,
  },
  "variabletype",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 0,
    size => 25,
  },
  "unit",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 25,
  },
  "circumstance",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "timeinstant",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "timeperiod",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "details",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
);
__PACKAGE__->set_primary_key("phenotypemethodid");
__PACKAGE__->add_unique_constraint("Identifier", ["identifier"]);
__PACKAGE__->add_unique_constraint("Name", ["name", "studyid"]);
__PACKAGE__->has_many(
  "experiments",
  "HGVbaseG2P::Schema::Experiment",
  { "foreign.phenotypemethodid" => "self.phenotypemethodid" },
);
__PACKAGE__->belongs_to(
  "studyid",
  "HGVbaseG2P::Schema::Study",
  { studyid => "studyid" },
);
__PACKAGE__->belongs_to(
  "phenotypepropertyid",
  "HGVbaseG2P::Schema::Phenotypeproperty",
  { phenotypepropertyid => "phenotypepropertyid" },
);
__PACKAGE__->has_many(
  "phenotypemethodcitations",
  "HGVbaseG2P::Schema::Phenotypemethodcitation",
  { "foreign.phenotypemethodid" => "self.phenotypemethodid" },
);
__PACKAGE__->has_many(
  "phenotypemethodcrossrefs",
  "HGVbaseG2P::Schema::Phenotypemethodcrossref",
  { "foreign.phenotypemethodid" => "self.phenotypemethodid" },
);
__PACKAGE__->has_many(
  "phenotypevalues",
  "HGVbaseG2P::Schema::Phenotypevalue",
  { "foreign.phenotypemethodid" => "self.phenotypemethodid" },
);


# Created by DBIx::Class::Schema::Loader v0.04005 @ 2008-12-29 14:15:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:N39kQFMkm6LXI09eYOm4xA


# You can replace this text with custom content, and it will be preserved on regeneration
*study = \&studyid;
*phenotypeproperty = \&phenotypepropertyid;
__PACKAGE__->many_to_many(citations => 'phenotypemethodcitations', 'citationid' );
__PACKAGE__->many_to_many(crossrefs => 'phenotypemethodcrossrefs', 'crossrefid' );
sub to_jsonhash {
    my ($self,$browsertag) = @_;
    my $discat = $self->phenotypeproperty->diseasecategory;
    my @bimage = split(' ',$browsertag);
    
    my @resultsets=();
    foreach my $exp($self->experiments) {
    	foreach my $rs($exp->resultsets) {
    		push @resultsets, $rs->resultsetid;
    	}
    }
    
     #check if study is allowed to be added to browser and change image to noentry if so
    if (!$self->study->isdisplayed) {
    	$bimage[0]='noentry';
    	$browsertag='Data not available to Browser';
    }
    my @discats;
    if ($discat) {
    foreach(split(';',$discat->name)) {
    	push @discats,$_;
    }
    }

    return { 
	'type'  => 'Phenotype',
	'label' => $self->identifier,
	'name' => $self->name,
	'identifier'    => $self->identifier,
	'description'     => $self->description || '',
	'variabletype' => $self->variabletype,
	'phenotypeproperty' => $self->phenotypeproperty->name,
	'study_identifier' => $self->study->identifier,
	'study_name' => $self->study->name,
	'diseasecategory' => \@discats,
	'browsertag' => $browsertag,
	'browserimage' => lc $bimage[0],
	'resultsets'=>join(",",@resultsets),
	'experiment_identifier' => $self->experiments->first->identifier,
    };
    
}


1;
