package HGVbaseG2P::Schema::Resultset;

use strict;
use warnings;

use base 'DBIx::Class';

__PACKAGE__->load_components("Core");
__PACKAGE__->table("Resultset");
__PACKAGE__->add_columns(
  "resultsetid",
  { data_type => "INT", default_value => undef, is_nullable => 0, size => 10 },
  "experimentid",
  { data_type => "INT", default_value => undef, is_nullable => 0, size => 10 },
  "analysismethodid",
  { data_type => "INT", default_value => undef, is_nullable => 1, size => 10 },
  "identifier",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 15,
  },
  "name",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 100,
  },
  "label",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 10,
  },
  "accession",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 15,
  },
  "accessionversion",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 10,
  },
  "description",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "protocolparameters",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "timecreated",
  {
    data_type => "TIMESTAMP",
    default_value => "CURRENT_TIMESTAMP",
    is_nullable => 0,
    size => 14,
  },
);
__PACKAGE__->set_primary_key("resultsetid");
__PACKAGE__->add_unique_constraint("Identifier", ["identifier"]);
__PACKAGE__->add_unique_constraint("Name", ["name", "experimentid"]);
__PACKAGE__->belongs_to(
  "analysismethodid",
  "HGVbaseG2P::Schema::Analysismethod",
  { analysismethodid => "analysismethodid" },
);
__PACKAGE__->belongs_to(
  "experimentid",
  "HGVbaseG2P::Schema::Experiment",
  { experimentid => "experimentid" },
);
__PACKAGE__->has_many(
  "significances",
  "HGVbaseG2P::Schema::Significance",
  { "foreign.resultsetid" => "self.resultsetid" },
);


# Created by DBIx::Class::Schema::Loader v0.04005 @ 2008-12-29 14:15:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:VceBm+LJxi4J37W48K6HgA


# You can replace this text with custom content, and it will be preserved on regeneration

# Method aliases, for the bits that the generator didn't figure out by itself
*experiment = \&experimentid;
*analysismethod = \&analysismethodid;

sub to_jsonhash {
    my $self = shift;
    return {
	'type'  => 'resultset',
	'label' => $self->name,
	'id'    => $self->identifier,
	'description'     => $self->description || '',
	'experiment' => $self->experiment->identifier,
	'analysismethod' => $self->analysismethod->identifier,
	
    };
}


1;
