package HGVbaseG2P::Schema::Study;

use strict;
use warnings;

use base 'DBIx::Class';

__PACKAGE__->load_components("Core");
__PACKAGE__->table("Study");
__PACKAGE__->add_columns(
  "studyid",
  {
    data_type => "MEDIUMINT",
    default_value => undef,
    is_nullable => 0,
    size => 8,
  },
  "identifier",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 15,
  },
  "name",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 100,
  },
  "label",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 10,
  },
  "accession",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 15,
  },
  "accessionversion",
  {
    data_type => "VARCHAR",
    default_value => undef,
    is_nullable => 1,
    size => 10,
  },
  "description",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "ishidden",
  { data_type => "CHAR", default_value => undef, is_nullable => 1, size => 5 },
  "abstract",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 0,
    size => 65535,
  },
  "background",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "objectives",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 0,
    size => 65535,
  },
  "keyresults",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 0,
    size => 65535,
  },
  "conclusions",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 0,
    size => 65535,
  },
  "studydesign",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "studysizereason",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "studypower",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "sourcesofbias",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "limitations",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "acknowledgements",
  {
    data_type => "TEXT",
    default_value => undef,
    is_nullable => 1,
    size => 65535,
  },
  "timecreated",
  {
    data_type => "TIMESTAMP",
    default_value => "CURRENT_TIMESTAMP",
    is_nullable => 0,
    size => 14,
  },
  "timeupdated",
  {
    data_type => "TIMESTAMP",
    default_value => "0000-00-00 00:00:00",
    is_nullable => 0,
    size => 14,
  },
  "isdisplayed",
  { data_type => "CHAR", default_value => undef, is_nullable => 1, size => 5 },
);
__PACKAGE__->set_primary_key("studyid");
__PACKAGE__->add_unique_constraint("Identifier", ["identifier"]);
__PACKAGE__->add_unique_constraint("Name", ["name"]);
__PACKAGE__->has_many(
  "analysismethods",
  "HGVbaseG2P::Schema::Analysismethod",
  { "foreign.submittedinstudyid" => "self.studyid" },
);
__PACKAGE__->has_many(
  "assays",
  "HGVbaseG2P::Schema::Assay",
  { "foreign.studyid" => "self.studyid" },
);
__PACKAGE__->has_many(
  "assayedpanels",
  "HGVbaseG2P::Schema::Assayedpanel",
  { "foreign.studyid" => "self.studyid" },
);
__PACKAGE__->has_many(
  "experiments",
  "HGVbaseG2P::Schema::Experiment",
  { "foreign.studyid" => "self.studyid" },
);
__PACKAGE__->has_many(
  "genotypedlocis",
  "HGVbaseG2P::Schema::Genotypedloci",
  { "foreign.studyid" => "self.studyid" },
);
__PACKAGE__->has_many(
  "phenotypemethods",
  "HGVbaseG2P::Schema::Phenotypemethod",
  { "foreign.studyid" => "self.studyid" },
);
__PACKAGE__->has_many(
  "samplepanels",
  "HGVbaseG2P::Schema::Samplepanel",
  { "foreign.submittedinstudyid" => "self.studyid" },
);
__PACKAGE__->has_many(
  "studyanalysismethods",
  "HGVbaseG2P::Schema::Studyanalysismethod",
  { "foreign.studyid" => "self.studyid" },
);
__PACKAGE__->has_many(
  "studycitations",
  "HGVbaseG2P::Schema::Studycitation",
  { "foreign.studyid" => "self.studyid" },
);
__PACKAGE__->has_many(
  "studycrossrefs",
  "HGVbaseG2P::Schema::Studycrossref",
  { "foreign.studyid" => "self.studyid" },
);
__PACKAGE__->has_many(
  "studyoverlap_studyid_news",
  "HGVbaseG2P::Schema::Studyoverlap",
  { "foreign.studyid_new" => "self.studyid" },
);
__PACKAGE__->has_many(
  "studyoverlap_studyid_olds",
  "HGVbaseG2P::Schema::Studyoverlap",
  { "foreign.studyid_old" => "self.studyid" },
);
__PACKAGE__->has_many(
  "studysamplepanels",
  "HGVbaseG2P::Schema::Studysamplepanel",
  { "foreign.studyid" => "self.studyid" },
);
__PACKAGE__->has_many(
  "submissions",
  "HGVbaseG2P::Schema::Submission",
  { "foreign.studyid" => "self.studyid" },
);


# Created by DBIx::Class::Schema::Loader v0.04005 @ 2008-12-29 14:15:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:cTKQFbO0BhaPIViMYKBFVw


# You can replace this text with custom content, and it will be preserved on regeneration

# TODO! find a way to un-install auto-generated samplepanels method above, since we want to
#       use this custom method instead. Currently this works, BUT DBIx::Class::Schema gives a warning.

*submittedsamplepanels = \*samplepanels;
*submittedanalysismethods = \*analysismethods;
__PACKAGE__->many_to_many(usedsamplepanels => 'studysamplepanels', 'samplepanelid' );
__PACKAGE__->many_to_many(usedanalysismethods => 'studyanalysismethods', 'analysismethodid' );
__PACKAGE__->many_to_many(authors => 'authors', 'researcherid' );
__PACKAGE__->many_to_many(citations => 'studycitations', 'citationid' );
__PACKAGE__->many_to_many(crossrefs => 'studycrossrefs', 'crossrefid' );

sub to_jsonhash {
    my ($self,$browsertag) = @_;
    my @bimage = split(' ',$browsertag);
    my @exps = map {$_->identifier} $self->experiments->search({ 'type' => {'!=' => 'Frequency determination' }});
    #my @exp_designs = map {$_->design} $self->experiments;
    
    my @resultsets=();
    foreach my $exp($self->experiments) {
    	foreach my $rs($exp->resultsets) {
    		push @resultsets, $rs->resultsetid;
    	}
    }
    my $subm = $self->submissions->search_related('contributions',{'contributions.isauthor'=>'yes'})->first;
    my $cit = $self->citations->first;
    my $timecr = $self->timecreated;
    my @temp = split(/\ /,$timecr);
    my $date = $temp[0];
    
    my $author=$subm->researcher->shortname;
    $author=~s/et\sal\./<i>et al.<i>/;
    
#    my @authors = split(/\,/,);
#    if (scalar(@authors)>1) {
#    	$author = $authors[0]." <i>et al.</i>";
#    }
#    else {
#    	$author = $authors[0];
#    }
    
    #check if study is allowed to be added to browser and change image to noentry if so
    if (!$self->isdisplayed) {
    	$bimage[0]='noentry';
    	$browsertag='Data not available to Browser';
    }
    
    return { 
	'type'  => 'Study',
	'name' => $self->name,
	'label'    => $self->identifier,
#	'description'     => $self->description || '',
	'pubmedid' => $cit->pubmedid,
	'citation' => $author,
#	'authors' => $cit->title."\n\n".$cit->authors,
	'timecreated' => $timecr,
	'browsertag' => $browsertag,
	'browserimage' => lc $bimage[0],
#	'experiment'=> \@exps,
	'resultsets'=>join(",",@resultsets)
    };
}

1;
