# $Id: marker.pm 1272 2009-08-21 15:08:35Z rcf8 $

=head1 NAME

HGVbaseG2P::Search::Results::marker - Return Results for region search


=head1 SYNOPSIS

    use HGVbaseG2P::Search;
    my $search = HGVbaseG2P::Search::Results->new({content_type=>'text/xml'});


=head1 DESCRIPTION

This class is a simple wrapper around different types of searches. An instance of the object can be set up and then several searches
performed using the same parameters.

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2P::Search::Results::marker; {
    
use strict;
use warnings;

# Use OIO inside-out object framework for our OO hierarachy
use Object::InsideOut qw(HGVbaseG2P::Search::Results);
use English qw( -no_match_vars );
use Data::Dumper qw(Dumper);
use HGVbaseG2P::Util qw(load_config init_logger );
 	
    # Initialization arguments
    my %init_args : InitArgs = (
        'dsn' => '',
        'user' => '',
        'pass' => '',
    );

    sub accepted_parameters {
    	return qw(region id);
    }
    
    sub search {
    	my ($self,$c, $output)=@_;
    	
		my $region = $self->param('region');
		
		
		my ($type, $chr,$start,$stop);
	
		if ($region) {
			$self->log->info("region supplied: $region");
			($type, $chr,$start,$stop) = $self->extract_keywords($region);
			$self->log->info("type:$type, chr:$chr, start:$start, stop:$stop");
		}
		
		if ($type) {
			if ($type eq 'feature') {
				$self->log->info("type is feature");
				($type,$chr,$start,$stop) = $self->get_feature_region($region, $c->model('SeqFeature'));
				$self->log->info("feature type:$type, chr:$chr, start:$start, stop:$stop");
			}
		}
		
		my $data = $self->get_marker_data($chr,$start,$stop,$c->model('MarkerDB'));
		
		$self->filter_results($data);
    }
    
    sub get_marker_data {
    	my ($self, $chr, $start, $stop, $marker_db)=@_;
    	my @data;
    	
    	
    	if ($chr && $start && $stop) {
    		$self->log->info("in range:$chr $start $stop");
	    	@data = $marker_db->get_markers_rs_in_range($chr,$start,$stop)->all;
		}
		else {
			my @id = $self->param('id');
			$self->log->info("ids:".Dumper(\@id));
			@data = $marker_db->get_marker_rs_by_accession_or_identifier(\@id,\@id)->all;	
		}
		
		return \@data;
    }
    
    sub filter_results {
    	my ($self, $data)=@_;
    	my @results=();
    	if ($data) {

    		my $counter=0;
			foreach my $item(@{$data}) {	
				
				my $coords = $item->markercoords->search( { assemblyname => 'Reference' })->first;
				my ($chr, $start,$stop)=qw(unknown unknown unknown);
				if ($coords) {
				 $chr = $coords->chr;
				 $start = $coords->start;
				 $stop = $coords->stop;
				}
				
				my $body = {
		        	'identifier' => $item->identifier, 
		        	'chr' =>  $chr,
		        	'start'=>$start, 
		        	'stop' => $stop
		        };	
		        
		        my $alleles = substr($item->upstream30bp,-10, 10). $item->alleleseqsshorthand . substr($item->downstream30bp,0, 10);
				
		        my $summary = {
		        	'Marker Identifier' => $item->identifier,
		        	'Accession' => $item->accession,
		        	'Database Source' => 'dbSNP',
		        	'Variation Type'=>$item->variationtype,
		        	'Alleles'=>$alleles
		        };
				
				push @results, {
					id=>"http://www.hgvbaseg2p.org/marker/".$item->identifier,
			    	title=>$item->identifier." present at ".$chr.":".$start."..".$stop,
			    	summary=>$summary,
			    	link=>"http://www.hgvbaseg2p.org/marker/".$item->identifier,
			    	content=>$body
				};
				$counter++;
			}
		}
		$self->log->info("results:".Dumper(\@results));
		return \@results;
    }
}
1;

=head1 SEE ALSO

L<HGVbaseG2P::FileParser>, L<HGVbaseG2P::Database> and related classes

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>

=head1 LICENCE AND COPYRIGHT

Copyright (c) <2009> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: marker.pm 1272 2009-08-21 15:08:35Z rcf8 $ 

=cut

    