# $Id: studies.pm 1272 2009-08-21 15:08:35Z rcf8 $

=head1 NAME

HGVbaseG2P::Search::Results::study - Return Results for 'study' search


=head1 SYNOPSIS

    use HGVbaseG2P::Search;
    my $search = HGVbaseG2P::Search::Results->new({content_type=>'text/xml'});


=head1 DESCRIPTION

This class is a simple wrapper around different types of searches. An instance of the object can be set up and then several searches
performed using the same parameters.

=head1 SUBROUTINES/METHODS 

=cut

package HGVbaseG2P::Search::Results::studies; {
    
use strict;
use warnings;

# Use OIO inside-out object framework for our OO hierarachy
use Object::InsideOut qw(HGVbaseG2P::Search::Results);
use English qw( -no_match_vars );
use Data::Dumper qw(Dumper);
use HGVbaseG2P::Util qw(load_config init_logger );
use Text::ParseWords;

	my @study_db : Field :All(study_db); #contains parameters - generally loaded from CGI param
	my @xapian_db : Field :All(xapian_db);
    
    sub accepted_parameters {
    	return qw(q);
    }
    
    sub required_db {
    	return {
    		'StudyDB'=>'study_db',
    		'Xapian'=>'xapian_db'
    	};
    }
    
    sub search {
    	my ($self)=@_;
    	
		my $keywords = $self->param('q');
		
		my ($data,$pager,$total);
		
		if ($keywords) {
			($data,$pager,$total) = $self->get_study_data($keywords,$self->study_db, $self->xapian_db);
		}
		else {
			my $rs = $self->study_db->get_paged_unhidden_studies_rs($self->page,$self->page_size);
			$data = [ $rs->all ];
			$pager = $rs->pager;
		}
		
		return ($self->filter_results($data),$pager,$total);
    }
    
     sub get_study_data {
    	my ($self, $query)=@_;
    	my @data;
    	
	    my $xap = $self->xapian_db;
		my $page_size = 10;
		
		
		my $qterms = $self->parse_query($query);
		
	    # Send query with supplied query string to text search engine. This may cause an exception
	    # to be thrown (e.g. invalid query syntax), so let's catch that
	    my ($pager,$identifiers) = $xap->search($qterms,'studies', $self->page, $self->page_size);
		my $total = $self->study_db->count_all_unhidden_studies;
		
		#grab list of identifiers from Xapian database and then retrieve study object for each
		my $method = "get_study_by_identifier";
		my @results;
		foreach my $identifier(@{$identifiers}) {
			push @results, $self->study_db->$method($identifier);
		}
		
  	  	return (\@results,$pager,$total);
    }
    
    sub filter_results {
    	my ($self, $data)=@_;
    	my @results=();
    	if ($data) {

    		my $counter=0;
			foreach my $item(@{$data}) {	
				
				my @resultsets=();
			    foreach my $exp($item->experiments) {
			    	foreach my $rs($exp->resultsets) {
			    		push @resultsets, $rs->resultsetid;
			    	}
			    }
			    my $cit = $item->citations->first;
				my $subm = $item->submissions->search_related('contributions',{'contributions.isauthor'=>'yes'})->first;
				my $author;
				
				if ($subm) {
					$author=$subm->researcher->shortname;
    				$author=~s/et\sal\./<i>et al.<i>/;
				}
				
				my $body = {
		        	'identifier' => $item->identifier, 
		        	'name' =>  $item->name,
		        	'date'=>$item->timecreated,
		        	'authors'=>$author,
		        	'state'=>$item->isdisplayed,
		        	'pubmedid' => ($cit ? $cit->pubmedid : undef),
		        	'resultsets'=>join(',',@resultsets)
		        };	
				
				my $summary = {
					'Study Identifier'=>$item->identifier,
					'Name'=> $item->name,
					'Abstract' => substr($item->abstract,0,200),
					'State'=>$item->isdisplayed
				};
				
				push @results, {
					id=>"study/".$item->identifier,
			    	title=>$item->name." (".$item->identifier.")",
			    	summary=>$summary,
			    	link=>"study/".$item->identifier,
			    	content=>$body
				};
				$counter++;
			}
		}
		#$self->log->info("results:".Dumper(\@results));
		return \@results;
    }
}
1;

=head1 SEE ALSO

L<HGVbaseG2P::FileParser>, L<HGVbaseG2P::Database> and related classes

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>

=head1 LICENCE AND COPYRIGHT

Copyright (c) <2009> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: studies.pm 1272 2009-08-21 15:08:35Z rcf8 $ 

=cut

    