#!perl
package HGVbaseG2P::Test::DataImport;

# $Id: DataImport.pm 1192 2009-06-18 11:26:43Z rcf8 $

=head1 NAME

  HGVbaseG2Pmart::Test::GenotypeImport - Test summary-level generic data import methods

=head1 SYNOPSIS

	
=head1 DESCRIPTION

  This test class inherits from the XMLdb test class, thereby inheriting a setup
  method which initializes an empty HGVbase-G2P database and connects to it with
  the XMLStore middleware.


=head1 SUBROUTINES/METHODS 

=cut


use strict;
use warnings;

use Data::Dumper;
use Test::More;
use Test::Exception;
use Data::Stag qw( :all );
use HGVbaseG2P::Util qw(load_config load_module);

use base qw(HGVbaseG2P::Test::Schema);
use Cwd;

sub load_freqs {
	return 0;
}

sub xml_temp_dir {
	my ($self, $value) = @_;
	$value and $self->{xml_temp_dir}=$value;
	return $self->{xml_temp_dir};
}

sub B_dataimport_init :Test(startup=>no_plan) {
    my $self = shift;

    my $importclass = $self->get_import_class;
    my %config = load_config('./conf/test/hgvbase.conf');
    $self->{testdata} = $config{TestData}->{$importclass};
    
    # Load some test marker & study data to hook up the frequency data to
    lives_ok { $self->get_xmldb->store_file('./t/data/markers.xml'); } "Storing marker XML-file";
    lives_ok { $self->get_xmldb->commit() } "Committing marker transaction";
    lives_ok { $self->get_xmldb->store_file('./t/data/marker_updates.xml'); } "Storing marker-updated XML-file";
    lives_ok { $self->get_xmldb->commit() } "Committing marker update transaction";
    lives_ok { $self->get_xmldb->store_file('./t/data/study/study_'.$self->get_source.'.xml'); } "Storing study XML-file for ".$self->get_source;
    lives_ok { $self->get_xmldb->commit() } "Committing study transaction";
    
    if ($self->load_freqs) {
    	lives_ok { $self->get_xmldb->store_file('./t/data/freqs/' . $self->get_source . '.xml'); } "Storing frequency XML-file for ".$self->get_source;
    	lives_ok { $self->get_xmldb->commit() } "Committing frequencies transaction";
    }
	
    
    
    # Initialize the class we are testing
    $self->xml_temp_dir($config{xml_temp_dir});
    
    my $dataimport = load_module($importclass, [dsn       => $self->get_dsn(),
					       user      => $self->get_user(),
					       passw     => $self->get_password(),					       
					       conf_file => './conf/test/hgvbase.conf',
					       log4perl_conf => './conf/log4perl.conf',
					       source => $self->get_source,
					       argv   => {studyid => $self->get_data('studyid'), assayedpanels=>$self->get_data('assayedpanels')}
					       ]);

    isa_ok($dataimport, 'HGVbaseG2P::DataImport', 'Import object is of the proper class' );
    $self->{dataimport} = $dataimport;

    # Check if subclass has implemented the mandatory methods (abstract in superclass)
    lives_ok {$dataimport->filetype()} "Filetype method is implemented in subclass";
}

sub get_dataimport {
    my $self = shift;
    return $self->{dataimport};
}

sub count_test {
	my ($self,$arrayref,$expected, $desc,$extra) = @_;
	!$extra and $extra=" ";
	is @{$arrayref}, $expected, "Expected number of ".$desc." returned (".scalar(@{$arrayref}).") $extra";
}

sub present_test {
	my ($self,$arrayref,$expected, $desc) = @_;
	my $present=0;
	foreach(@{$arrayref}) {
		$_ eq $expected and $present=1;
	}
	ok $present, "Expected value ($expected) was present in $desc array";
}

sub get_data {
	my ($self,$value) = @_;
	return $self->{testdata}->{$value};
}
1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Rob Free <rcfree@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Rob Free <rcfree@gmail.com>


=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: DataImport.pm 1192 2009-06-18 11:26:43Z rcf8 $

=cut


