#!perl
package HGVbaseG2P::Test::DataImport::Association;

# $Id: Association.pm 1099 2008-12-05 13:28:04Z rcf8 $

=head1 NAME

  HGVbaseG2Pmart::Test::Frequency - Base class for testing summary-level frequency importers

=head1 SYNOPSIS

	
=head1 DESCRIPTION

  This test class inherits from the Frequency test class, which creates a test db containing a study and marker data.
  The additional test run by a superclass are source (ie. CGEMS, Broad) specific.


=head1 SUBROUTINES/METHODS 

=cut

use strict;
use warnings;

use Data::Dumper;
use Test::More;
use Test::Exception;
use Data::Stag qw( :all );

use base qw(HGVbaseG2P::Test::DataImport);
use Cwd;

sub load_freqs {
	return 1;
}

# ToDo: make the same set of tests run for each import-subclass, not just CGEMS!
sub C_frequencyimport_init : Test( startup => no_plan) {
	my $self = shift;
			
	$self->{xmlfile}="assocs_".$self->get_source."_".$self->get_source.".xml";
	$self->{xmlpath}=$self->xml_temp_dir."/".$self->{xmlfile};
	$self->{infile}="./t/data/assocs/".$self->get_source.".txt";
	
}

sub get_import_class {
	my ($self) = @_;
	return "HGVbaseG2P::DataImport::Association::" . $self->get_source;
}

sub _01_generate_xml : Tests {
	my $self       = shift;
	my $dataimport = $self->get_dataimport();
	
	
	# Test main processing method
	$dataimport->process_file( $self->{infile} );
	my $stats = $dataimport->stats;
	
	!system("mv -f ".$self->{xmlfile}." ".$self->xml_temp_dir) or die "Unable to move ". $self->{xmlfile}." to ". $self->xml_temp_dir;
	
}

sub _02_check_xml : Tests {
	my $self = shift;

	my $xml;
	lives_ok {
		$xml = Data::Stag->parse( -file => $self->{xmlpath} );
	  }
	  "Parsing " . $self->get_source . " association file";

	my @apanels = $xml->get('Assayedpanel');
	$self->count_test( \@apanels, 3, "Assayedpanels" );

	my @exps = $xml->get('Experiment');
	$self->count_test( \@exps, 2, "Experiments" );

	my @markersets = $exps[1]->get('Usedmarkerset');
	$self->count_test( \@markersets, $self->get_data('usedmarkersets'), "Usedmarkersets" );
	my @markers = ();
	my @resultsets = $exps[1]->get('Resultset');

		my @sigs = $resultsets[0]->get('Significance');

		$self->count_test( \@resultsets, 6, "Resultsets" );
		$self->count_test( \@sigs, 1, "Significances",
			"for resultset" );
	
		my @fcs = $sigs[0]->get('FCS');
		$self->count_test( \@fcs, $self->get_data('fcs'), "FCS");
}

sub _03_store_xml : Tests {
	my $self = shift;
	print $self->{xmlpath}."\n";

	lives_ok { $self->get_xmldb->store_file( $self->{xmlpath} ); }
	  "Storing association XML-file '".$self->{xmlpath}."'";
	$self->get_xmldb->commit;
}

sub _04_query_db : Tests {
	my $self = shift;
	my $study;
	my $dataimport = $self->get_dataimport();

	lives_ok {
		$study = $self->get_xmldb->selectall_stag(
			-template => 'hgvbase-study',
			-bind     => { StudyID => $self->get_data('studyid') }
		);
	  }
	  "Get study from db";
	my @apanels = $study->find('Assayedpanel');
	$self->count_test( \@apanels, 3, "Assayedpanels", "from db" );
	my @apanelids = ();
	foreach (@apanels) {
		push @apanelids, $_->get('AssayedpanelID');
	}

	my $studyexp;
	lives_ok {
		$studyexp = $self->get_xmldb->selectall_stag(
			-template => 'hgvbase-experiment',
			-bind     => { StudyID => $self->get_data('studyid') }
		);
	  }
	  "Get experiment from db";

	my @experiments = $studyexp->get('Experiment');
	$self->count_test( \@experiments, 1, "Experiments", "from db" );
	
	my $experimentid;

	
	foreach(@experiments) {
		if ($_->get('Identifier') eq $dataimport->assoc_exp_identifier) {
			$experimentid = $_->get('ExperimentID');
		}
	}
	ok( $experimentid, "Association experiment present");
	$self->{experimentid}=$experimentid;
	
	my $sigsexp;
	lives_ok {
		$sigsexp = $self->get_xmldb->selectall_stag(
			-template => 'hgvbase-significance',
			-bind     => { ExperimentID => $experimentid }
		);
	  }
	  "Get significances from db for exp $experimentid";
	
	my @sigs = $sigsexp->get('Significance');
	$self->count_test( \@sigs, $self->get_data('significances'), "Significances", "from db" );
}
1;
