#!perl
package HGVbaseG2P::Test::DataImport::Frequency;

# $Id: Frequency.pm 1192 2009-06-18 11:26:43Z rcf8 $

=head1 NAME

  HGVbaseG2Pmart::Test::Frequency - Base class for testing summary-level frequency importers

=head1 SYNOPSIS

	
=head1 DESCRIPTION

  This test class inherits from the Frequency test class, which creates a test db containing a study and marker data.
  The additional test run by a superclass are source (ie. CGEMS, Broad) specific.


=head1 SUBROUTINES/METHODS 

=cut


use strict;
use warnings;

use Data::Dumper;
use Test::More;
use Test::Exception;
use Data::Stag qw( :all );
use HGVbaseG2P::Util qw(load_config load_module);

use base qw(HGVbaseG2P::Test::DataImport);

# ToDo: make the same set of tests run for each import-subclass, not just CGEMS!

#sub B_dataimport_init :Test(startup=>no_plan) {
#	my $self = shift;
#
#    my $importclass = $self->get_import_class;
#    my %config = load_config('./conf/test/hgvbase.conf');
#    $self->{testdata} = $config{TestData}->{$importclass};
#        
#    # Initialize the class we are testing
#    $self->xml_temp_dir($config{xml_temp_dir});
#    
#    my $dataimport = load_module($importclass, [dsn       => $self->get_dsn(),
#					       user      => $self->get_user(),
#					       passw     => $self->get_password(),					       
#					       conf_file => './conf/test/hgvbase.conf',
#					       log4perl_conf => './conf/log4perl.conf',
#					       source => $self->get_source,
#					       argv   => {studyid => $self->get_data('studyid'), assayedpanels=>$self->get_data('assayedpanels')}
#					       ]);
#
#    isa_ok($dataimport, 'HGVbaseG2P::DataImport', 'Import object is of the proper class' );
#    $self->{dataimport} = $dataimport;
#
#    # Check if subclass has implemented the mandatory methods (abstract in superclass)
#    lives_ok {$dataimport->filetype()} "Filetype method is implemented in subclass";
#
#}

sub C_frequencyimport_init :Test(startup => no_plan) {
    my $self = shift;
    
    $self->{xmlfile}="freqs_".$self->get_source."_".$self->get_source.".xml";
    $self->{xmlpath} = $self->xml_temp_dir."/".$self->{xmlfile};
    $self->{infile}="./t/data/freqs/".$self->get_source.".txt";
}

sub get_import_class {
    my ($self)=@_;
    return "HGVbaseG2P::DataImport::Frequency::".$self->get_source;
}

sub _01_generate_xml :Tests {
    my $self = shift;
    my $dataimport = $self->get_dataimport();
    
    # Test main processing method
    $dataimport->process_file($self->{infile});
    my $marker_stats  = $dataimport->stats;
    !system("mv -f ". $self->{xmlfile}." ".$self->xml_temp_dir) or die "Unable to move ". $self->{xmlfile}." to ". $self->xml_temp_dir;
}

sub _02_check_xml :Tests {
	my $self = shift;
	my $xml;
	lives_ok { $xml = Data::Stag->parse(-file => $self->{xmlpath}); 
	   } "Parsing ".$self->get_source." frequency file";
	 
	 my @exps = $xml->get('Experiment');
	 $self->count_test(\@exps,1,"Experiments");

	
	 
	 my @freqclusters = $exps[0]->get('FrequencyCluster');
	 my $rsid = $freqclusters[0]->get('Marker/Accession');
	 $self->count_test(\@freqclusters,$self->get_data('freqclusters'),"FrequencyClusters","for $rsid");

	my @gtfreqs = $freqclusters[0]->get('GenotypeFrequency');
	my @alfreqs = $freqclusters[0]->get('AlleleFrequency');
		
	$self->count_test(\@gtfreqs,3,"GenotypeFrequencies","for $rsid");
	$self->count_test(\@alfreqs,2,"AlleleFrequencies","for $rsid");
	 
	  my @markersets = $exps[0]->get('Usedmarkerset');
	 $self->count_test(\@markersets,$self->get_data('usedmarkersets'),"Usedmarkersets");
	 my @markers=();
}

sub _03_store_xml :Tests {
	my $self = shift;
	lives_ok { $self->get_xmldb->store_file($self->{xmlpath}); } "Storing frequency XML-file";
	lives_ok { $self->get_xmldb->commit() } "Committing frequency transaction";
}

sub _04_query_db :Tests {	
	my $self = shift;
	my $study;
	my $dataimport = $self->get_dataimport();
	
	lives_ok { $study = $self->get_xmldb->selectall_stag(-template => 'hgvbase-samplepanel',
						    -bind => {Identifier => $self->get_data('studyid') }); } "Get samplepanels from db";

	my @apanels = $study->find('Assayedpanel');
	$self->count_test(\@apanels,$self->get_data('assayedpanelno'),"Assayedpanels","from db");
	my @apanelids = ();
	foreach(@apanels) {
		push @apanelids, $_->get('AssayedpanelID');
	}
	
	my $studyexp;
	lives_ok { $studyexp = $self->get_xmldb->selectall_stag(-template => 'hgvbase-experiment',
						    -bind => {StudyID => $self->get_data('studyid') }); } "Get experiment from db";

	my @experiments = $studyexp->get('Experiment');
	$self->count_test(\@experiments,1,"Experiments","from db");
	my $experiment = shift @experiments;
	ok ($experiment->get('Identifier') eq $dataimport->freq_exp_identifier, "Experiment ID is correct (db:'" . $experiment->get('Identifier') . "' and expected:'".$dataimport->freq_exp_identifier."'");
	
	my $experimentid = $experiment->get('ExperimentID');
	
	my $umsexp;
	lives_ok { $umsexp = $self->get_xmldb->selectall_stag(-template => 'hgvbase-experiment_markersets',
						    -bind => {ExperimentID => $experimentid }); } "Get usedmarkersets from db for exp $experimentid";

	my @ums = $umsexp->get('Usedmarkerset');
	$self->count_test(\@ums,$self->get_data('db_usedmarkersets'),"Usedmarkersets","from db");
	
	my $exp;
	lives_ok { $exp = $self->get_xmldb->selectall_stag(-template => 'hgvbase-marker_freqs',
						    -bind => {ExperimentID => $experimentid }); } "Get FrequencyClusters from db for exp $experimentid";
    my @fc = $exp->find('FrequencyCluster');
    $self->count_test(\@fc,$self->get_data('freqclusters'),"FrequencyClusters for experiment","from db");
	
	my $allele_freqs;
	
	foreach my $marker (@fc) {
		my $markerid=$marker->get('MarkerID');

	   my @af = $marker->get('AlleleFrequency');
	   $self->count_test(\@af,2,"AlleleFrequencies","from db for marker $markerid");
	   
	   
	   my @gf = $marker->get('GenotypeFrequency');
	   $self->count_test(\@gf,3,"GenotypeFrequencies","from db for marker $markerid");
	   

	   
	}
}
1;

