package HGVbaseG2P::Test::XMLdbQuery;

# $Id: XMLdbQuery.pm 1192 2009-06-18 11:26:43Z rcf8 $

=head1 NAME

  HGVbaseG2Pmart::Test::XMLdbQuery - Test XML-2-relational query functions

=head1 SYNOPSIS

    
=head1 DESCRIPTION



=head1 SUBROUTINES/METHODS 

=cut


use strict;
use warnings;

use Data::Dumper;
use Test::More;
use Test::Exception;

use base qw(HGVbaseG2P::Test::XMLdb);


sub _2_retrieve_marker :Tests {
    my $self = shift;

    # Store marker XML-file in database 
    lives_ok { $self->get_xmldb->store_file('./t/data/markers.xml'); } "Storing marker XML-file";
    lives_ok { $self->get_xmldb->commit() } "Committing transaction";    
    
    # Retrieving marker XML-data from database 
    my $marker_set;
    my $markerid = 'HGVM510';
    lives_ok { $marker_set = $self->get_xmldb->selectall_stag(-template => 'hgvbase-marker',
                            -bind => {MarkerID => $markerid}); 
       } "Fetching marker from database";
    my $marker = $marker_set->find('Marker');
    ok defined($marker), "Marker is defined";

    isa_ok $marker, 'Data::Stag::StagImpl', "Marker entry is of proper class";
    #print $marker->itext();
    ok $marker->get('MarkerID') eq $markerid, "MarkerID from object is correct";
    ok $marker->get('Allele') > 1, "Marker has more than one allele";
    foreach my $tnode(qw( VariationType 
              Source 
              LocalID 
              AddedFromSourceBuild
              TimeLastTouched )) {
    ok defined($marker->get($tnode)), "Got data from terminal node $tnode in Marker, as expected";
    }
    ok !$marker->get('FooBar'), "Did not find data in non-existent node FooBar, as expected";
    my $mcoord = $marker->get('MarkerCoord');
    isa_ok $mcoord, 'Data::Stag::StagImpl', "MarkerCoord subnode of proper class";
    foreach my $tnode(qw( Chr
              Start
              Stop
              Strand
              AssemblyType
              AssemblyName )) {
    ok defined($mcoord->get($tnode)), "Got data from terminal node $tnode from MarkerCoord, as expected";
    }    
}

sub _3_retrieve_markerrevision :Tests {
    my $self = shift;
    
    # Try loading in some marker-revision information and then fetch it
    my $xmldb = $self->get_xmldb();
    lives_ok { $xmldb->store_file('./t/data/marker_updates.xml'); } "Storing XML-file with marker revisions";
    lives_ok { $xmldb->commit() } "Committing transaction";

    my $markerrev_set;
    my $markerid = 'HGVM510';
    lives_ok{ $markerrev_set = $self->get_xmldb->selectall_stag(-template => 'hgvbase-marker_revisionhistory',
                                -bind     => {MarkerID => $markerid})
          } "Retrieve marker revisions for '$markerid'";
    #print $markerrev_set->itext;
    isa_ok $markerrev_set, 'Data::Stag::StagImpl', "Marker revision set is of the proper class";
    my $markerrev = $markerrev_set->get('Marker/MarkerRevision');
    ok defined($markerrev), "Marker revision node defined";
    ok $markerrev->children > 0, "Marker revision node has child nodes";
    ok $markerrev->get('ChangeType') eq 'Merging', "Marker-rev change type is correct";
    my $replacedmarker = $markerrev->get('ReplacedByMarker');
    ok $replacedmarker->get('Marker/MarkerID') eq 'HGVM1984', "Replaced-by marker is correct";
}

sub _4_retrieve_study :Tests {
    my $self = shift;

    # Storing study XML-file in database
    my $xmldb = $self->get_xmldb();
    lives_ok { $xmldb->store_file('./t/data/study.xml') } "Storing XML-file with basic study-info";
    lives_ok { $xmldb->store_file('./t/data/study_significances.xml') } "Storing XML-file with significance data";
    lives_ok { $xmldb->commit() } "Committing transaction";

    # Do a few queries involving study data, using SQL-templates
    my $studytitle = 'Test study for regression test suite';
    my $study_set;
    lives_ok{ $study_set = $xmldb->selectall_stag(-template => 'hgvbase-study',
                                                  -bind     => {Name => $studytitle});
      } "Retrieve study entry with Title '$studytitle'";
    my $study = $study_set->find('Study');
    isa_ok $study, 'Data::Stag::StagImpl', "Study entry is of proper class";
    ok $study->name eq 'Study', "Study entry has the correct element name";
    ok $study->get('Title') eq $studytitle, "Title of study entry is correct";
    ok defined($study->get('Crossref')), "Study has a Crossref child element";
    print $study->itext;

    # Check if some of the study 'assets' are here
    my $anlmeth =  $study->sget('StudyAnalysisMethod/AnalysisMethod');
    ok $anlmeth, "Analysis method present";
    foreach my $att(qw(Identifier Name)) {
	ok $anlmeth->get($att), "Method has att $att";
    }


    # Get single experiment from this study
    my $exp = $study->sget('Experiment');
    print $exp->itext;
    foreach my $tnode(qw( Type
                          ExperimentID
                          Identifier
                          Name )) {
        ok defined($exp->get($tnode)), "Got data from terminal node $tnode from Experiment";
    }
    
    # Get experiment details plus all G2P result-sets contained within
    my $exp_id = $exp->get('Identifier');
    my $exp_set;
    lives_ok{ $exp_set = $xmldb->selectall_stag(-template => 'hgvbase-experiment',
						-bind     => {Identifier => $exp_id});
      } "Retrieve experiment with ID $exp_id" ;
    my $exp_full = $exp_set->get('Experiment');
    isa_ok $exp_full, 'Data::Stag::StagImpl', "Experiment entry is of proper class";
    print $exp_full->itext;

    # DBIx::Class test stuff
    #my $dbh = $self->get_dbh();
    #my $exp2 = $c->model("DB::Experiment")->search({identifier => $exp+id})->single();
    #print "Got DBIx::Class Experiment object ".$exp2;
    #my @rsets = @exp->resultsets();
    #my $rset = shift @rsets;
    #print "Got DBIx::Class Resultset object ".$rset;
    
}



1;

=head1 SEE ALSO

=head1 BUGS AND LIMITATIONS

There are no known bugs in this module.
Please report problems to Gudmundur Thorisson <gthorisson@gmail.com>

=head1 CONTACT

This module is part of the HGVbase-G2P project

=head1 AUTHOR

Gudmundur Thorisson <gthorisson@gmail.com>

=head1 LICENCE AND COPYRIGHT

Copyright (c) <2007> University of Leicester, Leicester, UK. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 

=head1 CVSINFO

$Id: XMLdbQuery.pm 1192 2009-06-18 11:26:43Z rcf8 $

=cut


