=head1 NAME

HGVbaseG2Pweb - Catalyst based application

=head1 SYNOPSIS

    # To start up a a standalone server
    script/hgvbaseg2pweb_server.pl

=head1 DESCRIPTION

This is the Catalyst-based HGVbaseG2P web application. This class
does little more than bootstrap the app from parameters in the config
file in conf/. All data retrieval, presentation and business logic 
resides in class modules in Model, View and Controller, respectively.

For newbies to the project and/or MVC-frameworks, please see the intro
at http://search.cpan.org/~jrockway/Catalyst-Manual/lib/Catalyst/Manual/Intro.pod
to get started.

=head1 SEE ALSO

L<HGVbaseG2Pweb::Controller::Root>, L<Catalyst>

=head1 AUTHOR

  Gudmundur A. Thorisson <gthorisson@gmail.com>

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

package HGVbaseG2P::Web;

# $Id: Web.pm 1272 2009-08-21 15:08:35Z rcf8 $

use strict;
use warnings;
use FindBin;
use Catalyst::Runtime '5.70';
use Catalyst::Log::Log4perl;
use Env;
use Data::Dumper qw(Dumper);

our $VERSION = '0.05';

# Load Catalyst itself, with various plugins & options
use Catalyst qw[
		-Log=debug
		-Stats=1
		ConfigLoader
		Static::Simple  
		StackTrace
		Session::Store::File
        Session
        Session::State::Cookie
        Browser
		];
        
# Then configure our application
$ENV{HGVBASEG2PWEB_HOME}='/Users/robf/Projects/hgvbaseg2p_v2/perl';
my $home = $ENV{HGVBASEG2PWEB_HOME} || die "FATAL ERROR:HGVBASEG2PWEB_HOME environment variable not set!";

__PACKAGE__->config( name   => 'HGVbaseG2P::Web',
		     'Plugin::ConfigLoader' => {
			 file => $home."/conf/hgvbase.conf",
		     },
#__PACKAGE__->config->{urlpath} = __PACKAGE_ || '';
		     
		     
		     );
#set up session to store in home temp directory
__PACKAGE__->config->{session} = {
	expires => 3600,
	storage => $home."/sess"
};
# Set up more configurable logger, replacing stock Catalyst one. Log::Log4perl
# can be configured entirely from a master config-file
__PACKAGE__->log(Catalyst::Log::Log4perl->new($home."/conf/log4perl.conf"));

# Set up Static::Simple, for serving static files from the application's root 
__PACKAGE__->config->{static} = {
    no_logs => 1,
    include_path => [$home . '/htmltemplates/static'],
    ignore_extensions =>  [qw/tmpl tt tt2/]
    };

# Finally start the application
__PACKAGE__->setup();




1;
