# $Id: Browser.pm 1258 2009-08-03 11:13:08Z rcf8 $

package HGVbaseG2P::Web::Controller::Browser;


=head1 NAME

  HGVbaseG2Pweb::Controller::Browser - Catalyst Controller for Browser

=head1 DESCRIPTION

  This class handles retrieving & transforming data for the Browser part of HGVbaseG2P
  It ties together the various views, config settings and AJAX calls.

=head1 METHODS

=cut

use strict;
use warnings;
use base qw(HGVbaseG2P::Web::Controller::Root);

use Data::Dumper qw(Dumper);
use List::MoreUtils qw(any uniq);
use HGVbaseG2P::Browser::Core;

my $home =  $ENV{HGVBASEG2PWEB_HOME} ;

=head2 default

Action to deal with browser default. Sets up the stash with session variables and collated hashrefs for studies and resultsets

=cut

sub view :Path('browser') {
    my ( $self, $c) = @_;
    
    #fill stash with session values
    $c->stash->{colors}=$c->session->{colors};
    $c->stash->{settings}=$c->session->{settings};
    $c->stash->{tracks}=$c->session->{tracks};
    
    #collate selected studies into a hashref and a list of resultsetids
    my ($studies,$resultsetids)=$self->collate_studies($c);
	
	#collate selected chromosomes into a hashref
	$c->stash->{chrs_to_display}=$self->collate_chrs($c);

	#store collated and session data in stash
    $c->stash->{resultsetid}=$resultsetids;
    $c->stash->{g_threshold}=$c->session->{g_threshold};
    $c->stash->{r_threshold}=$c->session->{r_threshold};

    $c->stash->{region}=$c->session->{region};
    $c->stash->{template} = 'browser.tt2';
    $c->stash->{studies}=$studies;
}

=head2 key

Action to deal with AJAX call for 'key' HTML. Retrieves resultset data from session/request and stashes it for template

=cut

sub key :Path('browser/key') {
    my ( $self, $c) = @_;
	
	#get resultsets from database and pass them to template
	my @rsdata = $self->get_db_resultsets($c);
    
	$c->stash->{rsdata}=\@rsdata;
	$c->stash->{template}="browser/key.tt2";
}	

=head2 store

Action to deal with AJAX call for session 'store'. Uses supplied parameters to populate session

=cut

sub store :Path('browser/store') {
    my ( $self, $c) = @_;
    
    #store general parameters
    my @chrs_to_display = $c->req->param('chrs_to_display');
    $c->req->param('chrs_to_display') and $c->session->{chrs_to_display}=\@chrs_to_display;
    $c->req->param('g_threshold') and $c->session->{g_threshold}=$c->req->param('g_threshold');
    $c->req->param('r_threshold') and $c->session->{r_threshold}=$c->req->param('r_threshold');
    
    
    #deal with current genomic region
    my $region;
    
    if ($c->req->param('region') && $c->req->param('region') eq 'undefined') {
    	$region = "";
    }
    else {
    	$region = $c->req->param('region');
    }
    
    $c->session->{region}=$region;
    
    #store settings and tracks (convert to hashes)
    my $setting_pairs = $c->req->param('settings') || '';
    my %settings_hash = ();
    if ($setting_pairs) {
    	
    	foreach my $pair(split(',',$setting_pairs)) {
			my @temp = split(/\|/, $pair);
			$settings_hash{$temp[0]}=$temp[1]
    	}
    	$c->session->{settings}=\%settings_hash;
    }
    
    my $tracks = $c->req->param('tracks');
    my %tracks_hash = ();
    if ($tracks) {
    	foreach my $track(split(',',$tracks)) {
			$tracks_hash{$track}=1;
    	}
    	$c->session->{tracks}=\%tracks_hash;
    }
    
    #store resultsets and studies by converting to array and hash respectively
    my @resultsetids = $c->req->param('resultsetid');
    if (@resultsetids) {
    	if ($resultsetids[0] eq 'none') {
    		$c->log->info("setting resultsets to none");
    		$c->session->{resultsetid}=[];
    	}
    	else {
    		$c->log->info("setting resultsets to".Dumper(\@resultsetids));
    		$c->session->{resultsetid}=\@resultsetids;
    	}
    }
    
    my @studies = $c->req->param('study');
    if (@studies) {
    	if ($studies[0] eq 'none') {
    		$c->log->info("setting studies to none");
    		$c->session->{studies}={};
    	}
    	else {
    		$c->log->info("setting studies to".Dumper(\@studies));
    		$c->session->{studies}={map { $_ => 1; } @studies};
    	}
    }
    
    $c->log->info("store_session:".Dumper($c->session));
    
    #return 'success' if no errors
    $c->response->body('success');
}

=head2 clear

Action to deal with AJAX call for session 'clear'. Deletes the session completely and resets it.

=cut

sub clear :Path('browser/clear') {
    my ( $self, $c) = @_;
    $c->delete_session('session expired');
    $c->forward('HGVbaseG2P::Web::Controller::Root','begin');
}

sub get_db_resultsets {
	my ($self, $c)=@_;
	my $resultsets = $c->stash->{base_resultsetids};
	$c->log->info("resultsets:".Dumper($resultsets));
	return if !$resultsets;
    my @resultsetids = sort @{$resultsets};
    
    my @rsdata=();
    foreach my $rsid(@resultsetids) {
		my $resultset = $c->model("StudyDB")->get_resultset($rsid);
		push @rsdata, $resultset;
    }
    
	return @rsdata;
}

sub genome :Path('browser/markers/genome') {
    	my ($self ,$c)=@_;
    	
    	#get resultsets from database and pass them to template
		my @rsdata = $self->get_db_resultsets($c);
		$c->stash->{threshold}=$c->req->param('threshold');
		$c->stash->{template}='browser/markers/genome.tt2';
		$c->stash->{rsdata}=\@rsdata;
    }
    
sub region :Path('browser/markers/region') {
    	my ($self ,$c)=@_;
    	
    	eval {
	    	my $browser = $self->get_browser($c);
	    	my $threshold=$c->req->param('threshold');
	    	$browser->threshold($c->req->param('threshold'));
	    	my $region = $browser->genomic_region;
	    	
	    	if ($region eq 'Chrnull' || $region eq 'Chr') {
	    		$c->stash->{multiple}=1;
	    		$c->stash->{template}='browser/markers/region_lowres.tt2';
	    		return;
	    	}
	    	
	    	#get resultsets from database and pass them to template
			my @rsdata = $self->get_db_resultsets($c);
			
			$c->stash->{rsdata}=\@rsdata;
			$c->stash->{chr}=$browser->chr;
			$c->stash->{region}=$region;
			$c->stash->{threshold}=$threshold;
			
			
			if ($browser->is_high_resolution) {
				$c->stash->{template}='browser/markers/region_hires.tt2';
				$c->stash->{markers}=$browser->get_markers_in_resultsets;
			}
			else {
				my $data = $browser->get_marker_binned_data({ bin_size => '1' } );
				$c->stash->{template}='browser/markers/region_lowres.tt2';
				$c->stash->{markers}=$data->{$browser->chr};
			}
    	};
    	if ($@) {
    		$c->stash->{template}='error.tt2';
    		$c->stash->{error}={info=>$@};
    	}
    }
    
    sub get_browser {
    	my ($self, $c) = @_;
    	my $browser = HGVbaseG2P::Browser::Core->new({conf_file=>$c->config});
    	$browser->db($c->model('BrowserDB'));
    	$browser->resultsetid($c->stash->{base_resultsetids});
    	$c->log->info("get_browser - session:".Dumper($c->session));
    	
    	my $region = $c->req->param('coords');
    	my ($chr,$start,$stop)=$self->extract_chr_region($c,$region);
    	
    	$browser->chr($chr);
    	$browser->seg_start($start);
    	$browser->seg_stop($stop);
    	my $l_binsize = $c->session->{'settings'}->{'lowres_binsize'};
    	$browser->setting("lowres_binsize",$l_binsize);
    	$browser->round_positions if $browser->seg_start;
    	
    	return $browser;
    }
    
    sub extract_chr_region {
    	my ($self,$c,$keywords)=@_;
    	$c->log->info("keywords:$keywords");
    	my ($chr, $start, $stop, $type);
    	if ($keywords =~ /[Chr|chr]*(\w+)/) {
    		my $chr = $1;
    		if ($keywords =~ /[Chr|chr]*(\w+)\D(\d+)..(\d+)/) {
				($chr,$start,$stop) = ($1,$2,$3);
				$c->log->info("1:$1, 2:$2, 3:$3");
				return ($chr, $start, $stop);
    		}
    		else {
    			$c->log->info("chr:$chr");
    			return ($chr);
    		}
		}
		return undef;
    }

=head1 AUTHOR

  Rob Free <rcfree@gmail.com>>

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
