package HGVbaseG2P::Web::Controller::PhenotypeMethod;

# $Id: PhenotypeMethod.pm 1231 2009-07-06 13:21:15Z rcf8 $

=head1 NAME

HGVbaseG2P::Web::Controller::PhenotypeMethod - Catalyst Controller for phenotype methods

=head1 DESCRIPTION

  Catalyst Controller.

=head1 METHODS

=cut

use strict;
use warnings;
use base qw(HGVbaseG2P::Web::Controller::Root);

#use HGVbaseG2P::Schema;
use JSON::XS;
use Data::Dumper qw(Dumper);

# Globals
my $json_coder = JSON::XS->new->ascii->pretty->allow_nonref;
$json_coder->space_after(1);

=head2 view

Action which redirects to the default action

=cut

sub view : Local {
    my ( $self, $c ) = @_;
    my $url = $c->req->uri->as_string;
    $url =~ s|(\w+)/view|$1|;
    $c->response->redirect($url);
}

=head2 default

Action which retrieves a phenotype method and passes it to the template

=cut

sub default :Regex('^phenotypemethod/(HGV\w+)$') {
    my ( $self, $c) = @_;
    my $id = $c->req->captures->[0];
    $c->log->debug("Creating phenotypemethod report for $id");
    my $phenmethod = $c->model("StudyDB")->get_phenotypemethod_by_identifier($id);
	
	#if not present redirect to notfound template
    if(!$phenmethod) {
    	$c->stash->{notfound_type}='Phenotype Method';
    	$c->stash->{notfound_id}=$id;
        $c->stash->{template} = 'notfound.tt2'; 
		return;
    }
    
    $c->stash->{phenmethodid} = $id;
    $c->stash->{template} = 'phenotypemethod/view.tt2';
    $c->stash->{phenmethod} = $phenmethod;
    return;
}

sub phenotypes :Regex('^phenotypes$') {
	my ($self, $c) = @_;
	if ($self->do_search('phenotypes',$c)) {
		my @dis_cats = $c->model("StudyDB")->dbh->dbh->resultset('Diseasecategory')->search->all;
		my %dis =();
		foreach my $con_dis (@dis_cats) {
			my @temp = split(";",$con_dis->name);
			foreach my $sep_dis(@temp) {
				$dis{$sep_dis}=1;
			}	
		}
		$c->stash->{category_splits}=[
			[qw(A B C D)],[qw(E F G H)],[qw(I J K L)], [qw(M N O P)], [qw(Q R S T)], [qw(U V W X)], [qw(Y Z)]
		];
		$c->stash->{disease_categories}=[sort keys %dis];
		$c->stash->{template}='phenotypes.tt2';
	}
}

=head2 experiments

Action which gets experiments associated with a phenotypemethod and passes them to a template.

=cut

sub experiments :Regex('^phenotypemethod/experiments/(HGV\w+)$') {
    my ( $self, $c ) = @_;
	my $id = $c->req->captures->[0];
	
    # Retrieve experiments with phenotype method from the database
    my $experiments = $c->model("StudyDB")->get_experiments_with_phenotypemethod_by_identifier($id);
    
  	if ($experiments->count==1 && $experiments->single->resultsets->count==1) {
  		$c->stash->{single}=1;
  	}
  	
    $c->stash->{experiments}=$experiments;
    
    $c->stash->{template}="phenotypemethod/experiments.tt2";
    return;
}


=head1 AUTHOR

  Gudmundur A. Thorisson <gthorisson@gmail.com>>
  Rob Free <rcfree@gmail.com>
  
=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
