package HGVbaseG2P::Web::Controller::Search;

# $Id: Search.pm 1253 2009-07-17 09:45:55Z rcf8 $

=head1 NAME

  HGVbaseG2P::Web::Controller::Search - Catalyst Controller for the free-text website search

=head1 DESCRIPTION

  This class is a wrapper around several data sources that can be queried via the website search
  tool. This includes documents indexed for Xapian boolean keyword search, direct queries to the
  master database, and feature database searches.

=head1 METHODS

=cut

use strict;
use warnings;
use English;
use Data::Dumper;

use base 'HGVbaseG2P::Web::Controller::Root';
use HGVbaseG2P::Search;
use Carp qw(confess);

#
#sub COMPONENT {
#    my ($class, $c, $args) = @_;
#    my $self = $class->NEXT::COMPONENT($c);
#    $self->config($args);
#    return $self;
#}


=head2 index 

=cut

sub search :Regex('^search$') {
    my ( $self, $c ) = @_;
    $c->stash->{template} = 'search/results.tt2';
    my $config = $c->config->{'Controller::Search'};
    my $qstring = $c->req->param('query');
    $qstring =~ s/(\n|\r|\n\r)/ /g;
    
    # Figure out which db or db's to use for search
    my $db2use = $c->req->param('db') || 'all';
    
    my @dbs2use;

    if($db2use ne 'all') {
        # Check if this is a valid database
        if (!exists $config->{Database}->{$db2use}) {
        	$c->stash->{error_msg}="The Search Database '$db2use' is not valid";return;
        }
        @dbs2use = ($db2use);
    }
    else {
        # We simply want to use all available databases
        @dbs2use = keys(%{$config->{Database}});
    }
    
	# make sure that the templates have access to the config for all the db's
    $c->stash->{dbconfig} = $config->{Database};
    $c->stash->{available_db}=$config->{Database};
    $c->stash->{dbs} = \@dbs2use;
        
	if (!defined($qstring) || length(trim($qstring))==0) {
		$c->stash->{error_msg}='You did not supply a query. Please try again.';
		return;
	}
	
    my $search = HGVbaseG2P::Search->new({
    	query => $qstring,
    	page => ($c->req->param('page') || 1),
    	page_size => ($c->req->param('page_size') || 10),
    	context => $c,
    	conf_file => $config
    });
    
    $c->stash->{qstring}=$qstring;
	$c->stash->{qterms}=$search->qterms;
    
    # Query each db in turn
    DB:
    foreach my $db(@dbs2use) {
        my ($results, $pager);
        my $dbconfig = $config->{Database}->{$db};

        if($dbconfig->{type} eq 'Xapian') {
            $c->log->debug("Sending query to the Xapian-db $db");
            eval {
           	 ($pager, $results) = $search->query_xapian($db);
            };
            if ($@) {
            	$c->stash->{error_msg}='This is not a valid query. Please try again.'.confess($@);
				return;
            }
        }
        elsif($dbconfig->{type} eq 'Study') {
            $c->log->debug("Sending query to StudyDB for dbclass $dbconfig->{class}");
            ($pager, $results) = $search->query_study($dbconfig->{class});
        }
        elsif($dbconfig->{type} eq 'Marker') {
            $c->log->info("Sending query to MarkerDB for dbclass $dbconfig->{class}");
            ($pager, $results) = $search->query_marker($dbconfig->{class});
        }
        elsif($dbconfig->{type} eq 'Mart') {
            $c->log->debug("Sending query to Mart-db $db");
            ($pager, $results) = $search->query_mart($db);
        }
        elsif($dbconfig->{type} eq 'SeqFeature') {
            $c->log->debug("Sending query to SeqFeature-db $db");
            ($pager, $results) = $search->query_seqfeatures($db);
        }
        else {
            $c->log->warn("Database type '$dbconfig->{type}' not recognized, skipping db $db");
            next DB;
        }

        if(!$results) {
            $c->log->debug("Nothing found db $db for string '$qstring'");
            next DB;
        }

        # If we only found a single entry AND this is a search in a single db, THEN
        # redirect browser straight to the report page (if we know which one it is)
       if(scalar(@{$results}) == 1 && scalar(@dbs2use) == 1) {
            if(my $url = $dbconfig->{reporturl}) {
            	my $item =  $results->[0];
                my $url_withid = sprintf($url, $item->identifier);
                $c->log->debug("Got single result in single db $db, so redirecting to report page $url_withid");
                $c->res->redirect($url_withid);
            }
        }

        # Pass results & iterator to template
        $c->stash->{searchresults}->{$db} = $results;
        $c->stash->{pagers}->{$db}        = $pager;     
    }
}

# Generate RSS news feed of search results, instead of normal web page
sub rss : Local {
    my ($self,$c) = @_;

    # First forward to the main index action above to run the actual search
    $c->log->debug("Creating RSS feed for search results");
    $c->forward('index');

    # Then create the RSS output based on the results now available in the stash from index()
    ## NB see http://search.cpan.org/~zarquon/Catalyst-Manual-5.7013/lib/Catalyst/Manual/Cookbook.pod#Using_XML::Feed
    my $feed = XML::Atom::Feed->new;

    $feed->title('HGVbaseG2P search results' );
    $feed->link("http://www.hgvbaseg2p.org" );

    foreach my $dbname(@{$c->stash->{dbs}}) {
	$c->log->debug("  Getting results for db $dbname");
	my $results = $c->stash->{searchresults}->{$dbname};
	foreach my $r(@$results) {
	    $c->log->debug("    Adding feed entry for ".$r->identifier);
	    my $feed_entry = XML::Atom::Entry->new;
	    $feed_entry->title($r->identifier." - Chromosome:". $r->markercoords->first->start. ", Start:".$r->markercoords->first->start .", Stop:".$r->markercoords->first->stop);
        my $link = XML::Atom::Link->new;
        $link->type('text/html');
        $link->rel('alternate');
        $link->href("http://www.hgvbaseg2p.org");
        $feed_entry->link($link);
	    $feed->add_entry($feed_entry);
	}
    }
    $c->res->body($feed->as_xml);
}

sub trim {
	my $string = shift;
	$string =~ s/^\s+//;
	$string =~ s/\s+$//;
	return $string;
}



=head1 AUTHOR

  Gudmundur A. Thorisson <gthorisson@gmail.com>>
  Rob Free <rcfree@gmail.com>
  
=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
