#!perl

# $Id: calculateMarkersImported.pl 1273 2009-08-21 15:12:40Z rcf8 $

# Precalculate markers imported and genotype bundle in StudyDB

use strict;
use warnings;
use FindBin;
use lib "$FindBin::Bin/../lib/";
use HGVbaseG2P::Database::Study;
use HGVbaseG2P::Util qw(load_config);

use Log::Log4perl qw(:easy);
Log::Log4perl->easy_init($INFO);

use Data::Dumper qw(Dumper);

# NB this module here handles commandline-option processing, according
# to the POD documention below the code.
use Getopt::Euclid qw( :minimal_keys );

my $conf_file  = $ARGV{c};

my %config     = load_config($conf_file);
my $SUMMARY_NO = 100000;

my $study_db   = HGVbaseG2P::Database::Study->new(
	{ conf_file=>\%config }
);

my @studies = $study_db->dbh->resultset('Study')->all;

foreach my $study(@studies) {
	foreach my $experiment($study->experiments->all) {
		my $count = $experiment->usedmarkersets->count;
		print $experiment->identifier.":".$count."\n";
		$experiment->update({ totalmarkersimported => $count});
	} 
}
$study_db->dbh->storage->dbh->do("UPDATE Experiment SET GenotypedBundle = (SELECT GROUP_CONCAT(BundleLoci.BundleName SEPARATOR ';') FROM BundleLoci NATURAL JOIN GenotypedBundle WHERE Experiment.ExperimentID = GenotypedBundle.ExperimentID)");



__END__


=head1 NAME

  - Calculate markers imported for each experiment, and genotyped bundle list in Study DB

=head1 VERSION

  0.1

=head1 DESCRIPTION

  This script calculates markers imported for each experiment in Study DB
 
  $Id

=head1 USAGE

  [ignored, usage line is built by Getopt::Euclid from interface-description below]

=head1 OPTIONS

=over

=item -v[erbose]

  Set logging to verbose (Log4perl level of 'DEBUG')
  
=item -c[onfigfile] <file>
  
  HGVbaseG2P config file to use

=for Euclid:
        file.type:    readable
        file.default: 'conf/hgvbase.conf'
         
=item --version

=item --usage

=item --help

=item --man

  Print the usual program information

=back

=head1 AUTHOR

  Rob Free <rcfree@gmail.com>>

=head1 BUGS

  None known, but please report any to the author
    
=cut
