#!perl

# $Id$


# create BioMart database using HGVbaseG2Pmart/HGVbaseG2P modules

use strict;
use warnings;
use FindBin;
use lib "$FindBin::Bin/../lib/";
use HGVbaseG2Pmart::MartCreator;
use Data::Dumper qw(Dumper);

# NB this module here handles commandline-option processing, according
# to the POD documention below the code.
use Getopt::Euclid qw( :minimal_keys );

if ($ARGV{test}) {
	$ARGV{configfile} = '../conf/test/hgvmart.conf'
}
print Dumper({
    append=>$ARGV{append},
    conf_file=>$ARGV{configfile},
    verbose=>$ARGV{verbose},
    update=>$ARGV{update}, 
    scripts=>$ARGV{scripts},
    dataset=>$ARGV{dataset},
    replaceid=>$ARGV{replaceid},
    noconfirm=>$ARGV{noconfirm},
    ignorebase=>$ARGV{ignorebase},
    killbase=>$ARGV{killbase},
});

my $creator = HGVbaseG2Pmart::MartCreator->new({
    append=>$ARGV{append},
	conf_file=>$ARGV{configfile},
	verbose=>$ARGV{verbose},
	update=>$ARGV{update}, 
	scripts=>$ARGV{scripts},
	dataset=>$ARGV{dataset},
    replaceid=>$ARGV{replaceid},
    noconfirm=>$ARGV{noconfirm},
    ignorebase=>$ARGV{ignorebase},
        killbase=>$ARGV{killbase},
});
$creator->create_mart;

__END__


=head1 NAME

  - Create mart from HGVbaseG2P database using a mart config script.

=head1 VERSION

  0.1

=head1 DESCRIPTION

  This script creates a BioMart database using the data in the live HGVbaseG2P database.
  It uses the SQL files in martsql and XML config files in martxml to generate this.
  Logic for the creation is in the HGVbaseG2Pmart::MartCreator and associated classes.
 
  $Id

=head1 USAGE

  [ignored, usage line is built by Getopt::Euclid from interface-description below]

=head1 OPTIONS

=over

=item -v[erbose]

  Set logging to verbose (Log4perl level of 'DEBUG')
  
=item -c[onfigfile] <file>
  
  Mart generating config file to use

=for Euclid:
        file.type:    readable
        file.default: '../conf/hgvmart.conf'

=item -t[est]
	
  Use the 'hgvmart.conf' config file in 'conf/test' rather that 'conf'
	
=item -u[pdate]

  Stops mart being dropped and only updates data in config table.

=item -a[ppend]

  Stops mart being dropped and runs append_[dateset].sql at end of creation. Generally used inconjunction with replace_id

=item -s[cripts] <file>

  Only execute these SQL script(s) in directory specified in config file

=item -d[ataset] <dataset>
 
  Only execute mart SQL for one dataset
  
=item -r[eplaceid] <id>

  Replace <replace_id> in SQL with this value e.g. HGVST1
  
=item -n[oconfirm]

  Removes need to confirm database drop

=item -i[gnorebase]

  Ignore base SQL (ie. [dataset].sql) and only run ones with a suffix eg. marker.sql will not be run, but marker_af.sql will

=item --version

=item --usage

=item --help

=item --man

  Print the usual program information

=back

=head1 AUTHOR

  Rob Free <rcfree@gmail.com>>

=head1 BUGS

  None known, but please report any to the author
    
=cut
