#!perl

# $Id: generateBulkdata.pl 550 2008-04-23 15:00:42Z rcf8 $


# generates bulk-data dumps from HGVmart using XML queries

use strict;
use warnings;
use FindBin;
use lib "$FindBin::Bin/../lib/";
use HGVbaseG2Pmart::DataGenerator;

# NB this module handles commandline-option processing, according
# to the POD documention below the code.
use Getopt::Euclid qw( :minimal_keys );

if ($ARGV{test}) {
	$ARGV{configfile} = '../conf/test/hgvmart.conf'
}

my $datagen = HGVbaseG2Pmart::DataGenerator->new(conf_file => $ARGV{configfile},
				 argv      => \%ARGV) || die "Could not initialize bulk-data generator";
				 
$datagen->generate_data;

__END__


=head1 NAME

  generateBulkdata.pl

=head1 VERSION

  0.1

=head1 DESCRIPTION

  This script generates bulk-data dumps from HGVmart using XML queries.
  It uses a config file to specify the location of the XML files, output file name properties and other
  required information.
  Logic for the creation is in the HGVbaseG2Pmart::DataGenerator and associated classes.
 
  $Id: generateBulkdata.pl 550 2008-04-23 15:00:42Z rcf8 $

=head1 USAGE

  [ignored, usage line is built by Getopt::Euclid from interface-description below]

=head1 OPTIONS

=over

=item -v[erbose]

  Set logging to verbose (Log4perl level of 'DEBUG')
  
=item -c[onfigfile] <file>
  
  Mart generating config file to use

=for Euclid:
        file.type:    readable
        file.default: '../conf/hgvmart.conf'

=item -t[est]
	
  Use the 'hgvmart.conf' config file in 'conf/test' rather that 'conf'
  
=item --version

=item --usage

=item --help

=item --man

  Print the usual program information

=back

=head1 AUTHOR

  Rob Free <rcfree@gmail.com>>

=head1 BUGS

  None known, but please report any to the author
    
=cut
