use FindBin;
use lib "$FindBin::Bin/../lib";
use HGVbaseG2P::Database::Study;
use HGVbaseG2P::Database::Browser;
use Data::Dumper qw(Dumper);
use HGVbaseG2P::Browser::Util qw(chr_list);

use Log::Log4perl qw(:easy);
Log::Log4perl->easy_init($INFO);


my $browser_db =
  HGVbaseG2P::Database::Browser->new( { conf_file => 'conf/hgvbase.conf' } );
my $study_db = HGVbaseG2P::Database::Study->new( { conf_file => 'conf/hgvbase.conf' } );
my @resultset_list = $study_db->dbh->resultset("Resultset")->search->all;

foreach(@resultset_list) {
$resultsets{$_->resultsetid}=$_;
}

foreach my $chr ( keys %{ chr_list() } ) {
	eval {
		$browser_db->dbh->do("CREATE TABLE `marker_resultsets_chr$chr` (
	  `Marker_Identifier` varchar(20) NOT NULL,
	  `Marker_Accession` varchar(20) NOT NULL,
	  `Start` bigint(20) NOT NULL,
	  `Stop` bigint(20) NOT NULL,
	  `ResultsetList0` text NOT NULL,
	  `ResultsetList1` text NOT NULL,
	  `ResultsetList2` text NOT NULL,
	  `ResultsetList3` text NOT NULL,
	  `ResultsetList4` text NOT NULL,
	  `ResultsetList5` text NOT NULL,
	  `ResultsetList6` text NOT NULL,
	  `ResultsetList7` text NOT NULL,
	  `ResultsetList8` text NOT NULL,
	  KEY `MarkerID` (`Marker_Identifier`),
	  KEY `Region` (`Start`,`Stop`)
	) ENGINE=MyISAM DEFAULT CHARSET=latin1;");
	};
	if ($@) {
		$browser_db->dbh->do("DELETE FROM marker_resultsets_chr$chr");
	}
	INFO "Chromosome $chr";
	my $sql = "select Marker_Accession, Marker_Identifier,Start, Stop, ResultsetID, NegLogPValue from marker_data_chr$chr";
	my $sth = $browser_db->dbh->prepare($sql);
	$sth->execute();
	my %markers=();
	while(my $row = $sth->fetchrow_hashref) {
		my $mid = $row->{'Marker_Identifier'};
		$markers{$mid}={accession=>$row->{Marker_Accession}, start=>$row->{Start}, stop=>$row->{Stop}, data=>[] } if !exists($markers{$mid});
		push @{$markers{$mid}->{data}},$row;
	}
	#INFO "Markers " . scalar(keys %markers);
	$sql = "insert into marker_resultsets_chr$chr (Marker_Identifier, Marker_Accession, Start, Stop, ResultsetList0,ResultsetList1,ResultsetList2,ResultsetList3,ResultsetList4,ResultsetList5,ResultsetList6,ResultsetList7,ResultsetList8) values(?,?,?,?,?,?,?,?,?,?,?,?,?)";
	$sth = $browser_db->dbh->prepare($sql);
	foreach my $mid(keys %markers) {
		my @studylists=();
		#INFO "marker: $mid" . Dumper(\%studies);
		foreach my $marker(@{$markers{$mid}->{data}}) {
			
			#INFO "Marker $marker->{Marker_Identifier}, Study:".$marker->{Identifier_Study}." Neg P value:".$marker->{NegLogPValue};
			for (my $threshold=8;$threshold>=0;$threshold--) {
				#INFO "Check threshold $threshold";
				if ($marker->{NegLogPValue}>=$threshold) {
					#INFO "-logPvalue greater than threshold $threshold";
					for (my $loc=0;$loc<=$threshold;$loc++) {
						my $rsid = $marker->{ResultsetID};
						my $rs = $resultsets{$rsid};
						my $study = $rs->identifier;
						$studylists[$loc]->{$study}=1;
					}
					last;
				}
				
			}
			
		}
		my @study;
		foreach my $counter(0..8) {
			my $study = $studylists[$counter];
			$study[$counter]=join(";",keys %{$study});
		}
		
		$sth->execute($mid,$markers{$mid}->{accession}, $markers{$mid}->{start}, $markers{$mid}->{stop},@study);
	}
}
