#$Id: validateXML.pl 480 2008-04-02 12:43:48Z rob $

#!/usr/bin/perl
use strict;
use warnings;
use Getopt::Euclid qw( :minimal_keys );
use IO::Uncompress::AnyUncompress qw(anyuncompress $AnyUncompressError);
use FindBin;
use lib "$FindBin::Bin/../lib";
use HGVbaseG2P::Util qw(initLogger);
use Data::Dumper;

#set up logger
my $logger = initLogger("$FindBin::Bin/../conf/log4perl.conf");

#relaxng schema (required)
my $relaxng_schema = $ARGV{relaxng_schema};
#files to process
my $infiles        = $ARGV{infiles};
my @all_files      = @$infiles;
#set up some counters for later
my $num_files      = 0;
my $valid          = 0;
my $error          = 0;
my @error_files;
foreach my $file (@all_files)
{
	$num_files++;
	my @file_name = split( /\./, $file );

	#create a new name for the uncompressed output
	my $output = $file_name[0] . ".xml.uncompressed";
	my $input  = $file;

	#create the uncompreessed file
	anyuncompress $input => $output
	  or die "anyuncompress failed: $AnyUncompressError\n";
	my ( $xml_validation, $success ) = Jing( $relaxng_schema, $output );
	
	if ( $success < 1 )
	{
		$logger->info("$file is valid according to $relaxng_schema");
		$valid++;
		unlink($output);
	} elsif ( $success > 0 )
	{
		$error++;
		$logger->error($xml_validation);
		unlink($output);
		push @error_files,"$file\n";
	}
}
$logger->info(
"\n###Validation has been performed on $num_files files###\n$valid valid files\n$error validation errors\n###error files###\n@error_files\n"
);

sub Jing
{
	my ( $relaxng_schema, $xmlfile ) = @_;
	my $info =
`java -jar /Users/rob/Documents/Tools/jing/bin/jing.jar $relaxng_schema $xmlfile 2>&1`;


if ($info=~/^Unable\s+to\s+access\s+jarfile.*/){
			$logger->error("$info");
		unlink($xmlfile);
		die;
}else{
			return ( $info, $? );
}

}
__END__

=head1 NAME

  XML Validation using Relaxng schema

=head1 VERSION
  
  
  0.1

=head1 DESCRIPTION

  This script takes reads a directory of XML files and validates them against a RELAXNG schema using JING
  If valid an info statement is printed to the terminal describing the file as valid, else an info statement points to print the jing error message, 
  statisitcs of valid and no valid files are printed at the end along with the error filenames
  
  
=head1 USAGE

  [ignored, usage line is built by Getopt::Euclid from interface-description below]
  replace the path to jing with your local copy

=head1 REQUIRED ARGUMENTS

=over

=item -r[elaxng_schema] <relaxng_schema>

a valid relaxng schema in XML format

	
=item -i[nfiles] <infiles>...

	/path/to/the/file.* etc
	





=back


=head1 OPTIONS

=over

=item -v[erbose]

  Set logging to verbose (Log4perl level of 'DEBUG')
  
=item --version

=item --usage

=item --help

=item --man

  Print the usual program information
  


=back


=head1 AUTHOR

  Robert Hastings (rkh7@le.ac.uk)

=head1 BUGS

  None known, but please report any to the author
    
=cut



