#!perl -w

# $Id: 03_markerimport.t 463 2008-03-27 13:02:59Z mummi $

# Test data import - export module

use strict;
use warnings;

use Test::More  qw/no_plan/; # NB increment this as you add more tests!
use Test::Exception;
use Data::Dumper qw(Dumper);
use List::Compare;
use FindBin;
use lib "$FindBin::Bin/../lib";
use HGVbaseG2P::Util qw(load_config);
use HGVbaseG2P::DataImport::Export::Database;
use HGVbaseG2P::DataImport::DataElement;
use HGVbaseG2P::Database::Study;
use Bio::SeqFeature::Generic;

my $export = HGVbaseG2P::DataImport::Export::Database->new;
my %template = load_config('conf/import/PMID16252231_1.conf');
$export->template(\%template);
$export->frequencies(0);
$export->associations(1);
$export->db(HGVbaseG2P::Database::Study->new({conf_file=>'conf/test/hgvbase.conf'}));
my ($study,$experiment) = $export->get_study_and_experiment($template{study_identifier}, $template{experiment_identifier});
$export->resultset_lookup('identifier');
my ($resultset) = $export->get_resultset($template{resultset_identifier});

$export->db->dbh->resultset('Usedmarkerset')->search({'experimentid'=>$experiment->experimentid})->delete;
$export->db->dbh->resultset('Significance')->search({'resultsetid'=>$resultset->resultsetid})->delete;


my @des = ();
$des[0] = HGVbaseG2P::DataImport::DataElement->new;
$des[0]->line({
          'genotype22' => '(T)',
          'genotype11' => '(C)',
          'position' => '36746853',
          'oddsratio' => '0.94059',
          'ignore' => '404',
          'lowerci' => '0.67759',
          'accession' => 'rs10000068',
          'allele2' => 'T',
          'chromosome' => '4',
          'pvalue' => '0.7142',
          'allele1' => 'C',
          'strand' => '+',
          'genotype12' => '(C)+(T)',
          'upperci' => '1.3057'
        });
my $marker = Bio::SeqFeature::Generic->new(
	-start => '3000',
	-stop => '3000',
	-strand => '1',
	-source => 'rs100000068',
	-score => '123',
	-display_name => 'HGVM35654',
	-tag          => {chr => '3', alleles=>[qw(A C)], upstream30bp =>'', downstream30bp =>'' }
);


$des[0]->marker($marker);  
$des[1] = HGVbaseG2P::DataImport::DataElement->new;
$des[1]->line({
          'genotype22' => '(T)',
          'genotype11' => '(C)',
          'position' => '36746853',
          'oddsratio' => '0.94059',
          'ignore' => '404',
          'lowerci' => '0.67759',
          'accession' => 'rs100066',
          'allele2' => 'T',
          'chromosome' => '4',
          'pvalue' => '0.7142',
          'allele1' => 'C',
          'strand' => '+',
          'genotype12' => '(C)+(T)',
          'upperci' => '1.3057'
        });
$des[1]->marker(Bio::SeqFeature::Generic->new(
	-start => '3000',
	-stop => '3000',
	-strand => '1',
	-source => 'rs100066',
	-score => '123',
	-display_name => 'HGVM3562',
	-tag          => {chr => '3', alleles=>[qw(A C)], upstream30bp =>'', downstream30bp =>'' }
));

$export->output(\@des);

$des[1]->line->{'pvalue'}='0.1345';
$export->output(\@des);
