#!perl -w

# $Id: 03_markerimport.t 463 2008-03-27 13:02:59Z mummi $

# Test data import - retrieve marker module

use strict;
use warnings;

use Test::More  qw/no_plan/; # NB increment this as you add more tests!
use Test::Exception;
use Data::Dumper qw(Dumper);

use FindBin;
use lib "$FindBin::Bin/../lib";
use HGVbaseG2P::DataImport::RetrieveMarker;
use HGVbaseG2P::Database::Marker;

my $rm = HGVbaseG2P::DataImport::RetrieveMarker->new();
my $db = HGVbaseG2P::Database::Marker->new({ conf_file=>'conf/hgvbase.conf' });
$rm->accession_db('dbSNP');
$rm->db($db);

#check active marker
check_marker("rs829","rs829",0,0,0,0);


#check dead marker with no pointer
check_marker("rs2795","rs2795",0,1,0,0);

#check strand flipped, dead and merged marker
check_marker("rs2795","rs2795",1,1,1,1);

my ($marker, $status) = $rm->get_validated_marker('rsXYZ');
ok !$marker,"Marker rsXYZ not present";

sub check_marker {
	my($accession, $latest_accession, $strandflip, $dead, $merged, $replacementdead) = @_;
	
	my ($marker, $status) = $rm->get_validated_marker($accession);
	$marker and ok $marker->source_tag eq $latest_accession,"Latest accession expected ".$marker->source_tag ." eq " . $latest_accession;
	
	if ($strandflip) {
		ok $status->{f},"Marker replacement strand flip";
	}
	else {
		ok !$status->{f},"Marker replacement NO strand flip";
	}
	
	if ($dead) {
		ok $status->{d},"Marker dead";
	}
	else {
		ok !$status->{d},"Marker NOT dead";
	}
	
	if ($merged) {
		ok $status->{m},"Marker merged";
	}
	else {
		ok !$status->{m},"Marker NOT merged";
	}
	
	if ($replacementdead) {
		ok $status->{r},"Marker replacement dead";
	}
	else {
		ok !$status->{r},"Marker replacement NOT dead";
	}
}